/***************************************************************************
 *   Copyright (C) 2004-2007 by Albert Astals Cid                          *
 *   aacid@kde.org                                                         *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 ***************************************************************************/
i18nc("afghanistan.kgm", "Afghanistan");
i18nc("afghanistan.kgm", "Provinces");
i18nc("afghanistan.kgm", "Frontier");
i18nc("afghanistan.kgm", "Frontier");
i18nc("afghanistan.kgm", "Iran");
i18nc("afghanistan.kgm", "Turkmenistan");
i18nc("afghanistan.kgm", "Uzbekistan");
i18nc("afghanistan.kgm", "Tajikistan");
i18nc("afghanistan.kgm", "China");
i18nc("afghanistan.kgm", "Pakistan");
i18nc("afghanistan.kgm", "India");
i18nc("afghanistan.kgm", "Badakhshan");
i18nc("afghanistan.kgm", "Fayzabad");
i18nc("afghanistan.kgm", "Badghis");
i18nc("afghanistan.kgm", "Qala i Naw");
i18nc("afghanistan.kgm", "Baghlan");
i18nc("afghanistan.kgm", "Puli Khumri");
i18nc("afghanistan.kgm", "Balkh");
i18nc("afghanistan.kgm", "Mazari Sharif");
i18nc("afghanistan.kgm", "Bamiyan");
i18nc("afghanistan.kgm", "Bamiyan");
i18nc("afghanistan.kgm", "Daykundi");
i18nc("afghanistan.kgm", "Nili");
i18nc("afghanistan.kgm", "Jowzjan");
i18nc("afghanistan.kgm", "Sheberghan");
i18nc("afghanistan.kgm", "Farah");
i18nc("afghanistan.kgm", "Farah");
i18nc("afghanistan.kgm", "Faryab");
i18nc("afghanistan.kgm", "Maymana");
i18nc("afghanistan.kgm", "Ghazni");
i18nc("afghanistan.kgm", "Ghazni");
i18nc("afghanistan.kgm", "Ghor");
i18nc("afghanistan.kgm", "Chaghcharan");
i18nc("afghanistan.kgm", "Helmand");
i18nc("afghanistan.kgm", "Lashkar Gah");
i18nc("afghanistan.kgm", "Herat");
i18nc("afghanistan.kgm", "Herat");
i18nc("afghanistan.kgm", "Kabul");
i18nc("afghanistan.kgm", "Kabul");
i18nc("afghanistan.kgm", "Kandahar");
i18nc("afghanistan.kgm", "Kandahar");
i18nc("afghanistan.kgm", "Kapisa");
i18nc("afghanistan.kgm", "Mahmud-i-Raqi");
i18nc("afghanistan.kgm", "Khost");
i18nc("afghanistan.kgm", "Khost");
i18nc("afghanistan.kgm", "Kunar");
i18nc("afghanistan.kgm", "Asadabad");
i18nc("afghanistan.kgm", "Kunduz");
i18nc("afghanistan.kgm", "Kunduz");
i18nc("afghanistan.kgm", "Laghman");
i18nc("afghanistan.kgm", "Mihtarlam");
i18nc("afghanistan.kgm", "Lowgar");
i18nc("afghanistan.kgm", "Pul-i-Alam");
i18nc("afghanistan.kgm", "Nangarhar");
i18nc("afghanistan.kgm", "Jalalabad");
i18nc("afghanistan.kgm", "Nimruz");
i18nc("afghanistan.kgm", "Zaranj");
i18nc("afghanistan.kgm", "Nuristan");
i18nc("afghanistan.kgm", "Kamdish");
i18nc("afghanistan.kgm", "Orūzgān");
i18nc("afghanistan.kgm", "Tarin Kowt");
i18nc("afghanistan.kgm", "Paktia");
i18nc("afghanistan.kgm", "Gardez");
i18nc("afghanistan.kgm", "Paktika");
i18nc("afghanistan.kgm", "Sharan");
i18nc("afghanistan.kgm", "Panjshir");
i18nc("afghanistan.kgm", "Bazarak");
i18nc("afghanistan.kgm", "Parwan");
i18nc("afghanistan.kgm", "Charikar");
i18nc("afghanistan.kgm", "Samangan");
i18nc("afghanistan.kgm", "Aybak");
i18nc("afghanistan.kgm", "Sar-e Pol");
i18nc("afghanistan.kgm", "Sar-e Pol");
i18nc("afghanistan.kgm", "Takhar");
i18nc("afghanistan.kgm", "Taloqan");
i18nc("afghanistan.kgm", "Wardak");
i18nc("afghanistan.kgm", "Meydan Shahr");
i18nc("afghanistan.kgm", "Zabul");
i18nc("afghanistan.kgm", "Qalat");
i18nc("africa.kgm", "Africa");
i18nc("africa.kgm", "Countries");
i18nc("africa.kgm", "Frontier");
i18nc("africa.kgm", "Water");
i18nc("africa.kgm", "Not Africa");
i18nc("africa.kgm", "Not Africa ");
i18nc("africa.kgm", "Algeria");
i18nc("africa.kgm", "Algiers");
i18nc("africa.kgm", "Angola");
i18nc("africa.kgm", "Luanda");
i18nc("africa.kgm", "Benin");
i18nc("africa.kgm", "Porto-Novo");
i18nc("africa.kgm", "Botswana");
i18nc("africa.kgm", "Gaborone");
i18nc("africa.kgm", "Burkina Faso");
i18nc("africa.kgm", "Ouagadougou");
i18nc("africa.kgm", "Burundi");
i18nc("africa.kgm", "Bujumbura");
i18nc("africa.kgm", "Cameroon");
i18nc("africa.kgm", "Yaoundé");
i18nc("africa.kgm", "Cape Verde");
i18nc("africa.kgm", "Praia");
i18nc("africa.kgm", "Central African Republic");
i18nc("africa.kgm", "Bangui");
i18nc("africa.kgm", "Chad");
i18nc("africa.kgm", "N'Djamena");
i18nc("africa.kgm", "Comoros");
i18nc("africa.kgm", "Moroni");
i18nc("africa.kgm", "Côte d'Ivoire");
i18nc("africa.kgm", "Yamoussoukro");
i18nc("africa.kgm", "Democratic Republic of the Congo");
i18nc("africa.kgm", "Kinshasa");
i18nc("africa.kgm", "Djibouti");
i18nc("africa.kgm", "Djibouti");
i18nc("africa.kgm", "Egypt");
i18nc("africa.kgm", "Cairo");
i18nc("africa.kgm", "Equatorial Guinea");
i18nc("africa.kgm", "Malabo");
i18nc("africa.kgm", "Eritrea");
i18nc("africa.kgm", "Asmara");
i18nc("africa.kgm", "Ethiopia");
i18nc("africa.kgm", "Addis Ababa");
i18nc("africa.kgm", "Gabon");
i18nc("africa.kgm", "Libreville");
i18nc("africa.kgm", "Gambia");
i18nc("africa.kgm", "Banjul");
i18nc("africa.kgm", "Ghana");
i18nc("africa.kgm", "Accra");
i18nc("africa.kgm", "Guinea");
i18nc("africa.kgm", "Conakry");
i18nc("africa.kgm", "Guinea-Bissau");
i18nc("africa.kgm", "Bissau");
i18nc("africa.kgm", "Kenya");
i18nc("africa.kgm", "Nairobi");
i18nc("africa.kgm", "Lesotho");
i18nc("africa.kgm", "Maseru");
i18nc("africa.kgm", "Liberia");
i18nc("africa.kgm", "Monrovia");
i18nc("africa.kgm", "Libya");
i18nc("africa.kgm", "Tripoli");
i18nc("africa.kgm", "Madagascar");
i18nc("africa.kgm", "Antananarivo");
i18nc("africa.kgm", "Malawi");
i18nc("africa.kgm", "Lilongwe");
i18nc("africa.kgm", "Mali");
i18nc("africa.kgm", "Bamako");
i18nc("africa.kgm", "Mauritania");
i18nc("africa.kgm", "Nouakchott");
i18nc("africa.kgm", "Mauritius");
i18nc("africa.kgm", "Port Louis");
i18nc("africa.kgm", "Morocco");
i18nc("africa.kgm", "Rabat");
i18nc("africa.kgm", "Mozambique");
i18nc("africa.kgm", "Maputo");
i18nc("africa.kgm", "Namibia");
i18nc("africa.kgm", "Windhoek");
i18nc("africa.kgm", "Niger");
i18nc("africa.kgm", "Niamey");
i18nc("africa.kgm", "Nigeria");
i18nc("africa.kgm", "Abuja");
i18nc("africa.kgm", "Republic of the Congo");
i18nc("africa.kgm", "Brazzaville");
i18nc("africa.kgm", "Rwanda");
i18nc("africa.kgm", "Kigali");
i18nc("africa.kgm", "Senegal");
i18nc("africa.kgm", "Dakar");
i18nc("africa.kgm", "Seychelles");
i18nc("africa.kgm", "Victoria");
i18nc("africa.kgm", "Sierra Leone");
i18nc("africa.kgm", "Freetown");
i18nc("africa.kgm", "Somalia");
i18nc("africa.kgm", "Mogadishu");
i18nc("africa.kgm", "South Africa");
i18nc("africa.kgm", "Pretoria");
i18nc("africa.kgm", "Sudan");
i18nc("africa.kgm", "Khartoum");
i18nc("africa.kgm", "South Sudan");
i18nc("africa.kgm", "Juba");
i18nc("africa.kgm", "Swaziland");
i18nc("africa.kgm", "Mbabane");
i18nc("africa.kgm", "São Tomé and Príncipe");
i18nc("africa.kgm", "São Tomé");
i18nc("africa.kgm", "Tanzania");
i18nc("africa.kgm", "Dodoma");
i18nc("africa.kgm", "Togo");
i18nc("africa.kgm", "Lomé");
i18nc("africa.kgm", "Tunisia");
i18nc("africa.kgm", "Tunis");
i18nc("africa.kgm", "Uganda");
i18nc("africa.kgm", "Kampala");
i18nc("africa.kgm", "Western Sahara");
i18nc("africa.kgm", "El Aaiún");
i18nc("africa.kgm", "Zambia");
i18nc("africa.kgm", "Lusaka");
i18nc("africa.kgm", "Zimbabwe");
i18nc("africa.kgm", "Harare");
i18nc("africa.kgm", "Canary Islands (Spain)");
i18nc("africa.kgm", "Las Palmas");
i18nc("africa.kgm", "Madeira (Portugal)");
i18nc("africa.kgm", "Funchal");
i18nc("africa.kgm", "Réunion (France)");
i18nc("africa.kgm", "Saint Denis");
i18nc("africa.kgm", "Saint Helena (UK)");
i18nc("africa.kgm", "Jamestown");
i18nc("albania_districts.kgm", "Albania (Districts)");
i18nc("albania_districts.kgm", "Districts");
i18nc("albania_districts.kgm", "Frontier");
i18nc("albania_districts.kgm", "Frontier");
i18nc("albania_districts.kgm", "Water");
i18nc("albania_districts.kgm", "Not Albania");
i18nc("albania_districts.kgm", "Berat");
i18nc("albania_districts.kgm", "Bulqizë");
i18nc("albania_districts.kgm", "Delvinë");
i18nc("albania_districts.kgm", "Devoll");
i18nc("albania_districts.kgm", "Dibër");
i18nc("albania_districts.kgm", "Durrës");
i18nc("albania_districts.kgm", "Elbasan");
i18nc("albania_districts.kgm", "Fier");
i18nc("albania_districts.kgm", "Gjirokastër");
i18nc("albania_districts.kgm", "Gramsh");
i18nc("albania_districts.kgm", "Has");
i18nc("albania_districts.kgm", "Kavajë");
i18nc("albania_districts.kgm", "Kolonjë");
i18nc("albania_districts.kgm", "Korçë");
i18nc("albania_districts.kgm", "Krujë");
i18nc("albania_districts.kgm", "Kuçovë");
i18nc("albania_districts.kgm", "Kukës");
i18nc("albania_districts.kgm", "Kurbin");
i18nc("albania_districts.kgm", "Lezhë");
i18nc("albania_districts.kgm", "Librazhd");
i18nc("albania_districts.kgm", "Lushnjë");
i18nc("albania_districts.kgm", "Malësi e Madhe");
i18nc("albania_districts.kgm", "Mallakastër");
i18nc("albania_districts.kgm", "Mat");
i18nc("albania_districts.kgm", "Mirditë");
i18nc("albania_districts.kgm", "Peqin");
i18nc("albania_districts.kgm", "Përmet");
i18nc("albania_districts.kgm", "Pogradec");
i18nc("albania_districts.kgm", "Pukë");
i18nc("albania_districts.kgm", "Sarandë");
i18nc("albania_districts.kgm", "Shkodër");
i18nc("albania_districts.kgm", "Skrapar");
i18nc("albania_districts.kgm", "Tepelenë");
i18nc("albania_districts.kgm", "Tiranë");
i18nc("albania_districts.kgm", "Tropojë");
i18nc("albania_districts.kgm", "Vlorë");
i18nc("albania_prefectures.kgm", "Albania (Prefectures)");
i18nc("albania_prefectures.kgm", "Prefectures");
i18nc("albania_prefectures.kgm", "Frontier");
i18nc("albania_prefectures.kgm", "Frontier");
i18nc("albania_prefectures.kgm", "Water");
i18nc("albania_prefectures.kgm", "Not Albania");
i18nc("albania_prefectures.kgm", "Berat");
i18nc("albania_prefectures.kgm", "Berat");
i18nc("albania_prefectures.kgm", "Dibër");
i18nc("albania_prefectures.kgm", "Peshkopi");
i18nc("albania_prefectures.kgm", "Durrès");
i18nc("albania_prefectures.kgm", "Durrès");
i18nc("albania_prefectures.kgm", "Elbasan");
i18nc("albania_prefectures.kgm", "Elbasan");
i18nc("albania_prefectures.kgm", "Fier");
i18nc("albania_prefectures.kgm", "Fier");
i18nc("albania_prefectures.kgm", "Gjirokastër");
i18nc("albania_prefectures.kgm", "Gjirokastër");
i18nc("albania_prefectures.kgm", "Korçë");
i18nc("albania_prefectures.kgm", "Korçë");
i18nc("albania_prefectures.kgm", "Kukës");
i18nc("albania_prefectures.kgm", "Kukës");
i18nc("albania_prefectures.kgm", "Lezhë");
i18nc("albania_prefectures.kgm", "Lezhë");
i18nc("albania_prefectures.kgm", "Shkodër");
i18nc("albania_prefectures.kgm", "Shkodër");
i18nc("albania_prefectures.kgm", "Tirana");
i18nc("albania_prefectures.kgm", "Tirana");
i18nc("albania_prefectures.kgm", "Vlorë");
i18nc("albania_prefectures.kgm", "Vlorë");
i18nc("algeria.kgm", "Algeria");
i18nc("algeria.kgm", "Provinces");
i18nc("algeria.kgm", "Frontier");
i18nc("algeria.kgm", "Water");
i18nc("algeria.kgm", "Not Algeria");
i18nc("algeria.kgm", "Adrar");
i18nc("algeria.kgm", "Aïn Defla");
i18nc("algeria.kgm", "Aïn Témouchent");
i18nc("algeria.kgm", "Algiers");
i18nc("algeria.kgm", "Annaba");
i18nc("algeria.kgm", "Batna");
i18nc("algeria.kgm", "Béchar");
i18nc("algeria.kgm", "Béjaïa");
i18nc("algeria.kgm", "Biskra");
i18nc("algeria.kgm", "Blida");
i18nc("algeria.kgm", "Bordj Bou Arréridj");
i18nc("algeria.kgm", "Bouira");
i18nc("algeria.kgm", "Boumerdès");
i18nc("algeria.kgm", "Chlef");
i18nc("algeria.kgm", "Constantine");
i18nc("algeria.kgm", "Djelfa");
i18nc("algeria.kgm", "El Bayadh");
i18nc("algeria.kgm", "El Oued");
i18nc("algeria.kgm", "El Tarf");
i18nc("algeria.kgm", "Ghardaïa");
i18nc("algeria.kgm", "Guelma");
i18nc("algeria.kgm", "Illizi");
i18nc("algeria.kgm", "Jijel");
i18nc("algeria.kgm", "Khenchela");
i18nc("algeria.kgm", "Laghouat");
i18nc("algeria.kgm", "Médéa");
i18nc("algeria.kgm", "Mila");
i18nc("algeria.kgm", "Mostaganem");
i18nc("algeria.kgm", "M'Sila");
i18nc("algeria.kgm", "Muaskar");
i18nc("algeria.kgm", "Naama");
i18nc("algeria.kgm", "Oran");
i18nc("algeria.kgm", "Ouargla");
i18nc("algeria.kgm", "Oum el-Bouaghi");
i18nc("algeria.kgm", "Relizane");
i18nc("algeria.kgm", "Saida");
i18nc("algeria.kgm", "Sétif");
i18nc("algeria.kgm", "Sidi Bel Abbes");
i18nc("algeria.kgm", "Skikda");
i18nc("algeria.kgm", "Souk Ahras");
i18nc("algeria.kgm", "Tamanghasset");
i18nc("algeria.kgm", "Tébessa");
i18nc("algeria.kgm", "Tiaret");
i18nc("algeria.kgm", "Tindouf");
i18nc("algeria.kgm", "Tipasa");
i18nc("algeria.kgm", "Tissemsilt");
i18nc("algeria.kgm", "Tizi Ouzou");
i18nc("algeria.kgm", "Tlemcen");
i18nc("andhrapradesh.kgm", "Andhra Pradesh");
i18nc("andhrapradesh.kgm", "District");
i18nc("andhrapradesh.kgm", "Not Andhra Pradesh");
i18nc("andhrapradesh.kgm", "Frontier");
i18nc("andhrapradesh.kgm", "Adilabad");
i18nc("andhrapradesh.kgm", "Adilabad");
i18nc("andhrapradesh.kgm", "Nizamabad");
i18nc("andhrapradesh.kgm", "Nizamabad");
i18nc("andhrapradesh.kgm", "Karimnagar");
i18nc("andhrapradesh.kgm", "Karimnagar");
i18nc("andhrapradesh.kgm", "Medak");
i18nc("andhrapradesh.kgm", "Sangareddy");
i18nc("andhrapradesh.kgm", "Warangal");
i18nc("andhrapradesh.kgm", "Warangal");
i18nc("andhrapradesh.kgm", "Rangareddy");
i18nc("andhrapradesh.kgm", "Hyderabad");
i18nc("andhrapradesh.kgm", "Hyderabad");
i18nc("andhrapradesh.kgm", "Hyderabad");
i18nc("andhrapradesh.kgm", "Khammam");
i18nc("andhrapradesh.kgm", "Khammam");
i18nc("andhrapradesh.kgm", "Nalgonda");
i18nc("andhrapradesh.kgm", "Nalgonda");
i18nc("andhrapradesh.kgm", "Mahbubnagar");
i18nc("andhrapradesh.kgm", "Mahbubnagar");
i18nc("andhrapradesh.kgm", "Kurnool");
i18nc("andhrapradesh.kgm", "Kurnool");
i18nc("andhrapradesh.kgm", "Anantapur");
i18nc("andhrapradesh.kgm", "Anantapur");
i18nc("andhrapradesh.kgm", "Chittoor");
i18nc("andhrapradesh.kgm", "Chittoor");
i18nc("andhrapradesh.kgm", "Cuddapah");
i18nc("andhrapradesh.kgm", "Cuddapah");
i18nc("andhrapradesh.kgm", "Nellore");
i18nc("andhrapradesh.kgm", "Nellore");
i18nc("andhrapradesh.kgm", "Prakasam");
i18nc("andhrapradesh.kgm", "Ongole");
i18nc("andhrapradesh.kgm", "Guntur");
i18nc("andhrapradesh.kgm", "Guntur");
i18nc("andhrapradesh.kgm", "Krishna");
i18nc("andhrapradesh.kgm", "Machilipatnam");
i18nc("andhrapradesh.kgm", "West Godavari");
i18nc("andhrapradesh.kgm", "Eluru");
i18nc("andhrapradesh.kgm", "East Godavari");
i18nc("andhrapradesh.kgm", "Kakinada");
i18nc("andhrapradesh.kgm", "Vishakhapatnam");
i18nc("andhrapradesh.kgm", "Vishakhapatnam");
i18nc("andhrapradesh.kgm", "Vizianagaram");
i18nc("andhrapradesh.kgm", "Vizianagaram");
i18nc("andhrapradesh.kgm", "Srikakulam");
i18nc("andhrapradesh.kgm", "Srikakulam");
i18nc("andorra.kgm", "Andorra");
i18nc("andorra.kgm", "Parishes");
i18nc("andorra.kgm", "Frontier");
i18nc("andorra.kgm", "Frontier");
i18nc("andorra.kgm", "Spain");
i18nc("andorra.kgm", "France");
i18nc("andorra.kgm", "Andorra la Vella");
i18nc("andorra.kgm", "La Massana");
i18nc("andorra.kgm", "Ordino");
i18nc("andorra.kgm", "Canillo");
i18nc("andorra.kgm", "Encamp");
i18nc("andorra.kgm", "Escaldes-Engordany");
i18nc("andorra.kgm", "Sant Julià de Lòria");
i18nc("angola_provinces.kgm", "Angola (Provinces)");
i18nc("angola_provinces.kgm", "Provinces");
i18nc("angola_provinces.kgm", "Frontier");
i18nc("angola_provinces.kgm", "Water");
i18nc("angola_provinces.kgm", "Not Angola (Provinces)");
i18nc("angola_provinces.kgm", "Bengo");
i18nc("angola_provinces.kgm", "Caxito");
i18nc("angola_provinces.kgm", "Benguela");
i18nc("angola_provinces.kgm", "Benguela");
i18nc("angola_provinces.kgm", "Bié");
i18nc("angola_provinces.kgm", "Kuito");
i18nc("angola_provinces.kgm", "Cabinda");
i18nc("angola_provinces.kgm", "Cabinda");
i18nc("angola_provinces.kgm", "Cuando Cubango");
i18nc("angola_provinces.kgm", "Menongue");
i18nc("angola_provinces.kgm", "Cuanza Norte");
i18nc("angola_provinces.kgm", "Ndalatando");
i18nc("angola_provinces.kgm", "Cuanza Sul");
i18nc("angola_provinces.kgm", "Sumbe");
i18nc("angola_provinces.kgm", "Cunene");
i18nc("angola_provinces.kgm", "Ondjiva");
i18nc("angola_provinces.kgm", "Huambo");
i18nc("angola_provinces.kgm", "Huambo");
i18nc("angola_provinces.kgm", "Huíla");
i18nc("angola_provinces.kgm", "Lubango");
i18nc("angola_provinces.kgm", "Luanda");
i18nc("angola_provinces.kgm", "Luanda");
i18nc("angola_provinces.kgm", "Lunda Norte");
i18nc("angola_provinces.kgm", "Lucapa");
i18nc("angola_provinces.kgm", "Lunda Sul");
i18nc("angola_provinces.kgm", "Saurimo");
i18nc("angola_provinces.kgm", "Malanje");
i18nc("angola_provinces.kgm", "Malanje");
i18nc("angola_provinces.kgm", "Namibe");
i18nc("angola_provinces.kgm", "Namibe");
i18nc("angola_provinces.kgm", "Moxico");
i18nc("angola_provinces.kgm", "Luena");
i18nc("angola_provinces.kgm", "Uíge");
i18nc("angola_provinces.kgm", "Uíge");
i18nc("angola_provinces.kgm", "Zaire");
i18nc("angola_provinces.kgm", "Mbanza Congo");
i18nc("argentina.kgm", "Argentina");
i18nc("argentina.kgm", "Provinces");
i18nc("argentina.kgm", "Frontier");
i18nc("argentina.kgm", "Frontier");
i18nc("argentina.kgm", "Not Argentina");
i18nc("argentina.kgm", "Water");
i18nc("argentina.kgm", "Buenos Aires(city)");
i18nc("argentina.kgm", "Buenos Aires");
i18nc("argentina.kgm", "La Plata");
i18nc("argentina.kgm", "Catamarca");
i18nc("argentina.kgm", "San Fernando del Valle de Catamarca");
i18nc("argentina.kgm", "Chaco");
i18nc("argentina.kgm", "Resistencia");
i18nc("argentina.kgm", "Chubut");
i18nc("argentina.kgm", "Rawson");
i18nc("argentina.kgm", "Córdoba");
i18nc("argentina.kgm", "Córdoba");
i18nc("argentina.kgm", "Corrientes");
i18nc("argentina.kgm", "Corrientes");
i18nc("argentina.kgm", "Entre Ríos");
i18nc("argentina.kgm", "Paraná");
i18nc("argentina.kgm", "Formosa");
i18nc("argentina.kgm", "Formosa");
i18nc("argentina.kgm", "Jujuy");
i18nc("argentina.kgm", "San Salvador de Jujuy");
i18nc("argentina.kgm", "La Pampa");
i18nc("argentina.kgm", "Santa Rosa");
i18nc("argentina.kgm", "La Rioja");
i18nc("argentina.kgm", "La Rioja");
i18nc("argentina.kgm", "Mendoza");
i18nc("argentina.kgm", "Mendoza");
i18nc("argentina.kgm", "Misiones");
i18nc("argentina.kgm", "Posadas");
i18nc("argentina.kgm", "Neuquén");
i18nc("argentina.kgm", "Neuquén");
i18nc("argentina.kgm", "Río Negro");
i18nc("argentina.kgm", "Viedma");
i18nc("argentina.kgm", "Salta");
i18nc("argentina.kgm", "Salta");
i18nc("argentina.kgm", "San Juan");
i18nc("argentina.kgm", "San Juan");
i18nc("argentina.kgm", "San Luis");
i18nc("argentina.kgm", "San Luis");
i18nc("argentina.kgm", "Santa Cruz");
i18nc("argentina.kgm", "Río Gallegos");
i18nc("argentina.kgm", "Santa Fe");
i18nc("argentina.kgm", "Santa Fe");
i18nc("argentina.kgm", "Santiago del Estero");
i18nc("argentina.kgm", "Santiago del Estero");
i18nc("argentina.kgm", "Tierra del Fuego");
i18nc("argentina.kgm", "Ushuaia");
i18nc("argentina.kgm", "Tucumán");
i18nc("argentina.kgm", "San Miguel de Tucumán");
i18nc("armenia.kgm", "Armenia");
i18nc("armenia.kgm", "Regions");
i18nc("armenia.kgm", "Frontier");
i18nc("armenia.kgm", "Frontier");
i18nc("armenia.kgm", "Lake Van");
i18nc("armenia.kgm", "Lake Sevan");
i18nc("armenia.kgm", "Azerbaijan");
i18nc("armenia.kgm", "Georgia");
i18nc("armenia.kgm", "Iran");
i18nc("armenia.kgm", "Turkey");
i18nc("armenia.kgm", "Aragatsotn");
i18nc("armenia.kgm", "Ashtarak");
i18nc("armenia.kgm", "Ararat");
i18nc("armenia.kgm", "Artashat");
i18nc("armenia.kgm", "Armavir");
i18nc("armenia.kgm", "Armavir");
i18nc("armenia.kgm", "Gegharkunik");
i18nc("armenia.kgm", "Gavar");
i18nc("armenia.kgm", "Kotayk");
i18nc("armenia.kgm", "Hrazdan");
i18nc("armenia.kgm", "Lori");
i18nc("armenia.kgm", "Vanadzor");
i18nc("armenia.kgm", "Shirak");
i18nc("armenia.kgm", "Gyumri");
i18nc("armenia.kgm", "Syunik");
i18nc("armenia.kgm", "Kapan");
i18nc("armenia.kgm", "Tavush");
i18nc("armenia.kgm", "Ijevan");
i18nc("armenia.kgm", "Vayots Dzor");
i18nc("armenia.kgm", "Yeghegnadzor");
i18nc("armenia.kgm", "Yerevan");
i18nc("arunachalpradesh.kgm", "Arunachal Pradesh");
i18nc("arunachalpradesh.kgm", "District");
i18nc("arunachalpradesh.kgm", "Not Arunachal Pradesh");
i18nc("arunachalpradesh.kgm", "Frontier");
i18nc("arunachalpradesh.kgm", "Tirap");
i18nc("arunachalpradesh.kgm", "Khonsa");
i18nc("arunachalpradesh.kgm", "Changlang");
i18nc("arunachalpradesh.kgm", "Changlang");
i18nc("arunachalpradesh.kgm", "Lohit");
i18nc("arunachalpradesh.kgm", "Tezu");
i18nc("arunachalpradesh.kgm", "Anjaw");
i18nc("arunachalpradesh.kgm", "Hawai");
i18nc("arunachalpradesh.kgm", "Lower Dibang Valley");
i18nc("arunachalpradesh.kgm", "Roing");
i18nc("arunachalpradesh.kgm", "Dibang Valley");
i18nc("arunachalpradesh.kgm", "Anini");
i18nc("arunachalpradesh.kgm", "Upper Siang");
i18nc("arunachalpradesh.kgm", "Yingkiong");
i18nc("arunachalpradesh.kgm", "East Siang");
i18nc("arunachalpradesh.kgm", "Pasighat");
i18nc("arunachalpradesh.kgm", "West Siang");
i18nc("arunachalpradesh.kgm", "Along");
i18nc("arunachalpradesh.kgm", "Tawang");
i18nc("arunachalpradesh.kgm", "Tawang");
i18nc("arunachalpradesh.kgm", "West Kameng");
i18nc("arunachalpradesh.kgm", "Bomdila");
i18nc("arunachalpradesh.kgm", "East Kameng");
i18nc("arunachalpradesh.kgm", "Seppa");
i18nc("arunachalpradesh.kgm", "Papum Pare");
i18nc("arunachalpradesh.kgm", "Yupia");
i18nc("arunachalpradesh.kgm", "Lower Subansiri");
i18nc("arunachalpradesh.kgm", "Ziro");
i18nc("arunachalpradesh.kgm", "Kurung Kumey");
i18nc("arunachalpradesh.kgm", "Koloriang");
i18nc("arunachalpradesh.kgm", "Upper Subansiri");
i18nc("arunachalpradesh.kgm", "Daporijo");
i18nc("asia.kgm", "Asia");
i18nc("asia.kgm", "Countries");
i18nc("asia.kgm", "Frontier");
i18nc("asia.kgm", "Water");
i18nc("asia.kgm", "Russia");
i18nc("asia.kgm", "Moscow");
i18nc("asia.kgm", "Turkey");
i18nc("asia.kgm", "Ankara");
i18nc("asia.kgm", "Egypt");
i18nc("asia.kgm", "Djibouti");
i18nc("asia.kgm", "Eritrea");
i18nc("asia.kgm", "Ethiopia");
i18nc("asia.kgm", "Iran");
i18nc("asia.kgm", "Tehran");
i18nc("asia.kgm", "Iraq");
i18nc("asia.kgm", "Baghdad");
i18nc("asia.kgm", "Israel");
i18nc("asia.kgm", "Jerusalem");
i18nc("asia.kgm", "Jordan");
i18nc("asia.kgm", "Amman");
i18nc("asia.kgm", "Kenya");
i18nc("asia.kgm", "Kuwait");
i18nc("asia.kgm", "Kuwait City");
i18nc("asia.kgm", "Lebanon");
i18nc("asia.kgm", "Beirut");
i18nc("asia.kgm", "Qatar");
i18nc("asia.kgm", "Doha");
i18nc("asia.kgm", "Saudi Arabia");
i18nc("asia.kgm", "Riyadh");
i18nc("asia.kgm", "Somalia");
i18nc("asia.kgm", "Sudan");
i18nc("asia.kgm", "South Sudan");
i18nc("asia.kgm", "Syria");
i18nc("asia.kgm", "Damascus");
i18nc("asia.kgm", "Uganda");
i18nc("asia.kgm", "United Arab Emirates");
i18nc("asia.kgm", "Abu Dhabi City");
i18nc("asia.kgm", "Oman");
i18nc("asia.kgm", "Muscat");
i18nc("asia.kgm", "West Bank");
i18nc("asia.kgm", "Yemen");
i18nc("asia.kgm", "Sana'a");
i18nc("asia.kgm", "Ukraine");
i18nc("asia.kgm", "China");
i18nc("asia.kgm", "Beijing");
i18nc("asia.kgm", "India");
i18nc("asia.kgm", "New Delhi");
i18nc("asia.kgm", "Sri Lanka");
i18nc("asia.kgm", "Colombo and Sri Jayewardenepura");
i18nc("asia.kgm", "Mongolia");
i18nc("asia.kgm", "Ulaanbaatar");
i18nc("asia.kgm", "Kazakhstan");
i18nc("asia.kgm", "Astana");
i18nc("asia.kgm", "Japan");
i18nc("asia.kgm", "Tokyo");
i18nc("asia.kgm", "Myanmar");
i18nc("asia.kgm", "Naypyidaw");
i18nc("asia.kgm", "Nepal");
i18nc("asia.kgm", "Kathmandu");
i18nc("asia.kgm", "Bhutan");
i18nc("asia.kgm", "Thimphu");
i18nc("asia.kgm", "Indonesia");
i18nc("asia.kgm", "Jakarta");
i18nc("asia.kgm", "Malaysia");
i18nc("asia.kgm", "Kuala Lumpur");
i18nc("asia.kgm", "Bangladesh");
i18nc("asia.kgm", "Dhaka");
i18nc("asia.kgm", "Afghanistan");
i18nc("asia.kgm", "Kabul");
i18nc("asia.kgm", "Azerbaijan");
i18nc("asia.kgm", "Baku");
i18nc("asia.kgm", "Armenia");
i18nc("asia.kgm", "Yerevan");
i18nc("asia.kgm", "Bahrain");
i18nc("asia.kgm", "Manama");
i18nc("asia.kgm", "Georgia");
i18nc("asia.kgm", "Tbilisi");
i18nc("asia.kgm", "Turkmenistan");
i18nc("asia.kgm", "Ashgabat");
i18nc("asia.kgm", "Uzbekistan");
i18nc("asia.kgm", "Tashkent");
i18nc("asia.kgm", "Kyrgyzstan");
i18nc("asia.kgm", "Bishkek");
i18nc("asia.kgm", "Tajikistan");
i18nc("asia.kgm", "Dushanbe");
i18nc("asia.kgm", "Pakistan");
i18nc("asia.kgm", "Islamabad");
i18nc("asia.kgm", "Laos");
i18nc("asia.kgm", "Vientiane");
i18nc("asia.kgm", "Cambodia");
i18nc("asia.kgm", "Phnom Penh");
i18nc("asia.kgm", "Brunei");
i18nc("asia.kgm", "Bandar Seri Begawan");
i18nc("asia.kgm", "Philippines");
i18nc("asia.kgm", "Manila");
i18nc("asia.kgm", "Thailand");
i18nc("asia.kgm", "Bangkok");
i18nc("asia.kgm", "Vietnam");
i18nc("asia.kgm", "Hanoi");
i18nc("asia.kgm", "Taiwan");
i18nc("asia.kgm", "Taipei");
i18nc("asia.kgm", "Singapore");
i18nc("asia.kgm", "Singapore");
i18nc("asia.kgm", "North Korea");
i18nc("asia.kgm", "Pyeongyang");
i18nc("asia.kgm", "South Korea");
i18nc("asia.kgm", "Seoul");
i18nc("asia.kgm", "East Timor");
i18nc("asia.kgm", "Dili");
i18nc("asia.kgm", "Tanzania");
i18nc("asia.kgm", "Zambia");
i18nc("asia.kgm", "Mozambique");
i18nc("asia.kgm", "Malawi");
i18nc("asia.kgm", "Madagascar");
i18nc("asia.kgm", "Papua New Guinea");
i18nc("asia.kgm", "Australia");
i18nc("asia.kgm", "Cyprus");
i18nc("assam.kgm", "Assam");
i18nc("assam.kgm", "District");
i18nc("assam.kgm", "Not Assam");
i18nc("assam.kgm", "Frontier");
i18nc("assam.kgm", "Kokrajhar");
i18nc("assam.kgm", "Kokrajhar");
i18nc("assam.kgm", "Dhuburi");
i18nc("assam.kgm", "Dhuburi");
i18nc("assam.kgm", "Goalpara");
i18nc("assam.kgm", "Goalpara");
i18nc("assam.kgm", "Bongaigaon");
i18nc("assam.kgm", "Bongaigaon");
i18nc("assam.kgm", "Barpeta");
i18nc("assam.kgm", "Barpeta");
i18nc("assam.kgm", "Nalbari");
i18nc("assam.kgm", "Nalbari");
i18nc("assam.kgm", "Dispur");
i18nc("assam.kgm", "Dispur");
i18nc("assam.kgm", "Kamrup");
i18nc("assam.kgm", "Guwahati");
i18nc("assam.kgm", "Darrang");
i18nc("assam.kgm", "Darrang");
i18nc("assam.kgm", "Marigaon");
i18nc("assam.kgm", "Marigaon");
i18nc("assam.kgm", "Karbi Anglong");
i18nc("assam.kgm", "Diphu");
i18nc("assam.kgm", "North Cachar Hills");
i18nc("assam.kgm", "Haflong");
i18nc("assam.kgm", "Cachar");
i18nc("assam.kgm", "Silchar");
i18nc("assam.kgm", "Hailakandi");
i18nc("assam.kgm", "Hailakandi");
i18nc("assam.kgm", "Karimganj");
i18nc("assam.kgm", "Karimganj");
i18nc("assam.kgm", "Golaghat");
i18nc("assam.kgm", "Golaghat");
i18nc("assam.kgm", "Nagaon");
i18nc("assam.kgm", "Nagaon");
i18nc("assam.kgm", "Sonitpur");
i18nc("assam.kgm", "Sonitpur");
i18nc("assam.kgm", "Lakhimpur");
i18nc("assam.kgm", "North Lakhimpur");
i18nc("assam.kgm", "Jorhat");
i18nc("assam.kgm", "Jorhat");
i18nc("assam.kgm", "Dhemaji");
i18nc("assam.kgm", "Dhemaji");
i18nc("assam.kgm", "Sibsagar");
i18nc("assam.kgm", "Sibsagar");
i18nc("assam.kgm", "Dibrugarh");
i18nc("assam.kgm", "Dibrugarh");
i18nc("assam.kgm", "Tinsukia");
i18nc("assam.kgm", "Tinsukia");
i18nc("australia.kgm", "Australia");
i18nc("australia.kgm", "States");
i18nc("australia.kgm", "Frontier");
i18nc("australia.kgm", "Not Australia");
i18nc("australia.kgm", "Coast");
i18nc("australia.kgm", "Australian Capital Territory");
i18nc("australia.kgm", "Canberra");
i18nc("australia.kgm", "New South Wales");
i18nc("australia.kgm", "Sydney");
i18nc("australia.kgm", "Victoria");
i18nc("australia.kgm", "Melbourne");
i18nc("australia.kgm", "Queensland");
i18nc("australia.kgm", "Brisbane");
i18nc("australia.kgm", "South Australia");
i18nc("australia.kgm", "Adelaide");
i18nc("australia.kgm", "Western Australia");
i18nc("australia.kgm", "Perth");
i18nc("australia.kgm", "Tasmania");
i18nc("australia.kgm", "Hobart");
i18nc("australia.kgm", "Northern Territory");
i18nc("australia.kgm", "Darwin");
i18nc("austria.kgm", "Austria");
i18nc("austria.kgm", "States");
i18nc("austria.kgm", "Frontier");
i18nc("austria.kgm", "Not Austria");
i18nc("austria.kgm", "Vienna");
i18nc("austria.kgm", "Vienna");
i18nc("austria.kgm", "Burgenland");
i18nc("austria.kgm", "Eisenstadt");
i18nc("austria.kgm", "Styria");
i18nc("austria.kgm", "Graz");
i18nc("austria.kgm", "Carinthia");
i18nc("austria.kgm", "Klagenfurt");
i18nc("austria.kgm", "Tyrol");
i18nc("austria.kgm", "Innsbruck");
i18nc("austria.kgm", "Vorarlberg");
i18nc("austria.kgm", "Bregenz");
i18nc("austria.kgm", "Salzburg");
i18nc("austria.kgm", "Salzburg");
i18nc("austria.kgm", "Upper Austria");
i18nc("austria.kgm", "Linz");
i18nc("austria.kgm", "Lower Austria");
i18nc("austria.kgm", "St. Pölten");
i18nc("azerbaijan.kgm", "Azerbaijan");
i18nc("azerbaijan.kgm", "Rayons");
i18nc("azerbaijan.kgm", "Frontier");
i18nc("azerbaijan.kgm", "Water");
i18nc("azerbaijan.kgm", "Not Azerbaijan");
i18nc("azerbaijan.kgm", "Absheron");
i18nc("azerbaijan.kgm", "Agjabadi");
i18nc("azerbaijan.kgm", "Agdam");
i18nc("azerbaijan.kgm", "Agdash");
i18nc("azerbaijan.kgm", "Agstafa");
i18nc("azerbaijan.kgm", "Agsu");
i18nc("azerbaijan.kgm", "Shirvan city");
i18nc("azerbaijan.kgm", "Astara");
i18nc("azerbaijan.kgm", "Baku city");
i18nc("azerbaijan.kgm", "Balakan");
i18nc("azerbaijan.kgm", "Barda");
i18nc("azerbaijan.kgm", "Beylagan");
i18nc("azerbaijan.kgm", "Bilasuvar");
i18nc("azerbaijan.kgm", "Jabrayil");
i18nc("azerbaijan.kgm", "Jalilabad");
i18nc("azerbaijan.kgm", "Dashkasan");
i18nc("azerbaijan.kgm", "Davachi");
i18nc("azerbaijan.kgm", "Fizuli");
i18nc("azerbaijan.kgm", "Gadabay");
i18nc("azerbaijan.kgm", "Ganja city");
i18nc("azerbaijan.kgm", "Goranboy");
i18nc("azerbaijan.kgm", "Goychay");
i18nc("azerbaijan.kgm", "Hajigabul");
i18nc("azerbaijan.kgm", "Imishli");
i18nc("azerbaijan.kgm", "Ismailli");
i18nc("azerbaijan.kgm", "Kalbajar");
i18nc("azerbaijan.kgm", "Kurdamir");
i18nc("azerbaijan.kgm", "Lachin");
i18nc("azerbaijan.kgm", "Lankaran");
i18nc("azerbaijan.kgm", "Lankaran city");
i18nc("azerbaijan.kgm", "Lerik");
i18nc("azerbaijan.kgm", "Masally");
i18nc("azerbaijan.kgm", "Mingachevir city");
i18nc("azerbaijan.kgm", "Naftalan city");
i18nc("azerbaijan.kgm", "Neftchala");
i18nc("azerbaijan.kgm", "Oguz");
i18nc("azerbaijan.kgm", "Qabala");
i18nc("azerbaijan.kgm", "Qakh");
i18nc("azerbaijan.kgm", "Qazakh");
i18nc("azerbaijan.kgm", "Qobustan");
i18nc("azerbaijan.kgm", "Quba");
i18nc("azerbaijan.kgm", "Qubadli");
i18nc("azerbaijan.kgm", "Qusar");
i18nc("azerbaijan.kgm", "Saatly");
i18nc("azerbaijan.kgm", "Sabirabad");
i18nc("azerbaijan.kgm", "Shaki");
i18nc("azerbaijan.kgm", "Shaki city");
i18nc("azerbaijan.kgm", "Salyan");
i18nc("azerbaijan.kgm", "Shamakhi");
i18nc("azerbaijan.kgm", "Shamkir");
i18nc("azerbaijan.kgm", "Samukh");
i18nc("azerbaijan.kgm", "Siazan");
i18nc("azerbaijan.kgm", "Sumqayit city");
i18nc("azerbaijan.kgm", "Shusha");
i18nc("azerbaijan.kgm", "Shusha city");
i18nc("azerbaijan.kgm", "Tartar");
i18nc("azerbaijan.kgm", "Tovuz");
i18nc("azerbaijan.kgm", "Ujar");
i18nc("azerbaijan.kgm", "Khachmaz");
i18nc("azerbaijan.kgm", "Khankendi city");
i18nc("azerbaijan.kgm", "Goygol");
i18nc("azerbaijan.kgm", "Khizi");
i18nc("azerbaijan.kgm", "Khojali");
i18nc("azerbaijan.kgm", "Khojavend");
i18nc("azerbaijan.kgm", "Yardymli");
i18nc("azerbaijan.kgm", "Yevlakh");
i18nc("azerbaijan.kgm", "Yevlakh city");
i18nc("azerbaijan.kgm", "Zangilan");
i18nc("azerbaijan.kgm", "Zaqatala");
i18nc("azerbaijan.kgm", "Zardab");
i18nc("azerbaijan.kgm", "Babek");
i18nc("azerbaijan.kgm", "Julfa");
i18nc("azerbaijan.kgm", "Kangarli");
i18nc("azerbaijan.kgm", "Nakhichevan City");
i18nc("azerbaijan.kgm", "Ordubad");
i18nc("azerbaijan.kgm", "Sadarak");
i18nc("azerbaijan.kgm", "Shakhbuz");
i18nc("azerbaijan.kgm", "Sharur");
i18nc("bangladesh.kgm", "Bangladesh");
i18nc("bangladesh.kgm", "Divisions");
i18nc("bangladesh.kgm", "Frontier");
i18nc("bangladesh.kgm", "Water");
i18nc("bangladesh.kgm", "Not Bangladesh");
i18nc("bangladesh.kgm", "Barisa");
i18nc("bangladesh.kgm", "Chittagong");
i18nc("bangladesh.kgm", "Dhaka");
i18nc("bangladesh.kgm", "Khulna");
i18nc("bangladesh.kgm", "Rajshahi");
i18nc("bangladesh.kgm", "Sylhet");
i18nc("belarus.kgm", "Belarus");
i18nc("belarus.kgm", "Provinces");
i18nc("belarus.kgm", "Frontier");
i18nc("belarus.kgm", "Frontier");
i18nc("belarus.kgm", "Not Belarus");
i18nc("belarus.kgm", "Minsk");
i18nc("belarus.kgm", "Brest Voblast");
i18nc("belarus.kgm", "Homyel Voblast");
i18nc("belarus.kgm", "Hrodna Voblast");
i18nc("belarus.kgm", "Mahilyow Voblast");
i18nc("belarus.kgm", "Minsk Voblast");
i18nc("belarus.kgm", "Vitebsk Voblast");
i18nc("belgium.kgm", "Belgium");
i18nc("belgium.kgm", "Provinces");
i18nc("belgium.kgm", "Frontier");
i18nc("belgium.kgm", "Not Belgium");
i18nc("belgium.kgm", "Water");
i18nc("belgium.kgm", "Antwerp");
i18nc("belgium.kgm", "Antwerp");
i18nc("belgium.kgm", "Brussels");
i18nc("belgium.kgm", "Brussels");
i18nc("belgium.kgm", "Flemish Brabant");
i18nc("belgium.kgm", "Louvain");
i18nc("belgium.kgm", "West Flanders");
i18nc("belgium.kgm", "Bruges");
i18nc("belgium.kgm", "East Flanders");
i18nc("belgium.kgm", "Ghent");
i18nc("belgium.kgm", "Limburg");
i18nc("belgium.kgm", "Hasselt");
i18nc("belgium.kgm", "Walloon Brabant");
i18nc("belgium.kgm", "Wavre");
i18nc("belgium.kgm", "Hainaut");
i18nc("belgium.kgm", "Mons");
i18nc("belgium.kgm", "Liege");
i18nc("belgium.kgm", "Liege");
i18nc("belgium.kgm", "Luxembourg");
i18nc("belgium.kgm", "Arlon");
i18nc("belgium.kgm", "Namur");
i18nc("belgium.kgm", "Namur");
i18nc("belize.kgm", "Belize");
i18nc("belize.kgm", "Districts");
i18nc("belize.kgm", "Frontier");
i18nc("belize.kgm", "Frontier");
i18nc("belize.kgm", "Water");
i18nc("belize.kgm", "Not Belize");
i18nc("belize.kgm", "Belize District");
i18nc("belize.kgm", "Belize City");
i18nc("belize.kgm", "Cayo District");
i18nc("belize.kgm", "San Ignacio");
i18nc("belize.kgm", "Corozal District");
i18nc("belize.kgm", "Corozal Town");
i18nc("belize.kgm", "Orange Walk District");
i18nc("belize.kgm", "Orange Walk Town");
i18nc("belize.kgm", "Stann Creek District");
i18nc("belize.kgm", "Dangriga");
i18nc("belize.kgm", "Toledo District");
i18nc("belize.kgm", "Punta Gorda");
i18nc("bhutan.kgm", "Bhutan");
i18nc("bhutan.kgm", "Districts");
i18nc("bhutan.kgm", "Frontier");
i18nc("bhutan.kgm", "Not Bhutan");
i18nc("bhutan.kgm", "Bumthang");
i18nc("bhutan.kgm", "Chukha");
i18nc("bhutan.kgm", "Dagana");
i18nc("bhutan.kgm", "Gasa");
i18nc("bhutan.kgm", "Haa");
i18nc("bhutan.kgm", "Lhuntse");
i18nc("bhutan.kgm", "Mongar");
i18nc("bhutan.kgm", "Paro");
i18nc("bhutan.kgm", "Pemagatshel");
i18nc("bhutan.kgm", "Punakha");
i18nc("bhutan.kgm", "Samdrup Jongkhar");
i18nc("bhutan.kgm", "Samtse");
i18nc("bhutan.kgm", "Sarpang");
i18nc("bhutan.kgm", "Thimphu");
i18nc("bhutan.kgm", "Trashigang");
i18nc("bhutan.kgm", "Trashiyangste");
i18nc("bhutan.kgm", "Trongsa");
i18nc("bhutan.kgm", "Tsirang");
i18nc("bhutan.kgm", "Wangdue Phodrang");
i18nc("bhutan.kgm", "Zhemgang");
i18nc("bolivia.kgm", "Bolivia");
i18nc("bolivia.kgm", "Departments");
i18nc("bolivia.kgm", "Frontier");
i18nc("bolivia.kgm", "Frontier");
i18nc("bolivia.kgm", "Water");
i18nc("bolivia.kgm", "Not Bolivia");
i18nc("bolivia.kgm", "Beni");
i18nc("bolivia.kgm", "Trinidad");
i18nc("bolivia.kgm", "Chuquisaca");
i18nc("bolivia.kgm", "Sucre");
i18nc("bolivia.kgm", "Cochabamba");
i18nc("bolivia.kgm", "Cochabamba");
i18nc("bolivia.kgm", "La Paz");
i18nc("bolivia.kgm", "La Paz");
i18nc("bolivia.kgm", "Oruro");
i18nc("bolivia.kgm", "Oruro");
i18nc("bolivia.kgm", "Pando");
i18nc("bolivia.kgm", "Cobija");
i18nc("bolivia.kgm", "Potosí");
i18nc("bolivia.kgm", "Potosí");
i18nc("bolivia.kgm", "Santa Cruz");
i18nc("bolivia.kgm", "Santa Cruz");
i18nc("bolivia.kgm", "Tarija");
i18nc("bolivia.kgm", "Tarija");
i18nc("bosnia-herzegovina.kgm", "Bosnia-Herzegovina");
i18nc("bosnia-herzegovina.kgm", "Cantons");
i18nc("bosnia-herzegovina.kgm", "Frontier");
i18nc("bosnia-herzegovina.kgm", "Water");
i18nc("bosnia-herzegovina.kgm", "Not Bosnia-Herzegovina");
i18nc("bosnia-herzegovina.kgm", "Brčko");
i18nc("bosnia-herzegovina.kgm", "Bosnian Podrinje");
i18nc("bosnia-herzegovina.kgm", "Central Bosnia");
i18nc("bosnia-herzegovina.kgm", "Herzegovina-Neretva");
i18nc("bosnia-herzegovina.kgm", "Posavina");
i18nc("bosnia-herzegovina.kgm", "Sarajevo");
i18nc("bosnia-herzegovina.kgm", "Tuzla");
i18nc("bosnia-herzegovina.kgm", "Una Sana");
i18nc("bosnia-herzegovina.kgm", "West Bosnia");
i18nc("bosnia-herzegovina.kgm", "West Herzegovina");
i18nc("bosnia-herzegovina.kgm", "Zenica-Doboj");
i18nc("bosnia-herzegovina.kgm", "Banja Luka");
i18nc("bosnia-herzegovina.kgm", "Doboj");
i18nc("bosnia-herzegovina.kgm", "Bijeljina");
i18nc("bosnia-herzegovina.kgm", "Vlasenica");
i18nc("bosnia-herzegovina.kgm", "Sarajevo-Romanija or Sokolac");
i18nc("bosnia-herzegovina.kgm", "Foča");
i18nc("bosnia-herzegovina.kgm", "Trebinje");
i18nc("botswana.kgm", "Botswana");
i18nc("botswana.kgm", "Districts");
i18nc("botswana.kgm", "Frontier");
i18nc("botswana.kgm", "Water");
i18nc("botswana.kgm", "Not Botswana");
i18nc("botswana.kgm", "Central");
i18nc("botswana.kgm", "Serowe");
i18nc("botswana.kgm", "Ghanzi");
i18nc("botswana.kgm", "Ghanzi");
i18nc("botswana.kgm", "Kgalagadi");
i18nc("botswana.kgm", "Tshabong");
i18nc("botswana.kgm", "Kgatleng");
i18nc("botswana.kgm", "Mochudi");
i18nc("botswana.kgm", "Kweneng");
i18nc("botswana.kgm", "Molepolole");
i18nc("botswana.kgm", "North-East");
i18nc("botswana.kgm", "Francistown");
i18nc("botswana.kgm", "North-West");
i18nc("botswana.kgm", "Maun");
i18nc("botswana.kgm", "South-East");
i18nc("botswana.kgm", "Gaborone");
i18nc("botswana.kgm", "Southern");
i18nc("botswana.kgm", "Kanye");
i18nc("brazil.kgm", "Brazil");
i18nc("brazil.kgm", "States");
i18nc("brazil.kgm", "Sergipe");
i18nc("brazil.kgm", "Aracaju");
i18nc("brazil.kgm", "Para");
i18nc("brazil.kgm", "Belem");
i18nc("brazil.kgm", "Minas Gerais");
i18nc("brazil.kgm", "Belo Horizonte");
i18nc("brazil.kgm", "Roraima");
i18nc("brazil.kgm", "Boa Vista");
i18nc("brazil.kgm", "Federal District");
i18nc("brazil.kgm", "Brasilia");
i18nc("brazil.kgm", "Mato Grosso do Sul");
i18nc("brazil.kgm", "Campo Grande");
i18nc("brazil.kgm", "Mato Grosso");
i18nc("brazil.kgm", "Cuiaba");
i18nc("brazil.kgm", "Parana");
i18nc("brazil.kgm", "Curitiba");
i18nc("brazil.kgm", "Santa Catarina");
i18nc("brazil.kgm", "Florianopolis");
i18nc("brazil.kgm", "Ceara");
i18nc("brazil.kgm", "Fortaleza");
i18nc("brazil.kgm", "Goias");
i18nc("brazil.kgm", "Goiânia");
i18nc("brazil.kgm", "Paraiba");
i18nc("brazil.kgm", "Joao Pessoa");
i18nc("brazil.kgm", "Amapa");
i18nc("brazil.kgm", "Macapa");
i18nc("brazil.kgm", "Alagoas");
i18nc("brazil.kgm", "Maceio");
i18nc("brazil.kgm", "Amazonas");
i18nc("brazil.kgm", "Manaus");
i18nc("brazil.kgm", "Rio Grande do Norte");
i18nc("brazil.kgm", "Natal");
i18nc("brazil.kgm", "Tocantins");
i18nc("brazil.kgm", "Palmas");
i18nc("brazil.kgm", "Rio Grande do Sul");
i18nc("brazil.kgm", "Porto Alegre");
i18nc("brazil.kgm", "Rondonia");
i18nc("brazil.kgm", "Porto Velho");
i18nc("brazil.kgm", "Pernambuco");
i18nc("brazil.kgm", "Recife");
i18nc("brazil.kgm", "Acre");
i18nc("brazil.kgm", "Rio Branco");
i18nc("brazil.kgm", "Rio de Janeiro State");
i18nc("brazil.kgm", "Rio de Janeiro");
i18nc("brazil.kgm", "Bahia");
i18nc("brazil.kgm", "Salvador");
i18nc("brazil.kgm", "Maranhao");
i18nc("brazil.kgm", "Sao Luis");
i18nc("brazil.kgm", "Sao Paulo State");
i18nc("brazil.kgm", "Sao Paulo (city)");
i18nc("brazil.kgm", "Piaui");
i18nc("brazil.kgm", "Teresina");
i18nc("brazil.kgm", "Espirito Santo");
i18nc("brazil.kgm", "Vitoria");
i18nc("brazil.kgm", "Frontier");
i18nc("brazil.kgm", "Out of Bounds");
i18nc("bulgaria.kgm", "Bulgaria");
i18nc("bulgaria.kgm", "Provinces");
i18nc("bulgaria.kgm", "Frontier");
i18nc("bulgaria.kgm", "Water");
i18nc("bulgaria.kgm", "Not Bulgaria");
i18nc("bulgaria.kgm", "Blagoevgrad");
i18nc("bulgaria.kgm", "Burgas");
i18nc("bulgaria.kgm", "Dobrich");
i18nc("bulgaria.kgm", "Gabrovo");
i18nc("bulgaria.kgm", "Haskovo");
i18nc("bulgaria.kgm", "Kardzhali");
i18nc("bulgaria.kgm", "Kyustendil");
i18nc("bulgaria.kgm", "Lovech");
i18nc("bulgaria.kgm", "Montana");
i18nc("bulgaria.kgm", "Pazardzhik");
i18nc("bulgaria.kgm", "Pernik");
i18nc("bulgaria.kgm", "Pleven");
i18nc("bulgaria.kgm", "Plovdiv");
i18nc("bulgaria.kgm", "Razgrad");
i18nc("bulgaria.kgm", "Ruse");
i18nc("bulgaria.kgm", "Shumen");
i18nc("bulgaria.kgm", "Silistra");
i18nc("bulgaria.kgm", "Sliven");
i18nc("bulgaria.kgm", "Smolyan");
i18nc("bulgaria.kgm", "Sofia Province");
i18nc("bulgaria.kgm", "Sofia City");
i18nc("bulgaria.kgm", "Stara Zagora");
i18nc("bulgaria.kgm", "Targovishte");
i18nc("bulgaria.kgm", "Veliko Tarnovo");
i18nc("bulgaria.kgm", "Varna");
i18nc("bulgaria.kgm", "Vidin");
i18nc("bulgaria.kgm", "Vratsa");
i18nc("bulgaria.kgm", "Yambol");
i18nc("burma.kgm", "Myanmar");
i18nc("burma.kgm", "States and divisions");
i18nc("burma.kgm", "Frontier");
i18nc("burma.kgm", "Water");
i18nc("burma.kgm", "Not Myanmar");
i18nc("burma.kgm", "Ayeyarwady");
i18nc("burma.kgm", "Pathein");
i18nc("burma.kgm", "Bago");
i18nc("burma.kgm", "Bago");
i18nc("burma.kgm", "Magway");
i18nc("burma.kgm", "Magwe");
i18nc("burma.kgm", "Mandalay");
i18nc("burma.kgm", "Mandalay");
i18nc("burma.kgm", "Sagaing");
i18nc("burma.kgm", "Sagaing");
i18nc("burma.kgm", "Tanintharyi");
i18nc("burma.kgm", "Dawei");
i18nc("burma.kgm", "Yangon");
i18nc("burma.kgm", "Yangon (former Rangoon)");
i18nc("burma.kgm", "Chin");
i18nc("burma.kgm", "Hakha");
i18nc("burma.kgm", "Kachin");
i18nc("burma.kgm", "Myitkyina");
i18nc("burma.kgm", "Kayin");
i18nc("burma.kgm", "Hpa-an");
i18nc("burma.kgm", "Kayah");
i18nc("burma.kgm", "Loikaw");
i18nc("burma.kgm", "Mon");
i18nc("burma.kgm", "Mawlamyine");
i18nc("burma.kgm", "Rakhine");
i18nc("burma.kgm", "Sittwe");
i18nc("burma.kgm", "Shan");
i18nc("burma.kgm", "Taunggyi");
i18nc("cameroon_departments.kgm", "Cameroon (Departments)");
i18nc("cameroon_departments.kgm", "Departments");
i18nc("cameroon_departments.kgm", "Frontier");
i18nc("cameroon_departments.kgm", "Water");
i18nc("cameroon_departments.kgm", "Not Cameroon (Departments)");
i18nc("cameroon_departments.kgm", "Djérem");
i18nc("cameroon_departments.kgm", "Tibati");
i18nc("cameroon_departments.kgm", "Faro-et-Déo");
i18nc("cameroon_departments.kgm", "Tignère");
i18nc("cameroon_departments.kgm", "Mayo-Banyo");
i18nc("cameroon_departments.kgm", "Banyo");
i18nc("cameroon_departments.kgm", "Mbéré");
i18nc("cameroon_departments.kgm", "Meiganga");
i18nc("cameroon_departments.kgm", "Vina");
i18nc("cameroon_departments.kgm", "Ngaoundéré");
i18nc("cameroon_departments.kgm", "Haute-Sanaga");
i18nc("cameroon_departments.kgm", "Nanga-Eboko");
i18nc("cameroon_departments.kgm", "Lekié");
i18nc("cameroon_departments.kgm", "Monatele");
i18nc("cameroon_departments.kgm", "Mbam-et-Inoubou");
i18nc("cameroon_departments.kgm", "Bafia");
i18nc("cameroon_departments.kgm", "Mbam-et-Kim");
i18nc("cameroon_departments.kgm", "Ntui");
i18nc("cameroon_departments.kgm", "Méfou-et-Afamba");
i18nc("cameroon_departments.kgm", "Mfou");
i18nc("cameroon_departments.kgm", "Méfou-et-Akono");
i18nc("cameroon_departments.kgm", "Ngoumou");
i18nc("cameroon_departments.kgm", "Mfoundi");
i18nc("cameroon_departments.kgm", "Yaoundé");
i18nc("cameroon_departments.kgm", "Nyong-et-Kellé");
i18nc("cameroon_departments.kgm", "Éséka");
i18nc("cameroon_departments.kgm", "Nyong-et-Mfoumou");
i18nc("cameroon_departments.kgm", "Akonolinga");
i18nc("cameroon_departments.kgm", "Nyong-et-So'o");
i18nc("cameroon_departments.kgm", "Mbalmayo");
i18nc("cameroon_departments.kgm", "Boumba-et-Ngoko");
i18nc("cameroon_departments.kgm", "Yokadouma");
i18nc("cameroon_departments.kgm", "Haut-Nyong");
i18nc("cameroon_departments.kgm", "Abong-Mbang");
i18nc("cameroon_departments.kgm", "Kadey");
i18nc("cameroon_departments.kgm", "Batouri");
i18nc("cameroon_departments.kgm", "Lom-et-Djérem");
i18nc("cameroon_departments.kgm", "Bertoua");
i18nc("cameroon_departments.kgm", "Diamaré");
i18nc("cameroon_departments.kgm", "Maroua");
i18nc("cameroon_departments.kgm", "Logone-et-Chari");
i18nc("cameroon_departments.kgm", "Kousséri");
i18nc("cameroon_departments.kgm", "Mayo-Danay");
i18nc("cameroon_departments.kgm", "Yagoua");
i18nc("cameroon_departments.kgm", "Mayo-Kani");
i18nc("cameroon_departments.kgm", "Kaélé");
i18nc("cameroon_departments.kgm", "Mayo-Sava");
i18nc("cameroon_departments.kgm", "Mora");
i18nc("cameroon_departments.kgm", "Mayo-Tsanaga");
i18nc("cameroon_departments.kgm", "Mokolo");
i18nc("cameroon_departments.kgm", "Moungo");
i18nc("cameroon_departments.kgm", "Nkongsamba");
i18nc("cameroon_departments.kgm", "Nkam");
i18nc("cameroon_departments.kgm", "Yabassi");
i18nc("cameroon_departments.kgm", "Sanaga-Maritime");
i18nc("cameroon_departments.kgm", "Édéa");
i18nc("cameroon_departments.kgm", "Wouri");
i18nc("cameroon_departments.kgm", "Douala");
i18nc("cameroon_departments.kgm", "Bénoué");
i18nc("cameroon_departments.kgm", "Garoua");
i18nc("cameroon_departments.kgm", "Faro");
i18nc("cameroon_departments.kgm", "Poli");
i18nc("cameroon_departments.kgm", "Mayo-Louti");
i18nc("cameroon_departments.kgm", "Guider");
i18nc("cameroon_departments.kgm", "Mayo-Rey");
i18nc("cameroon_departments.kgm", "Tchollire");
i18nc("cameroon_departments.kgm", "Boyo");
i18nc("cameroon_departments.kgm", "Fundong");
i18nc("cameroon_departments.kgm", "Bui");
i18nc("cameroon_departments.kgm", "Kumbo");
i18nc("cameroon_departments.kgm", "Donga-Mantung");
i18nc("cameroon_departments.kgm", "Nkambé");
i18nc("cameroon_departments.kgm", "Menchum");
i18nc("cameroon_departments.kgm", "Wum");
i18nc("cameroon_departments.kgm", "Mezam");
i18nc("cameroon_departments.kgm", "Bamenda");
i18nc("cameroon_departments.kgm", "Momo");
i18nc("cameroon_departments.kgm", "Mbengwi");
i18nc("cameroon_departments.kgm", "Ngo-Ketunjia");
i18nc("cameroon_departments.kgm", "Ndop");
i18nc("cameroon_departments.kgm", "Bamboutos");
i18nc("cameroon_departments.kgm", "Mbouda");
i18nc("cameroon_departments.kgm", "Haut-Nkam");
i18nc("cameroon_departments.kgm", "Bafang");
i18nc("cameroon_departments.kgm", "Hauts-Plateaux");
i18nc("cameroon_departments.kgm", "Baham");
i18nc("cameroon_departments.kgm", "Koung-Khi");
i18nc("cameroon_departments.kgm", "Bandjoun");
i18nc("cameroon_departments.kgm", "Menoua");
i18nc("cameroon_departments.kgm", "Dschang");
i18nc("cameroon_departments.kgm", "Mifi");
i18nc("cameroon_departments.kgm", "Bafoussam");
i18nc("cameroon_departments.kgm", "Ndé");
i18nc("cameroon_departments.kgm", "Bangangté");
i18nc("cameroon_departments.kgm", "Noun");
i18nc("cameroon_departments.kgm", "Foumban");
i18nc("cameroon_departments.kgm", "Dja-et-Lobo");
i18nc("cameroon_departments.kgm", "Sangmélima");
i18nc("cameroon_departments.kgm", "Mvila");
i18nc("cameroon_departments.kgm", "Ebolowa");
i18nc("cameroon_departments.kgm", "Océan");
i18nc("cameroon_departments.kgm", "Kribi");
i18nc("cameroon_departments.kgm", "Vallée-du-Ntem");
i18nc("cameroon_departments.kgm", "Ambam");
i18nc("cameroon_departments.kgm", "Fako");
i18nc("cameroon_departments.kgm", "Limbé");
i18nc("cameroon_departments.kgm", "Koupé-Manengouba");
i18nc("cameroon_departments.kgm", "Bangem");
i18nc("cameroon_departments.kgm", "Lebialem");
i18nc("cameroon_departments.kgm", "Menji");
i18nc("cameroon_departments.kgm", "Manyu");
i18nc("cameroon_departments.kgm", "Mamfé");
i18nc("cameroon_departments.kgm", "Meme");
i18nc("cameroon_departments.kgm", "Kumba");
i18nc("cameroon_departments.kgm", "Ndian");
i18nc("cameroon_departments.kgm", "Mudemba");
i18nc("cameroon_provinces.kgm", "Cameroon (Provinces)");
i18nc("cameroon_provinces.kgm", "Provinces");
i18nc("cameroon_provinces.kgm", "Frontier");
i18nc("cameroon_provinces.kgm", "Water");
i18nc("cameroon_provinces.kgm", "Not Cameroon (Provinces)");
i18nc("cameroon_provinces.kgm", "Adamawa");
i18nc("cameroon_provinces.kgm", "Ngaoundéré");
i18nc("cameroon_provinces.kgm", "Centre");
i18nc("cameroon_provinces.kgm", "Yaoundé");
i18nc("cameroon_provinces.kgm", "East");
i18nc("cameroon_provinces.kgm", "Bertoua");
i18nc("cameroon_provinces.kgm", "Far North");
i18nc("cameroon_provinces.kgm", "Maroua");
i18nc("cameroon_provinces.kgm", "Littoral");
i18nc("cameroon_provinces.kgm", "Douala");
i18nc("cameroon_provinces.kgm", "North");
i18nc("cameroon_provinces.kgm", "Garoua");
i18nc("cameroon_provinces.kgm", "Northwest");
i18nc("cameroon_provinces.kgm", "Bamenda");
i18nc("cameroon_provinces.kgm", "South");
i18nc("cameroon_provinces.kgm", "Ebolowa");
i18nc("cameroon_provinces.kgm", "Southwest");
i18nc("cameroon_provinces.kgm", "Buea");
i18nc("cameroon_provinces.kgm", "West");
i18nc("cameroon_provinces.kgm", "Bafoussam");
i18nc("canada.kgm", "Canada");
i18nc("canada.kgm", "Provinces and Territories");
i18nc("canada.kgm", "Out of Bounds");
i18nc("canada.kgm", "Frontier");
i18nc("canada.kgm", "Prince Edward Island");
i18nc("canada.kgm", "Charlottetown");
i18nc("canada.kgm", "British Columbia");
i18nc("canada.kgm", "Victoria");
i18nc("canada.kgm", "Ontario");
i18nc("canada.kgm", "Toronto");
i18nc("canada.kgm", "Newfoundland");
i18nc("canada.kgm", "St John's");
i18nc("canada.kgm", "Nunavut");
i18nc("canada.kgm", "Iqaluit");
i18nc("canada.kgm", "Alberta");
i18nc("canada.kgm", "Edmonton");
i18nc("canada.kgm", "North West Territories");
i18nc("canada.kgm", "Yellowknife");
i18nc("canada.kgm", "Quebec");
i18nc("canada.kgm", "Quebec City");
i18nc("canada.kgm", "New Brunswick");
i18nc("canada.kgm", "Fredericton");
i18nc("canada.kgm", "Manitoba");
i18nc("canada.kgm", "Winnipeg");
i18nc("canada.kgm", "Nova Scotia");
i18nc("canada.kgm", "Halifax");
i18nc("canada.kgm", "Yukon Territory");
i18nc("canada.kgm", "Whitehorse");
i18nc("canada.kgm", "Saskatchewan");
i18nc("canada.kgm", "Regina");
i18nc("caribbean.kgm", "Caribbean");
i18nc("caribbean.kgm", "Countries");
i18nc("caribbean.kgm", "Frontier");
i18nc("caribbean.kgm", "Water");
i18nc("caribbean.kgm", "Not Caribbean");
i18nc("caribbean.kgm", "Bahamas");
i18nc("caribbean.kgm", "Nassau");
i18nc("caribbean.kgm", "Turks and Caicos Islands (UK)");
i18nc("caribbean.kgm", "Cockburn Town");
i18nc("caribbean.kgm", "Cuba");
i18nc("caribbean.kgm", "Havana");
i18nc("caribbean.kgm", "Haiti");
i18nc("caribbean.kgm", "Port-au-Prince");
i18nc("caribbean.kgm", "Dominican Republic");
i18nc("caribbean.kgm", "Santo Domingo");
i18nc("caribbean.kgm", "Puerto Rico (USA)");
i18nc("caribbean.kgm", "San Juan");
i18nc("caribbean.kgm", "U.S Virgin Islands (USA)");
i18nc("caribbean.kgm", "Charlotte Amalie");
i18nc("caribbean.kgm", "British Virgin Islands (UK)");
i18nc("caribbean.kgm", "Road Town");
i18nc("caribbean.kgm", "Anguilla (UK)");
i18nc("caribbean.kgm", "The Valley");
i18nc("caribbean.kgm", "Saint Martin (France)");
i18nc("caribbean.kgm", "Marigot");
i18nc("caribbean.kgm", "Saint Barthelemy (France)");
i18nc("caribbean.kgm", "Gustavia");
i18nc("caribbean.kgm", "Antigua and Barbuda");
i18nc("caribbean.kgm", "Saint John's");
i18nc("caribbean.kgm", "Saint Kitts and Nevis");
i18nc("caribbean.kgm", "Basseterre");
i18nc("caribbean.kgm", "Montserrat (UK)");
i18nc("caribbean.kgm", "Plymouth");
i18nc("caribbean.kgm", "Guadeloupe (France)");
i18nc("caribbean.kgm", "Basse-Terre");
i18nc("caribbean.kgm", "Dominica");
i18nc("caribbean.kgm", "Roseau");
i18nc("caribbean.kgm", "Martinique (France)");
i18nc("caribbean.kgm", "Fort de France");
i18nc("caribbean.kgm", "Saint Lucia");
i18nc("caribbean.kgm", "Castries");
i18nc("caribbean.kgm", "Barbados");
i18nc("caribbean.kgm", "Bridgetown");
i18nc("caribbean.kgm", "Saint Vincent and the Grenadines");
i18nc("caribbean.kgm", "Kingstown");
i18nc("caribbean.kgm", "Grenada");
i18nc("caribbean.kgm", "Saint George's");
i18nc("caribbean.kgm", "Trinidad and Tobago");
i18nc("caribbean.kgm", "Port of Spain");
i18nc("caribbean.kgm", "Netherlands Antilles (NL)");
i18nc("caribbean.kgm", "Willemstad");
i18nc("caribbean.kgm", "Aruba (NL)");
i18nc("caribbean.kgm", "Oranjestad");
i18nc("caribbean.kgm", "Jamaica");
i18nc("caribbean.kgm", "Kingston");
i18nc("caribbean.kgm", "Cayman Islands (UK)");
i18nc("caribbean.kgm", "George Town");
i18nc("catalonia_comarques.kgm", "Catalonia (Comarques)");
i18nc("catalonia_comarques.kgm", "Comarques");
i18nc("catalonia_comarques.kgm", "Frontier");
i18nc("catalonia_comarques.kgm", "Frontier");
i18nc("catalonia_comarques.kgm", "Outside Catalonia");
i18nc("catalonia_comarques.kgm", "Alt Camp");
i18nc("catalonia_comarques.kgm", "Valls");
i18nc("catalonia_comarques.kgm", "Alt Empordà");
i18nc("catalonia_comarques.kgm", "Figueres");
i18nc("catalonia_comarques.kgm", "Alt Penedès");
i18nc("catalonia_comarques.kgm", "Vilafranca del Penedès");
i18nc("catalonia_comarques.kgm", "Alt Urgell");
i18nc("catalonia_comarques.kgm", "La Seu d'Urgell");
i18nc("catalonia_comarques.kgm", "Alta Ribagorça");
i18nc("catalonia_comarques.kgm", "Pont de Suert");
i18nc("catalonia_comarques.kgm", "Anoia");
i18nc("catalonia_comarques.kgm", "Igualada");
i18nc("catalonia_comarques.kgm", "Bages");
i18nc("catalonia_comarques.kgm", "Manresa");
i18nc("catalonia_comarques.kgm", "Baix Camp");
i18nc("catalonia_comarques.kgm", "Reus");
i18nc("catalonia_comarques.kgm", "Baix Ebre");
i18nc("catalonia_comarques.kgm", "Tortosa");
i18nc("catalonia_comarques.kgm", "Baix Empordà");
i18nc("catalonia_comarques.kgm", "La Bisbal d'Empordà");
i18nc("catalonia_comarques.kgm", "Baix Llobregat");
i18nc("catalonia_comarques.kgm", "Sant Feliu de Llobregat");
i18nc("catalonia_comarques.kgm", "Baix Penedès");
i18nc("catalonia_comarques.kgm", "El Vendrell");
i18nc("catalonia_comarques.kgm", "Barcelonès");
i18nc("catalonia_comarques.kgm", "Barcelona");
i18nc("catalonia_comarques.kgm", "Berguedà");
i18nc("catalonia_comarques.kgm", "Berga");
i18nc("catalonia_comarques.kgm", "Cerdanya");
i18nc("catalonia_comarques.kgm", "Puigcerdà");
i18nc("catalonia_comarques.kgm", "Conca de Barberà");
i18nc("catalonia_comarques.kgm", "Montblanc");
i18nc("catalonia_comarques.kgm", "Garraf");
i18nc("catalonia_comarques.kgm", "Vilanova i la Geltrú");
i18nc("catalonia_comarques.kgm", "Garrigues");
i18nc("catalonia_comarques.kgm", "Les Borges Blanques");
i18nc("catalonia_comarques.kgm", "Garrotxa");
i18nc("catalonia_comarques.kgm", "Olot");
i18nc("catalonia_comarques.kgm", "Gironès");
i18nc("catalonia_comarques.kgm", "Girona");
i18nc("catalonia_comarques.kgm", "Maresme");
i18nc("catalonia_comarques.kgm", "Mataró");
i18nc("catalonia_comarques.kgm", "Montsià");
i18nc("catalonia_comarques.kgm", "Amposta");
i18nc("catalonia_comarques.kgm", "Noguera");
i18nc("catalonia_comarques.kgm", "Balaguer");
i18nc("catalonia_comarques.kgm", "Osona");
i18nc("catalonia_comarques.kgm", "Vic");
i18nc("catalonia_comarques.kgm", "Pallars Jussà");
i18nc("catalonia_comarques.kgm", "Tremp");
i18nc("catalonia_comarques.kgm", "Pallars Sobirà");
i18nc("catalonia_comarques.kgm", "Sort");
i18nc("catalonia_comarques.kgm", "Pla de l'Estany");
i18nc("catalonia_comarques.kgm", "Banyoles");
i18nc("catalonia_comarques.kgm", "Pla d'Urgell");
i18nc("catalonia_comarques.kgm", "Mollerussa");
i18nc("catalonia_comarques.kgm", "Priorat");
i18nc("catalonia_comarques.kgm", "Falset");
i18nc("catalonia_comarques.kgm", "Ribera d'Ebre");
i18nc("catalonia_comarques.kgm", "Móra d'Ebre");
i18nc("catalonia_comarques.kgm", "Ripollès");
i18nc("catalonia_comarques.kgm", "Ripoll");
i18nc("catalonia_comarques.kgm", "Segarra");
i18nc("catalonia_comarques.kgm", "Cervera");
i18nc("catalonia_comarques.kgm", "Segrià");
i18nc("catalonia_comarques.kgm", "Lleida");
i18nc("catalonia_comarques.kgm", "Selva");
i18nc("catalonia_comarques.kgm", "Santa Coloma de Farners");
i18nc("catalonia_comarques.kgm", "Solsonès");
i18nc("catalonia_comarques.kgm", "Solsona");
i18nc("catalonia_comarques.kgm", "Tarragonès");
i18nc("catalonia_comarques.kgm", "Tarragona");
i18nc("catalonia_comarques.kgm", "Terra Alta");
i18nc("catalonia_comarques.kgm", "Gandesa");
i18nc("catalonia_comarques.kgm", "Urgell");
i18nc("catalonia_comarques.kgm", "Tàrrega");
i18nc("catalonia_comarques.kgm", "Vall d'Aran");
i18nc("catalonia_comarques.kgm", "Vielha e Mijaran");
i18nc("catalonia_comarques.kgm", "Vallès Occidental");
i18nc("catalonia_comarques.kgm", "Sabadell and Terrassa");
i18nc("catalonia_comarques.kgm", "Vallès Oriental");
i18nc("catalonia_comarques.kgm", "Granollers");
i18nc("chhattisgarh.kgm", "Chhattisgarh");
i18nc("chhattisgarh.kgm", "District");
i18nc("chhattisgarh.kgm", "Not Chhattisgarh");
i18nc("chhattisgarh.kgm", "Frontier");
i18nc("chhattisgarh.kgm", "Surguja");
i18nc("chhattisgarh.kgm", "Ambikapur");
i18nc("chhattisgarh.kgm", "Koriya");
i18nc("chhattisgarh.kgm", "Koriya");
i18nc("chhattisgarh.kgm", "Jashpur");
i18nc("chhattisgarh.kgm", "Jashpur");
i18nc("chhattisgarh.kgm", "Korba");
i18nc("chhattisgarh.kgm", "Korba");
i18nc("chhattisgarh.kgm", "Bilaspur");
i18nc("chhattisgarh.kgm", "Bilaspur");
i18nc("chhattisgarh.kgm", "Raigarh");
i18nc("chhattisgarh.kgm", "Raigarh");
i18nc("chhattisgarh.kgm", "Kabirdham");
i18nc("chhattisgarh.kgm", "Kawardha");
i18nc("chhattisgarh.kgm", "Janjgir-Champa");
i18nc("chhattisgarh.kgm", "Janjgir");
i18nc("chhattisgarh.kgm", "Durg");
i18nc("chhattisgarh.kgm", "Durg");
i18nc("chhattisgarh.kgm", "Raipur");
i18nc("chhattisgarh.kgm", "Raipur");
i18nc("chhattisgarh.kgm", "Rajnandgaon");
i18nc("chhattisgarh.kgm", "Rajnandgaon");
i18nc("chhattisgarh.kgm", "Mahasamund");
i18nc("chhattisgarh.kgm", "Mahasamund");
i18nc("chhattisgarh.kgm", "Kanker");
i18nc("chhattisgarh.kgm", "Kanker");
i18nc("chhattisgarh.kgm", "Bastar");
i18nc("chhattisgarh.kgm", "Jagdalpur");
i18nc("chhattisgarh.kgm", "Dantewada");
i18nc("chhattisgarh.kgm", "Dantewada");
i18nc("chhattisgarh.kgm", "Dhamtari");
i18nc("chhattisgarh.kgm", "Dhamtari");
i18nc("chile.kgm", "Chile");
i18nc("chile.kgm", "Regions");
i18nc("chile.kgm", "Frontier");
i18nc("chile.kgm", "Water");
i18nc("chile.kgm", "Not Chile");
i18nc("chile.kgm", "Tarapacá");
i18nc("chile.kgm", "Iquique");
i18nc("chile.kgm", "Antofagasta");
i18nc("chile.kgm", "Antofagasta");
i18nc("chile.kgm", "Atacama");
i18nc("chile.kgm", "Copiapo");
i18nc("chile.kgm", "Coquimbo");
i18nc("chile.kgm", "La Serena");
i18nc("chile.kgm", "Valparaíso");
i18nc("chile.kgm", "Valparaiso");
i18nc("chile.kgm", "O'Higgins");
i18nc("chile.kgm", "Rancagua");
i18nc("chile.kgm", "Maule");
i18nc("chile.kgm", "Talca");
i18nc("chile.kgm", "Bío-Bío");
i18nc("chile.kgm", "Concepción");
i18nc("chile.kgm", "Araucanía");
i18nc("chile.kgm", "Temuco");
i18nc("chile.kgm", "Los Lagos");
i18nc("chile.kgm", "Puerto Montt");
i18nc("chile.kgm", "Aysen");
i18nc("chile.kgm", "Coyhaique");
i18nc("chile.kgm", "Magallanes y la Antártica Chilena");
i18nc("chile.kgm", "Punta Arenas");
i18nc("chile.kgm", "Santiago Metropolitan Region");
i18nc("chile.kgm", "Santiago");
i18nc("chile.kgm", "Los Rios");
i18nc("chile.kgm", "Valdivia");
i18nc("chile.kgm", "Arica and Parinacota");
i18nc("chile.kgm", "Arica");
i18nc("china.kgm", "China");
i18nc("china.kgm", "Provinces");
i18nc("china.kgm", "Frontier");
i18nc("china.kgm", "Water");
i18nc("china.kgm", "Coast");
i18nc("china.kgm", "Russia");
i18nc("china.kgm", "Japan");
i18nc("china.kgm", "Mongolia");
i18nc("china.kgm", "North Korea");
i18nc("china.kgm", "South Korea");
i18nc("china.kgm", "Kazakhstan");
i18nc("china.kgm", "Kyrgyzstan");
i18nc("china.kgm", "Tajikistan");
i18nc("china.kgm", "Afghanistan");
i18nc("china.kgm", "Pakistan");
i18nc("china.kgm", "India");
i18nc("china.kgm", "Bhutan");
i18nc("china.kgm", "Bangladesh");
i18nc("china.kgm", "Myanmar");
i18nc("china.kgm", "Thailand");
i18nc("china.kgm", "Taiwan");
i18nc("china.kgm", "Vietnam");
i18nc("china.kgm", "Laos");
i18nc("china.kgm", "Nepal");
i18nc("china.kgm", "Anhui");
i18nc("china.kgm", "Hefei");
i18nc("china.kgm", "Beijing");
i18nc("china.kgm", "Chongqing");
i18nc("china.kgm", "Fujian");
i18nc("china.kgm", "Fuzhou");
i18nc("china.kgm", "Gansu");
i18nc("china.kgm", "Lanzhou");
i18nc("china.kgm", "Guangdong");
i18nc("china.kgm", "Guangzhou");
i18nc("china.kgm", "Guangxi Zhuang");
i18nc("china.kgm", "Nanning");
i18nc("china.kgm", "Guizhou");
i18nc("china.kgm", "Guiyang");
i18nc("china.kgm", "Hainan");
i18nc("china.kgm", "Haikou");
i18nc("china.kgm", "Hebei");
i18nc("china.kgm", "Shijiazhuang");
i18nc("china.kgm", "Heilongjiang");
i18nc("china.kgm", "Harbin");
i18nc("china.kgm", "Henan");
i18nc("china.kgm", "Zhengzhou");
i18nc("china.kgm", "Hubei");
i18nc("china.kgm", "Wuhan");
i18nc("china.kgm", "Hunan");
i18nc("china.kgm", "Changsha");
i18nc("china.kgm", "Jiangsu");
i18nc("china.kgm", "Nanjing");
i18nc("china.kgm", "Jiangxi");
i18nc("china.kgm", "Nanchang");
i18nc("china.kgm", "Jilin");
i18nc("china.kgm", "Changchun");
i18nc("china.kgm", "Liaoning");
i18nc("china.kgm", "Shenyang");
i18nc("china.kgm", "Nei Mongol");
i18nc("china.kgm", "Hohhot");
i18nc("china.kgm", "Ningxia Hui");
i18nc("china.kgm", "Yinchuan");
i18nc("china.kgm", "Qinghai");
i18nc("china.kgm", "Xining");
i18nc("china.kgm", "Shanxi");
i18nc("china.kgm", "Taiyuan");
i18nc("china.kgm", "Shandong");
i18nc("china.kgm", "Jinan");
i18nc("china.kgm", "Shanghai");
i18nc("china.kgm", "Shaanxi");
i18nc("china.kgm", "Xian");
i18nc("china.kgm", "Sichuan");
i18nc("china.kgm", "Chengdu");
i18nc("china.kgm", "Tianjin");
i18nc("china.kgm", "Xinjiang Uygur");
i18nc("china.kgm", "Urumqi");
i18nc("china.kgm", "Xizang");
i18nc("china.kgm", "Lhasa");
i18nc("china.kgm", "Yunnan");
i18nc("china.kgm", "Kunming");
i18nc("china.kgm", "Zhejiang");
i18nc("china.kgm", "Hangzhou");
i18nc("china.kgm", "Hong Kong");
i18nc("china.kgm", "Macao");
i18nc("colombia.kgm", "Colombia");
i18nc("colombia.kgm", "Departments");
i18nc("colombia.kgm", "Amazonas");
i18nc("colombia.kgm", "Leticia");
i18nc("colombia.kgm", "Antioquia");
i18nc("colombia.kgm", "Medellin");
i18nc("colombia.kgm", "Arauca");
i18nc("colombia.kgm", "Arauca");
i18nc("colombia.kgm", "Atlantico");
i18nc("colombia.kgm", "Barranquilla");
i18nc("colombia.kgm", "Bolivar");
i18nc("colombia.kgm", "Cartagena");
i18nc("colombia.kgm", "Boyaca");
i18nc("colombia.kgm", "Tunja");
i18nc("colombia.kgm", "Caldas");
i18nc("colombia.kgm", "Manizales");
i18nc("colombia.kgm", "Caqueta");
i18nc("colombia.kgm", "Florencia");
i18nc("colombia.kgm", "Casanare");
i18nc("colombia.kgm", "Yopal");
i18nc("colombia.kgm", "Cauca");
i18nc("colombia.kgm", "Popayan");
i18nc("colombia.kgm", "Cesar");
i18nc("colombia.kgm", "Valledupar");
i18nc("colombia.kgm", "Choco");
i18nc("colombia.kgm", "Quibdo");
i18nc("colombia.kgm", "Cordoba");
i18nc("colombia.kgm", "Monteria");
i18nc("colombia.kgm", "Cundinamarca");
i18nc("colombia.kgm", "Bogota");
i18nc("colombia.kgm", "Capital District");
i18nc("colombia.kgm", "Bogota");
i18nc("colombia.kgm", "Guainia");
i18nc("colombia.kgm", "Inírida");
i18nc("colombia.kgm", "Guaviare");
i18nc("colombia.kgm", "San Jose");
i18nc("colombia.kgm", "Huila");
i18nc("colombia.kgm", "Neiva");
i18nc("colombia.kgm", "La Guajira");
i18nc("colombia.kgm", "Riohacha");
i18nc("colombia.kgm", "Magdalena");
i18nc("colombia.kgm", "Santa Marta");
i18nc("colombia.kgm", "Meta");
i18nc("colombia.kgm", "Villavicencio");
i18nc("colombia.kgm", "Narinyo");
i18nc("colombia.kgm", "Pasto");
i18nc("colombia.kgm", "Norte de Santander");
i18nc("colombia.kgm", "Cucuta");
i18nc("colombia.kgm", "Putumayo");
i18nc("colombia.kgm", "Mocoa");
i18nc("colombia.kgm", "Quindio");
i18nc("colombia.kgm", "Armenia");
i18nc("colombia.kgm", "Risaralda");
i18nc("colombia.kgm", "Pereira");
i18nc("colombia.kgm", "St Andrew and Providence");
i18nc("colombia.kgm", "St Andrew");
i18nc("colombia.kgm", "Santander");
i18nc("colombia.kgm", "Bucaramanga");
i18nc("colombia.kgm", "Sucre");
i18nc("colombia.kgm", "Sincelejo");
i18nc("colombia.kgm", "Tolima");
i18nc("colombia.kgm", "Ibague");
i18nc("colombia.kgm", "Valle del Cauca");
i18nc("colombia.kgm", "Cali");
i18nc("colombia.kgm", "Vaupes");
i18nc("colombia.kgm", "Mitu");
i18nc("colombia.kgm", "Vichada");
i18nc("colombia.kgm", "Puerto Carrenyo");
i18nc("colombia.kgm", "Ocean");
i18nc("colombia.kgm", "Border");
i18nc("colombia.kgm", "Frontier");
i18nc("colombia.kgm", "Other Countries");
i18nc("costa_rica.kgm", "Costa Rica");
i18nc("costa_rica.kgm", "Provinces");
i18nc("costa_rica.kgm", "Frontier");
i18nc("costa_rica.kgm", "Frontier");
i18nc("costa_rica.kgm", "Water");
i18nc("costa_rica.kgm", "Not Costa Rica");
i18nc("costa_rica.kgm", "Alajuela");
i18nc("costa_rica.kgm", "Alajuela");
i18nc("costa_rica.kgm", "Cartago");
i18nc("costa_rica.kgm", "Cartago");
i18nc("costa_rica.kgm", "Guanacaste");
i18nc("costa_rica.kgm", "Liberia");
i18nc("costa_rica.kgm", "Heredia");
i18nc("costa_rica.kgm", "Heredia");
i18nc("costa_rica.kgm", "Limón");
i18nc("costa_rica.kgm", "Limón");
i18nc("costa_rica.kgm", "Puntarenas");
i18nc("costa_rica.kgm", "Puntarenas");
i18nc("costa_rica.kgm", "San José");
i18nc("costa_rica.kgm", "San José");
i18nc("cuba.kgm", "Cuba");
i18nc("cuba.kgm", "Provinces");
i18nc("cuba.kgm", "Frontier");
i18nc("cuba.kgm", "Frontier");
i18nc("cuba.kgm", "Not Cuba");
i18nc("cuba.kgm", "Isla de la Juventud");
i18nc("cuba.kgm", "Nueva Gerona");
i18nc("cuba.kgm", "Pinar del Río");
i18nc("cuba.kgm", "La Habana");
i18nc("cuba.kgm", "Ciudad de La Habana");
i18nc("cuba.kgm", "Matanzas");
i18nc("cuba.kgm", "Cienfuegos");
i18nc("cuba.kgm", "Villa Clara");
i18nc("cuba.kgm", "Santa Clara");
i18nc("cuba.kgm", "Sancti Spíritus");
i18nc("cuba.kgm", "Ciego de Ávila");
i18nc("cuba.kgm", "Camagüey");
i18nc("cuba.kgm", "Las Tunas");
i18nc("cuba.kgm", "Victoria de Las Tunas");
i18nc("cuba.kgm", "Granma");
i18nc("cuba.kgm", "Bayamo");
i18nc("cuba.kgm", "Holguín");
i18nc("cuba.kgm", "Santiago de Cuba");
i18nc("cuba.kgm", "Guantánamo");
i18nc("cyprus.kgm", "Cyprus");
i18nc("cyprus.kgm", "Districts");
i18nc("cyprus.kgm", "Frontier");
i18nc("cyprus.kgm", "Not Cyprus");
i18nc("cyprus.kgm", "Paphos");
i18nc("cyprus.kgm", "Limassol");
i18nc("cyprus.kgm", "Larnaca");
i18nc("cyprus.kgm", "Famagusta");
i18nc("cyprus.kgm", "Kyrenia");
i18nc("cyprus.kgm", "Nicosia");
i18nc("czech.kgm", "Czech Republic");
i18nc("czech.kgm", "Regions");
i18nc("czech.kgm", "Frontier");
i18nc("czech.kgm", "Frontier");
i18nc("czech.kgm", "Not Czech");
i18nc("czech.kgm", "Prague");
i18nc("czech.kgm", "Central Bohemia");
i18nc("czech.kgm", "Prague");
i18nc("czech.kgm", "South Bohemia");
i18nc("czech.kgm", "České Budějovice");
i18nc("czech.kgm", "Plzeň");
i18nc("czech.kgm", "Plzeň");
i18nc("czech.kgm", "Karlovy Vary");
i18nc("czech.kgm", "Karlovy Vary");
i18nc("czech.kgm", "Ústí nad Labem");
i18nc("czech.kgm", "Ústí nad Labem");
i18nc("czech.kgm", "Liberec");
i18nc("czech.kgm", "Liberec");
i18nc("czech.kgm", "Hradec Králové");
i18nc("czech.kgm", "Hradec Králové");
i18nc("czech.kgm", "Pardubice");
i18nc("czech.kgm", "Pardubice");
i18nc("czech.kgm", "Olomouc");
i18nc("czech.kgm", "Olomouc");
i18nc("czech.kgm", "Moravia-Silesia");
i18nc("czech.kgm", "Ostrava");
i18nc("czech.kgm", "South Moravia");
i18nc("czech.kgm", "Brno");
i18nc("czech.kgm", "Zlín");
i18nc("czech.kgm", "Zlín");
i18nc("czech.kgm", "Vysočina");
i18nc("czech.kgm", "Jihlava");
i18nc("denmark_counties.kgm", "Denmark (Counties) (1970-2006)");
i18nc("denmark_counties.kgm", "Counties");
i18nc("denmark_counties.kgm", "Frontier");
i18nc("denmark_counties.kgm", "Not Denmark (Counties)");
i18nc("denmark_counties.kgm", "Water");
i18nc("denmark_counties.kgm", "Copenhagen (city)");
i18nc("denmark_counties.kgm", "Frederiksberg (city)");
i18nc("denmark_counties.kgm", "Copenhagen (county)");
i18nc("denmark_counties.kgm", "Glostrup");
i18nc("denmark_counties.kgm", "Frederiksborg");
i18nc("denmark_counties.kgm", "Hillerød");
i18nc("denmark_counties.kgm", "Roskilde");
i18nc("denmark_counties.kgm", "Roskilde");
i18nc("denmark_counties.kgm", "West Zealand");
i18nc("denmark_counties.kgm", "Sorø");
i18nc("denmark_counties.kgm", "Storstrøm");
i18nc("denmark_counties.kgm", "Næstved");
i18nc("denmark_counties.kgm", "Funen");
i18nc("denmark_counties.kgm", "Odense");
i18nc("denmark_counties.kgm", "South Jutland");
i18nc("denmark_counties.kgm", "Aabenraa");
i18nc("denmark_counties.kgm", "Ribe");
i18nc("denmark_counties.kgm", "Ribe");
i18nc("denmark_counties.kgm", "Vejle");
i18nc("denmark_counties.kgm", "Vejle");
i18nc("denmark_counties.kgm", "Ringkjøbing");
i18nc("denmark_counties.kgm", "Ringkøbing");
i18nc("denmark_counties.kgm", "Viborg");
i18nc("denmark_counties.kgm", "Viborg");
i18nc("denmark_counties.kgm", "North Jutland");
i18nc("denmark_counties.kgm", "Ålborg");
i18nc("denmark_counties.kgm", "Århus");
i18nc("denmark_counties.kgm", "Århus");
i18nc("denmark_counties.kgm", "Bornholm");
i18nc("denmark_counties.kgm", "Rønne");
i18nc("dominican_republic.kgm", "Dominican Republic");
i18nc("dominican_republic.kgm", "Provinces");
i18nc("dominican_republic.kgm", "Frontier");
i18nc("dominican_republic.kgm", "Frontier");
i18nc("dominican_republic.kgm", "Water");
i18nc("dominican_republic.kgm", "Not Dominican Republic");
i18nc("dominican_republic.kgm", "Azua");
i18nc("dominican_republic.kgm", "Azua de Compostela");
i18nc("dominican_republic.kgm", "Baoruco");
i18nc("dominican_republic.kgm", "Neiba");
i18nc("dominican_republic.kgm", "Barahona");
i18nc("dominican_republic.kgm", "Santa Cruz de Barahona");
i18nc("dominican_republic.kgm", "Dajabón");
i18nc("dominican_republic.kgm", "Dajabón");
i18nc("dominican_republic.kgm", "Duarte");
i18nc("dominican_republic.kgm", "San Francisco de Macorís");
i18nc("dominican_republic.kgm", "Elías Piña");
i18nc("dominican_republic.kgm", "Comendador");
i18nc("dominican_republic.kgm", "El Seibo");
i18nc("dominican_republic.kgm", "Santa Cruz del Seibo");
i18nc("dominican_republic.kgm", "Espaillat");
i18nc("dominican_republic.kgm", "Moca");
i18nc("dominican_republic.kgm", "Hato Mayor");
i18nc("dominican_republic.kgm", "Hato Mayor del Rey");
i18nc("dominican_republic.kgm", "Independencia");
i18nc("dominican_republic.kgm", "Jimaní");
i18nc("dominican_republic.kgm", "La Altagracia");
i18nc("dominican_republic.kgm", "Salvaleón de Higüey");
i18nc("dominican_republic.kgm", "La Romana");
i18nc("dominican_republic.kgm", "La Romana");
i18nc("dominican_republic.kgm", "La Vega");
i18nc("dominican_republic.kgm", "Concepción de La Vega");
i18nc("dominican_republic.kgm", "María Trinidad Sánchez");
i18nc("dominican_republic.kgm", "Nagua");
i18nc("dominican_republic.kgm", "Monseñor Nouel");
i18nc("dominican_republic.kgm", "Bonao");
i18nc("dominican_republic.kgm", "Monte Cristi");
i18nc("dominican_republic.kgm", "San Fernando de Monte Cristi");
i18nc("dominican_republic.kgm", "Monte Plata");
i18nc("dominican_republic.kgm", "Monte Plata");
i18nc("dominican_republic.kgm", "Pedernales");
i18nc("dominican_republic.kgm", "Pedernales");
i18nc("dominican_republic.kgm", "Peravia");
i18nc("dominican_republic.kgm", "Baní");
i18nc("dominican_republic.kgm", "Puerto Plata");
i18nc("dominican_republic.kgm", "San Felipe de Puerto Plata");
i18nc("dominican_republic.kgm", "Hermanas Mirabal");
i18nc("dominican_republic.kgm", "Salcedo");
i18nc("dominican_republic.kgm", "Samaná");
i18nc("dominican_republic.kgm", "Santa Bárbara de Samaná");
i18nc("dominican_republic.kgm", "Sánchez Ramírez");
i18nc("dominican_republic.kgm", "Cotuí");
i18nc("dominican_republic.kgm", "San Cristóbal");
i18nc("dominican_republic.kgm", "San Cristóbal");
i18nc("dominican_republic.kgm", "San José de Ocoa");
i18nc("dominican_republic.kgm", "San José de Ocoa");
i18nc("dominican_republic.kgm", "San Juan");
i18nc("dominican_republic.kgm", "San Juan de la Maguana");
i18nc("dominican_republic.kgm", "San Pedro de Macorís");
i18nc("dominican_republic.kgm", "San Pedro de Macorís");
i18nc("dominican_republic.kgm", "Santiago");
i18nc("dominican_republic.kgm", "Santiago de los Caballeros");
i18nc("dominican_republic.kgm", "Santiago Rodríguez");
i18nc("dominican_republic.kgm", "San Ignacio de Sabaneta");
i18nc("dominican_republic.kgm", "Santo Domingo");
i18nc("dominican_republic.kgm", "Santo Domingo de Guzmán");
i18nc("dominican_republic.kgm", "Valverde");
i18nc("dominican_republic.kgm", "Santa Cruz de Mao");
i18nc("dominican_republic.kgm", "National District");
i18nc("dominican_republic.kgm", "Santo Domingo de Guzmán");
i18nc("ecuador.kgm", "Ecuador");
i18nc("ecuador.kgm", "Provinces");
i18nc("ecuador.kgm", "Frontier");
i18nc("ecuador.kgm", "Frontier");
i18nc("ecuador.kgm", "Water");
i18nc("ecuador.kgm", "Not Ecuador");
i18nc("ecuador.kgm", "Azuay");
i18nc("ecuador.kgm", "Cuenca");
i18nc("ecuador.kgm", "Bolívar");
i18nc("ecuador.kgm", "Guaranda");
i18nc("ecuador.kgm", "Cañar");
i18nc("ecuador.kgm", "Azogues");
i18nc("ecuador.kgm", "Carchi");
i18nc("ecuador.kgm", "Tulcán");
i18nc("ecuador.kgm", "Chimborazo");
i18nc("ecuador.kgm", "Riobamba");
i18nc("ecuador.kgm", "Cotopaxi");
i18nc("ecuador.kgm", "Latacunga");
i18nc("ecuador.kgm", "El Oro");
i18nc("ecuador.kgm", "Machala");
i18nc("ecuador.kgm", "Esmeraldas");
i18nc("ecuador.kgm", "Esmeraldas");
i18nc("ecuador.kgm", "Galápagos");
i18nc("ecuador.kgm", "Puerto Baquerizo Moreno");
i18nc("ecuador.kgm", "Guayas");
i18nc("ecuador.kgm", "Guayaquil");
i18nc("ecuador.kgm", "Imbabura");
i18nc("ecuador.kgm", "Ibarra");
i18nc("ecuador.kgm", "Loja");
i18nc("ecuador.kgm", "Loja");
i18nc("ecuador.kgm", "Los Ríos");
i18nc("ecuador.kgm", "Babahoyo");
i18nc("ecuador.kgm", "Manabí");
i18nc("ecuador.kgm", "Portoviejo");
i18nc("ecuador.kgm", "Morona Santiago");
i18nc("ecuador.kgm", "Macas");
i18nc("ecuador.kgm", "Santa Elena");
i18nc("ecuador.kgm", "Santa Elena");
i18nc("ecuador.kgm", "Santo Domingo de los Tsáchilas");
i18nc("ecuador.kgm", "Santo Domingo de Los Colorados");
i18nc("ecuador.kgm", "Napo");
i18nc("ecuador.kgm", "Tena");
i18nc("ecuador.kgm", "Orellana");
i18nc("ecuador.kgm", "Puerto Francisco de Orellana");
i18nc("ecuador.kgm", "Pastaza");
i18nc("ecuador.kgm", "Puyo");
i18nc("ecuador.kgm", "Pichincha");
i18nc("ecuador.kgm", "Quito");
i18nc("ecuador.kgm", "Sucumbíos");
i18nc("ecuador.kgm", "Nueva Loja");
i18nc("ecuador.kgm", "Tungurahua");
i18nc("ecuador.kgm", "Ambato");
i18nc("ecuador.kgm", "Zamora Chinchipe");
i18nc("ecuador.kgm", "Zamora");
i18nc("egypt.kgm", "Egypt");
i18nc("egypt.kgm", "Governorates");
i18nc("egypt.kgm", "Frontier");
i18nc("egypt.kgm", "Water");
i18nc("egypt.kgm", "Not Egypt");
i18nc("egypt.kgm", "Alexandria");
i18nc("egypt.kgm", "Alexandria");
i18nc("egypt.kgm", "Aswan");
i18nc("egypt.kgm", "Aswan");
i18nc("egypt.kgm", "Asyut");
i18nc("egypt.kgm", "Asyut");
i18nc("egypt.kgm", "Beheira");
i18nc("egypt.kgm", "Damanhur");
i18nc("egypt.kgm", "Beni Suef");
i18nc("egypt.kgm", "Beni Suef");
i18nc("egypt.kgm", "Cairo");
i18nc("egypt.kgm", "Cairo");
i18nc("egypt.kgm", "Dakahlia");
i18nc("egypt.kgm", "Mansura");
i18nc("egypt.kgm", "Damietta");
i18nc("egypt.kgm", "Damietta");
i18nc("egypt.kgm", "Faiyum");
i18nc("egypt.kgm", "Faiyum");
i18nc("egypt.kgm", "Gharbia");
i18nc("egypt.kgm", "Tanta");
i18nc("egypt.kgm", "Giza");
i18nc("egypt.kgm", "Giza");
i18nc("egypt.kgm", "Ismailia");
i18nc("egypt.kgm", "Ismailia");
i18nc("egypt.kgm", "Kafr el-Sheikh");
i18nc("egypt.kgm", "Kafr el-Sheikh");
i18nc("egypt.kgm", "Matruh");
i18nc("egypt.kgm", "Mersa Matruh");
i18nc("egypt.kgm", "Minya");
i18nc("egypt.kgm", "Minya");
i18nc("egypt.kgm", "Monufia");
i18nc("egypt.kgm", "Shibin el-Kom");
i18nc("egypt.kgm", "New Valley");
i18nc("egypt.kgm", "Kharga");
i18nc("egypt.kgm", "North Sinai");
i18nc("egypt.kgm", "Arish");
i18nc("egypt.kgm", "Port Said");
i18nc("egypt.kgm", "Port Said");
i18nc("egypt.kgm", "Qalyubia");
i18nc("egypt.kgm", "Banha");
i18nc("egypt.kgm", "Qena");
i18nc("egypt.kgm", "Qena");
i18nc("egypt.kgm", "Red Sea");
i18nc("egypt.kgm", "Hurghada");
i18nc("egypt.kgm", "Sharqia");
i18nc("egypt.kgm", "Zagazig");
i18nc("egypt.kgm", "Sohag");
i18nc("egypt.kgm", "Sohag");
i18nc("egypt.kgm", "South Sinai");
i18nc("egypt.kgm", "el-Tor");
i18nc("egypt.kgm", "Suez");
i18nc("egypt.kgm", "Suez");
i18nc("egypt.kgm", "Luxor");
i18nc("egypt.kgm", "Luxo");
i18nc("el_salvador.kgm", "El Salvador");
i18nc("el_salvador.kgm", "Departments");
i18nc("el_salvador.kgm", "Frontier");
i18nc("el_salvador.kgm", "Frontier");
i18nc("el_salvador.kgm", "Water");
i18nc("el_salvador.kgm", "Not El Salvador");
i18nc("el_salvador.kgm", "Ahuachapán");
i18nc("el_salvador.kgm", "Ahuachapán");
i18nc("el_salvador.kgm", "Santa Ana");
i18nc("el_salvador.kgm", "Santa Ana");
i18nc("el_salvador.kgm", "Sonsonate");
i18nc("el_salvador.kgm", "Sonsonate");
i18nc("el_salvador.kgm", "Usulután");
i18nc("el_salvador.kgm", "Usulután");
i18nc("el_salvador.kgm", "San Miguel");
i18nc("el_salvador.kgm", "San Miguel");
i18nc("el_salvador.kgm", "Morazán");
i18nc("el_salvador.kgm", "San Francisco Gotera");
i18nc("el_salvador.kgm", "La Unión");
i18nc("el_salvador.kgm", "La Unión");
i18nc("el_salvador.kgm", "La Libertad");
i18nc("el_salvador.kgm", "Santa Tecla");
i18nc("el_salvador.kgm", "Chalatenango");
i18nc("el_salvador.kgm", "Chalatenango");
i18nc("el_salvador.kgm", "Cuscatlán");
i18nc("el_salvador.kgm", "Cojutepeque");
i18nc("el_salvador.kgm", "San Salvador");
i18nc("el_salvador.kgm", "San Salvador");
i18nc("el_salvador.kgm", "La Paz");
i18nc("el_salvador.kgm", "Zacatecoluca");
i18nc("el_salvador.kgm", "Cabañas");
i18nc("el_salvador.kgm", "Sensuntepeque");
i18nc("el_salvador.kgm", "San Vicente");
i18nc("el_salvador.kgm", "San Vicente");
i18nc("emirates.kgm", "United Arab Emirates");
i18nc("emirates.kgm", "Emirates");
i18nc("emirates.kgm", "Frontier");
i18nc("emirates.kgm", "Water");
i18nc("emirates.kgm", "Not Emirates");
i18nc("emirates.kgm", "Abu Dhabi");
i18nc("emirates.kgm", "Ajman");
i18nc("emirates.kgm", "Dubaï");
i18nc("emirates.kgm", "Fujairah");
i18nc("emirates.kgm", "Ras al-Khaimah");
i18nc("emirates.kgm", "Sharjah");
i18nc("emirates.kgm", "Umm al-Qaiwain");
i18nc("estonia.kgm", "Estonia");
i18nc("estonia.kgm", "Counties");
i18nc("estonia.kgm", "Frontier");
i18nc("estonia.kgm", "Frontier");
i18nc("estonia.kgm", "Water");
i18nc("estonia.kgm", "Not Estonia");
i18nc("estonia.kgm", "Harju");
i18nc("estonia.kgm", "Tallinn");
i18nc("estonia.kgm", "Hiiu");
i18nc("estonia.kgm", "Kärdla");
i18nc("estonia.kgm", "Ida-Viru");
i18nc("estonia.kgm", "Jõhvi");
i18nc("estonia.kgm", "Järva");
i18nc("estonia.kgm", "Paide");
i18nc("estonia.kgm", "Jõgeva");
i18nc("estonia.kgm", "Jõgeva");
i18nc("estonia.kgm", "Lääne");
i18nc("estonia.kgm", "Haapsalu");
i18nc("estonia.kgm", "Lääne-Viru");
i18nc("estonia.kgm", "Rakvere");
i18nc("estonia.kgm", "Pärnu");
i18nc("estonia.kgm", "Pärnu");
i18nc("estonia.kgm", "Põlva");
i18nc("estonia.kgm", "Põlva");
i18nc("estonia.kgm", "Rapla");
i18nc("estonia.kgm", "Rapla");
i18nc("estonia.kgm", "Saare");
i18nc("estonia.kgm", "Kuressaare");
i18nc("estonia.kgm", "Tartu");
i18nc("estonia.kgm", "Tartu");
i18nc("estonia.kgm", "Valga");
i18nc("estonia.kgm", "Valga");
i18nc("estonia.kgm", "Viljandi");
i18nc("estonia.kgm", "Viljandi");
i18nc("estonia.kgm", "Võru");
i18nc("estonia.kgm", "Võru");
i18nc("europe.kgm", "Europe");
i18nc("europe.kgm", "Countries");
i18nc("europe.kgm", "Water");
i18nc("europe.kgm", "Coast");
i18nc("europe.kgm", "Frontier");
i18nc("europe.kgm", "Albania");
i18nc("europe.kgm", "Tirana");
i18nc("europe.kgm", "Algeria");
i18nc("europe.kgm", "Andorra");
i18nc("europe.kgm", "Andorra la Vella");
i18nc("europe.kgm", "Austria");
i18nc("europe.kgm", "Vienna");
i18nc("europe.kgm", "Belarus");
i18nc("europe.kgm", "Minsk");
i18nc("europe.kgm", "Belgium");
i18nc("europe.kgm", "Brussels");
i18nc("europe.kgm", "Bosnia and Herzegovina");
i18nc("europe.kgm", "Sarajevo");
i18nc("europe.kgm", "Bulgaria");
i18nc("europe.kgm", "Sofia");
i18nc("europe.kgm", "Croatia");
i18nc("europe.kgm", "Zagreb");
i18nc("europe.kgm", "Czech Republic");
i18nc("europe.kgm", "Prague");
i18nc("europe.kgm", "Denmark");
i18nc("europe.kgm", "Copenhagen");
i18nc("europe.kgm", "Estonia");
i18nc("europe.kgm", "Tallinn");
i18nc("europe.kgm", "Finland");
i18nc("europe.kgm", "Helsinki");
i18nc("europe.kgm", "Macedonia");
i18nc("europe.kgm", "Skopje");
i18nc("europe.kgm", "France");
i18nc("europe.kgm", "Paris");
i18nc("europe.kgm", "Germany");
i18nc("europe.kgm", "Berlin");
i18nc("europe.kgm", "Greece");
i18nc("europe.kgm", "Athens");
i18nc("europe.kgm", "Hungary");
i18nc("europe.kgm", "Budapest");
i18nc("europe.kgm", "Iceland");
i18nc("europe.kgm", "Reykjavik");
i18nc("europe.kgm", "Ireland");
i18nc("europe.kgm", "Dublin");
i18nc("europe.kgm", "Italy");
i18nc("europe.kgm", "Rome");
i18nc("europe.kgm", "Latvia");
i18nc("europe.kgm", "Riga");
i18nc("europe.kgm", "Liechtenstein");
i18nc("europe.kgm", "Vaduz");
i18nc("europe.kgm", "Lithuania");
i18nc("europe.kgm", "Vilnius");
i18nc("europe.kgm", "Luxembourg");
i18nc("europe.kgm", "Luxembourg");
i18nc("europe.kgm", "Moldova");
i18nc("europe.kgm", "Chisinau");
i18nc("europe.kgm", "Monaco");
i18nc("europe.kgm", "Monaco");
i18nc("europe.kgm", "Morocco");
i18nc("europe.kgm", "Netherlands");
i18nc("europe.kgm", "Amsterdam");
i18nc("europe.kgm", "Norway");
i18nc("europe.kgm", "Oslo");
i18nc("europe.kgm", "Poland");
i18nc("europe.kgm", "Warsaw");
i18nc("europe.kgm", "Portugal");
i18nc("europe.kgm", "Lisbon");
i18nc("europe.kgm", "Romania");
i18nc("europe.kgm", "Bucharest");
i18nc("europe.kgm", "Russia");
i18nc("europe.kgm", "Moscow");
i18nc("europe.kgm", "San Marino");
i18nc("europe.kgm", "San Marino");
i18nc("europe.kgm", "Serbia");
i18nc("europe.kgm", "Belgrade");
i18nc("europe.kgm", "Montenegro");
i18nc("europe.kgm", "Podgorica");
i18nc("europe.kgm", "Slovakia");
i18nc("europe.kgm", "Bratislava");
i18nc("europe.kgm", "Slovenia");
i18nc("europe.kgm", "Ljubljana");
i18nc("europe.kgm", "Spain");
i18nc("europe.kgm", "Madrid");
i18nc("europe.kgm", "Sweden");
i18nc("europe.kgm", "Stockholm");
i18nc("europe.kgm", "Switzerland");
i18nc("europe.kgm", "Bern");
i18nc("europe.kgm", "Syria");
i18nc("europe.kgm", "Tunisia");
i18nc("europe.kgm", "Turkey");
i18nc("europe.kgm", "Ankara");
i18nc("europe.kgm", "Ukraine");
i18nc("europe.kgm", "Kiev");
i18nc("europe.kgm", "United Kingdom");
i18nc("europe.kgm", "London");
i18nc("europe.kgm", "Vatican City");
i18nc("europe.kgm", "Vatican City");
i18nc("finland_regions.kgm", "Finland (Regions)");
i18nc("finland_regions.kgm", "Regions");
i18nc("finland_regions.kgm", "Frontier");
i18nc("finland_regions.kgm", "Water");
i18nc("finland_regions.kgm", "Not Finland (Regions)");
i18nc("finland_regions.kgm", "Åland");
i18nc("finland_regions.kgm", "Mariehamn");
i18nc("finland_regions.kgm", "North Carelia");
i18nc("finland_regions.kgm", "Joensuu");
i18nc("finland_regions.kgm", "South Carelia");
i18nc("finland_regions.kgm", "Lappeenranta");
i18nc("finland_regions.kgm", "Central Finland");
i18nc("finland_regions.kgm", "Jyväskylä");
i18nc("finland_regions.kgm", "Finland Proper");
i18nc("finland_regions.kgm", "Turku");
i18nc("finland_regions.kgm", "Kainuu");
i18nc("finland_regions.kgm", "Kajaani");
i18nc("finland_regions.kgm", "Lapland");
i18nc("finland_regions.kgm", "Rovaniemi");
i18nc("finland_regions.kgm", "Ostrobothnia");
i18nc("finland_regions.kgm", "Vaasa");
i18nc("finland_regions.kgm", "Central Ostrobothnia");
i18nc("finland_regions.kgm", "Kokkola");
i18nc("finland_regions.kgm", "Northern Ostrobothnia");
i18nc("finland_regions.kgm", "Oulu");
i18nc("finland_regions.kgm", "Southern Ostrobothnia");
i18nc("finland_regions.kgm", "Seinäjoki");
i18nc("finland_regions.kgm", "Päijänne-Tavastia");
i18nc("finland_regions.kgm", "Lahti");
i18nc("finland_regions.kgm", "Tavastia Proper");
i18nc("finland_regions.kgm", "Hämeenlinna");
i18nc("finland_regions.kgm", "Pirkanmaa");
i18nc("finland_regions.kgm", "Tampere");
i18nc("finland_regions.kgm", "Satakunta");
i18nc("finland_regions.kgm", "Pori");
i18nc("finland_regions.kgm", "Northern Savonia");
i18nc("finland_regions.kgm", "Kuopio");
i18nc("finland_regions.kgm", "Southern Savonia");
i18nc("finland_regions.kgm", "Mikkeli");
i18nc("finland_regions.kgm", "Nylandia");
i18nc("finland_regions.kgm", "Helsinki");
i18nc("finland_regions.kgm", "Kymenlaakso");
i18nc("finland_regions.kgm", "Kouvola");
i18nc("france.kgm", "France");
i18nc("france.kgm", "Departments");
i18nc("france.kgm", "Not France");
i18nc("france.kgm", "Frontier");
i18nc("france.kgm", "Frontier");
i18nc("france.kgm", "Ain");
i18nc("france.kgm", "Bourg en Bresse");
i18nc("france.kgm", "Aisne");
i18nc("france.kgm", "Laon");
i18nc("france.kgm", "Allier");
i18nc("france.kgm", "Moulins");
i18nc("france.kgm", "Alpes de Haute-Provence");
i18nc("france.kgm", "Digne");
i18nc("france.kgm", "Hautes-Alpes");
i18nc("france.kgm", "Gap");
i18nc("france.kgm", "Alpes Maritimes");
i18nc("france.kgm", "Nice");
i18nc("france.kgm", "Ardèche");
i18nc("france.kgm", "Privas");
i18nc("france.kgm", "Ardennes");
i18nc("france.kgm", "Charleville-Mézières");
i18nc("france.kgm", "Ariège");
i18nc("france.kgm", "Foix");
i18nc("france.kgm", "Aube");
i18nc("france.kgm", "Troyes");
i18nc("france.kgm", "Aude");
i18nc("france.kgm", "Carcassonne");
i18nc("france.kgm", "Aveyron");
i18nc("france.kgm", "Rodez");
i18nc("france.kgm", "Bouches-du-Rhône");
i18nc("france.kgm", "Marseille");
i18nc("france.kgm", "Calvados");
i18nc("france.kgm", "Caen");
i18nc("france.kgm", "Cantal");
i18nc("france.kgm", "Aurillac");
i18nc("france.kgm", "Charente");
i18nc("france.kgm", "Angoulème");
i18nc("france.kgm", "Charente-Maritime");
i18nc("france.kgm", "La Rochelle");
i18nc("france.kgm", "Cher");
i18nc("france.kgm", "Bourges");
i18nc("france.kgm", "Corrèze");
i18nc("france.kgm", "Tulle");
i18nc("france.kgm", "Corse du Sud");
i18nc("france.kgm", "Ajaccio");
i18nc("france.kgm", "Haute-Corse");
i18nc("france.kgm", "Bastia");
i18nc("france.kgm", "Côte d'Or");
i18nc("france.kgm", "Dijon");
i18nc("france.kgm", "Côtes d'Armor");
i18nc("france.kgm", "Saint Brieuc");
i18nc("france.kgm", "Creuse");
i18nc("france.kgm", "Guéret");
i18nc("france.kgm", "Dordogne");
i18nc("france.kgm", "Périgueux");
i18nc("france.kgm", "Doubs");
i18nc("france.kgm", "Besançon");
i18nc("france.kgm", "Drôme");
i18nc("france.kgm", "Valence");
i18nc("france.kgm", "Eure");
i18nc("france.kgm", "Evreux");
i18nc("france.kgm", "Eure et Loir");
i18nc("france.kgm", "Chartres");
i18nc("france.kgm", "Finistère");
i18nc("france.kgm", "Quimper");
i18nc("france.kgm", "Gard");
i18nc("france.kgm", "Nîmes");
i18nc("france.kgm", "Haute-Garonne");
i18nc("france.kgm", "Toulouse");
i18nc("france.kgm", "Gers");
i18nc("france.kgm", "Auch");
i18nc("france.kgm", "Gironde");
i18nc("france.kgm", "Bordeaux");
i18nc("france.kgm", "Hérault");
i18nc("france.kgm", "Montpellier");
i18nc("france.kgm", "Ille et Vilaine");
i18nc("france.kgm", "Rennes");
i18nc("france.kgm", "Indre");
i18nc("france.kgm", "Châteauroux");
i18nc("france.kgm", "Indre et Loire");
i18nc("france.kgm", "Tours");
i18nc("france.kgm", "Isère");
i18nc("france.kgm", "Grenoble");
i18nc("france.kgm", "Jura");
i18nc("france.kgm", "Lons le Saunier");
i18nc("france.kgm", "Landes");
i18nc("france.kgm", "Mont de Marsan");
i18nc("france.kgm", "Loir et Cher");
i18nc("france.kgm", "Blois");
i18nc("france.kgm", "Loire");
i18nc("france.kgm", "Saint Etienne");
i18nc("france.kgm", "Haute-Loire");
i18nc("france.kgm", "Le Puy");
i18nc("france.kgm", "Loire-Atlantique");
i18nc("france.kgm", "Nantes");
i18nc("france.kgm", "Loiret");
i18nc("france.kgm", "Orléans");
i18nc("france.kgm", "Lot");
i18nc("france.kgm", "Cahors");
i18nc("france.kgm", "Lot et Garonne");
i18nc("france.kgm", "Agen");
i18nc("france.kgm", "Lozère");
i18nc("france.kgm", "Mende");
i18nc("france.kgm", "Maine et Loire");
i18nc("france.kgm", "Angers");
i18nc("france.kgm", "Manche");
i18nc("france.kgm", "Saint Lô");
i18nc("france.kgm", "Marne");
i18nc("france.kgm", "Châlon en Champagne");
i18nc("france.kgm", "Haute-Marne");
i18nc("france.kgm", "Chaumont");
i18nc("france.kgm", "Mayenne");
i18nc("france.kgm", "Laval");
i18nc("france.kgm", "Meurthe et Moselle");
i18nc("france.kgm", "Nancy");
i18nc("france.kgm", "Meuse");
i18nc("france.kgm", "Bar le Duc");
i18nc("france.kgm", "Morbihan");
i18nc("france.kgm", "Vannes");
i18nc("france.kgm", "Moselle");
i18nc("france.kgm", "Metz");
i18nc("france.kgm", "Nièvre");
i18nc("france.kgm", "Nevers");
i18nc("france.kgm", "Nord");
i18nc("france.kgm", "Lille");
i18nc("france.kgm", "Oise");
i18nc("france.kgm", "Beauvais");
i18nc("france.kgm", "Orne");
i18nc("france.kgm", "Alençon");
i18nc("france.kgm", "Pas-de-Calais");
i18nc("france.kgm", "Arras");
i18nc("france.kgm", "Puy-de-Dôme");
i18nc("france.kgm", "Clermont Ferrand");
i18nc("france.kgm", "Pyrénées-Atlantiques");
i18nc("france.kgm", "Pau");
i18nc("france.kgm", "Hautes-Pyrénées");
i18nc("france.kgm", "Tarbes");
i18nc("france.kgm", "Pyrénées-Orientales");
i18nc("france.kgm", "Perpignan");
i18nc("france.kgm", "Bas-Rhin");
i18nc("france.kgm", "Strasbourg");
i18nc("france.kgm", "Haut-Rhin");
i18nc("france.kgm", "Colmar");
i18nc("france.kgm", "Rhône");
i18nc("france.kgm", "Lyon");
i18nc("france.kgm", "Haute-Saône");
i18nc("france.kgm", "Vesoul");
i18nc("france.kgm", "Saône et Loire");
i18nc("france.kgm", "Mâcon");
i18nc("france.kgm", "Sarthe");
i18nc("france.kgm", "Le Mans");
i18nc("france.kgm", "Savoie");
i18nc("france.kgm", "Chambéry");
i18nc("france.kgm", "Haute-Savoie");
i18nc("france.kgm", "Annecy");
i18nc("france.kgm", "Paris");
i18nc("france.kgm", "Paris");
i18nc("france.kgm", "Seine-Maritime");
i18nc("france.kgm", "Rouen");
i18nc("france.kgm", "Seine et Marne");
i18nc("france.kgm", "Melun");
i18nc("france.kgm", "Yvelines");
i18nc("france.kgm", "Versailles");
i18nc("france.kgm", "Deux-Sèvres");
i18nc("france.kgm", "Niort");
i18nc("france.kgm", "Somme");
i18nc("france.kgm", "Amiens");
i18nc("france.kgm", "Tarn");
i18nc("france.kgm", "Albi");
i18nc("france.kgm", "Tarn et Garonne");
i18nc("france.kgm", "Montauban");
i18nc("france.kgm", "Var");
i18nc("france.kgm", "Toulon");
i18nc("france.kgm", "Vaucluse");
i18nc("france.kgm", "Avignon");
i18nc("france.kgm", "Vendée");
i18nc("france.kgm", "La Roche sur Yon");
i18nc("france.kgm", "Vienne");
i18nc("france.kgm", "Poitiers");
i18nc("france.kgm", "Haute-Vienne");
i18nc("france.kgm", "Limoges");
i18nc("france.kgm", "Vosges");
i18nc("france.kgm", "Epinal");
i18nc("france.kgm", "Yonne");
i18nc("france.kgm", "Auxerre");
i18nc("france.kgm", "Territoire de Belfort");
i18nc("france.kgm", "Belfort");
i18nc("france.kgm", "Essonne");
i18nc("france.kgm", "Evry");
i18nc("france.kgm", "Hauts-de-Seine");
i18nc("france.kgm", "Nanterre");
i18nc("france.kgm", "Seine-Saint-Denis");
i18nc("france.kgm", "Bobigny");
i18nc("france.kgm", "Val-de-Marne");
i18nc("france.kgm", "Créteil");
i18nc("france.kgm", "Val d'Oise");
i18nc("france.kgm", "Cergy-Pontoise");
i18nc("france_regions.kgm", "France (Regions)");
i18nc("france_regions.kgm", "Regions");
i18nc("france_regions.kgm", "Frontier");
i18nc("france_regions.kgm", "Water");
i18nc("france_regions.kgm", "Not France (Regions)");
i18nc("france_regions.kgm", "Provence-Alpes-Côte d'Azur");
i18nc("france_regions.kgm", "Marseille");
i18nc("france_regions.kgm", "Basse Normandie");
i18nc("france_regions.kgm", "Caen");
i18nc("france_regions.kgm", "Corse");
i18nc("france_regions.kgm", "Ajaccio");
i18nc("france_regions.kgm", "Bourgogne");
i18nc("france_regions.kgm", "Dijon");
i18nc("france_regions.kgm", "Franche Comté");
i18nc("france_regions.kgm", "Besançon");
i18nc("france_regions.kgm", "Midi-Pyrénées");
i18nc("france_regions.kgm", "Toulouse");
i18nc("france_regions.kgm", "Aquitaine");
i18nc("france_regions.kgm", "Bordeaux");
i18nc("france_regions.kgm", "Languedoc-Roussilon");
i18nc("france_regions.kgm", "Montpellier");
i18nc("france_regions.kgm", "Bretagne");
i18nc("france_regions.kgm", "Rennes");
i18nc("france_regions.kgm", "Pays de Loire");
i18nc("france_regions.kgm", "Nantes");
i18nc("france_regions.kgm", "Centre");
i18nc("france_regions.kgm", "Orléans");
i18nc("france_regions.kgm", "Champagne-Ardennes");
i18nc("france_regions.kgm", "Châlon en Champagne");
i18nc("france_regions.kgm", "Lorraine");
i18nc("france_regions.kgm", "Metz");
i18nc("france_regions.kgm", "Nord-Pas de Calais");
i18nc("france_regions.kgm", "Lille");
i18nc("france_regions.kgm", "Auvergne");
i18nc("france_regions.kgm", "Clermont Ferrand");
i18nc("france_regions.kgm", "Alsace");
i18nc("france_regions.kgm", "Strasbourg");
i18nc("france_regions.kgm", "Rhône-Alpes");
i18nc("france_regions.kgm", "Lyon");
i18nc("france_regions.kgm", "Île de France");
i18nc("france_regions.kgm", "Paris");
i18nc("france_regions.kgm", "Haute Normandie");
i18nc("france_regions.kgm", "Rouen");
i18nc("france_regions.kgm", "Picardie");
i18nc("france_regions.kgm", "Amiens");
i18nc("france_regions.kgm", "Poitou-Charentes");
i18nc("france_regions.kgm", "Poitiers");
i18nc("france_regions.kgm", "Limousin");
i18nc("france_regions.kgm", "Limoges");
i18nc("georgia.kgm", "Georgia");
i18nc("georgia.kgm", "Regions");
i18nc("georgia.kgm", "Frontier");
i18nc("georgia.kgm", "Water");
i18nc("georgia.kgm", "Not Georgia");
i18nc("georgia.kgm", "Abkhazia");
i18nc("georgia.kgm", "Sokhumi");
i18nc("georgia.kgm", "Samegrelo-Zemo Svaneti");
i18nc("georgia.kgm", "Zugdidi");
i18nc("georgia.kgm", "Guria");
i18nc("georgia.kgm", "Ozurgeti");
i18nc("georgia.kgm", "Ajaria");
i18nc("georgia.kgm", "Batumi");
i18nc("georgia.kgm", "Racha-Lechkhumi and Kvemo Svaneti");
i18nc("georgia.kgm", "Ambrolauri");
i18nc("georgia.kgm", "Imereti");
i18nc("georgia.kgm", "Kutaisi");
i18nc("georgia.kgm", "Samtskhe-Javakheti");
i18nc("georgia.kgm", "Akhaltsikhe");
i18nc("georgia.kgm", "Shida Kartli");
i18nc("georgia.kgm", "Gori");
i18nc("georgia.kgm", "Mtskheta-Mtianeti");
i18nc("georgia.kgm", "Mtskheta");
i18nc("georgia.kgm", "Kvemo Kartli");
i18nc("georgia.kgm", "Rustavi");
i18nc("georgia.kgm", "Kakheti");
i18nc("georgia.kgm", "Telavi");
i18nc("georgia.kgm", "Tbilisi");
i18nc("georgia.kgm", "Tbilisi");
i18nc("germany.kgm", "Germany");
i18nc("germany.kgm", "States");
i18nc("germany.kgm", "Frontier");
i18nc("germany.kgm", "Not Germany");
i18nc("germany.kgm", "Baden-Württemberg");
i18nc("germany.kgm", "Stuttgart");
i18nc("germany.kgm", "Bavaria");
i18nc("germany.kgm", "Munich");
i18nc("germany.kgm", "Berlin");
i18nc("germany.kgm", "Berlin");
i18nc("germany.kgm", "Brandenburg");
i18nc("germany.kgm", "Potsdam");
i18nc("germany.kgm", "Bremen");
i18nc("germany.kgm", "Bremen");
i18nc("germany.kgm", "Hamburg");
i18nc("germany.kgm", "Hamburg");
i18nc("germany.kgm", "Hesse");
i18nc("germany.kgm", "Wiesbaden");
i18nc("germany.kgm", "Mecklenburg-Western Pomerania");
i18nc("germany.kgm", "Schwerin");
i18nc("germany.kgm", "Lower Saxony");
i18nc("germany.kgm", "Hanover");
i18nc("germany.kgm", "North Rhine-Westphalia");
i18nc("germany.kgm", "Düsseldorf");
i18nc("germany.kgm", "Rhineland-Palatinate");
i18nc("germany.kgm", "Mainz");
i18nc("germany.kgm", "Saarland");
i18nc("germany.kgm", "Saarbrücken");
i18nc("germany.kgm", "Saxony");
i18nc("germany.kgm", "Dresden");
i18nc("germany.kgm", "Saxony-Anhalt");
i18nc("germany.kgm", "Magdeburg");
i18nc("germany.kgm", "Schleswig-Holstein");
i18nc("germany.kgm", "Kiel");
i18nc("germany.kgm", "Thuringia");
i18nc("germany.kgm", "Erfurt");
i18nc("goa.kgm", "Goa");
i18nc("goa.kgm", "District");
i18nc("goa.kgm", "Not Goa");
i18nc("goa.kgm", "Frontier");
i18nc("goa.kgm", "Canacona");
i18nc("goa.kgm", "Chaudi");
i18nc("goa.kgm", "Quepem");
i18nc("goa.kgm", "Quepem");
i18nc("goa.kgm", "Mormugao");
i18nc("goa.kgm", "Vasco da Gama");
i18nc("goa.kgm", "Sanguem");
i18nc("goa.kgm", "Sanguem");
i18nc("goa.kgm", "Salcette");
i18nc("goa.kgm", "Margao");
i18nc("goa.kgm", "Ponda");
i18nc("goa.kgm", "Ponda");
i18nc("goa.kgm", "Pernem");
i18nc("goa.kgm", "Pernem");
i18nc("goa.kgm", "Bardez");
i18nc("goa.kgm", "Mapusa");
i18nc("goa.kgm", "Bicholim");
i18nc("goa.kgm", "Bicholim");
i18nc("goa.kgm", "Tiswadi");
i18nc("goa.kgm", "Panjim");
i18nc("goa.kgm", "Satari");
i18nc("goa.kgm", "Valpoi");
i18nc("great-britain_counties.kgm", "Great-Britain (Counties)");
i18nc("great-britain_counties.kgm", "Counties");
i18nc("great-britain_counties.kgm", "Frontier");
i18nc("great-britain_counties.kgm", "Water");
i18nc("great-britain_counties.kgm", "Not Great-Britain (Counties)");
i18nc("great-britain_counties.kgm", "Shetland islands");
i18nc("great-britain_counties.kgm", "Lerwick");
i18nc("great-britain_counties.kgm", "Orkney");
i18nc("great-britain_counties.kgm", "Kirkwall");
i18nc("great-britain_counties.kgm", "Caithness");
i18nc("great-britain_counties.kgm", "Wick");
i18nc("great-britain_counties.kgm", "Sutherland");
i18nc("great-britain_counties.kgm", "Dornoch");
i18nc("great-britain_counties.kgm", "Ross-shire and Cromarty");
i18nc("great-britain_counties.kgm", "Dingwall");
i18nc("great-britain_counties.kgm", "Inverness-shire");
i18nc("great-britain_counties.kgm", "Inverness");
i18nc("great-britain_counties.kgm", "Nairnshire");
i18nc("great-britain_counties.kgm", "Nairn");
i18nc("great-britain_counties.kgm", "Morayshire");
i18nc("great-britain_counties.kgm", "Elgin");
i18nc("great-britain_counties.kgm", "Banffshire");
i18nc("great-britain_counties.kgm", "Banff");
i18nc("great-britain_counties.kgm", "Aberdeenshire");
i18nc("great-britain_counties.kgm", "Aberdeen");
i18nc("great-britain_counties.kgm", "Kincardineshire");
i18nc("great-britain_counties.kgm", "Stonehaven");
i18nc("great-britain_counties.kgm", "Angus");
i18nc("great-britain_counties.kgm", "Forfar");
i18nc("great-britain_counties.kgm", "Perthshire");
i18nc("great-britain_counties.kgm", "Perth");
i18nc("great-britain_counties.kgm", "Argyllshire");
i18nc("great-britain_counties.kgm", "Inveraray");
i18nc("great-britain_counties.kgm", "Dumbartonshire");
i18nc("great-britain_counties.kgm", "Dumbarton");
i18nc("great-britain_counties.kgm", "Stirlingshire");
i18nc("great-britain_counties.kgm", "Stirling");
i18nc("great-britain_counties.kgm", "Clackmannanshire");
i18nc("great-britain_counties.kgm", "Alloa");
i18nc("great-britain_counties.kgm", "Kinross-shire");
i18nc("great-britain_counties.kgm", "Kinross");
i18nc("great-britain_counties.kgm", "Fife");
i18nc("great-britain_counties.kgm", "Glenrothes");
i18nc("great-britain_counties.kgm", "East Lothian");
i18nc("great-britain_counties.kgm", "Haddington");
i18nc("great-britain_counties.kgm", "Midlothian");
i18nc("great-britain_counties.kgm", "Dalkeith");
i18nc("great-britain_counties.kgm", "West Lothian");
i18nc("great-britain_counties.kgm", "Livingston");
i18nc("great-britain_counties.kgm", "Lanarkshire");
i18nc("great-britain_counties.kgm", "Lanark");
i18nc("great-britain_counties.kgm", "Renfrewshire");
i18nc("great-britain_counties.kgm", "Paisley");
i18nc("great-britain_counties.kgm", "Ayrshire");
i18nc("great-britain_counties.kgm", "Ayr");
i18nc("great-britain_counties.kgm", "Buteshire");
i18nc("great-britain_counties.kgm", "Rothesay");
i18nc("great-britain_counties.kgm", "Wigtownshire");
i18nc("great-britain_counties.kgm", "Wigtown");
i18nc("great-britain_counties.kgm", "Kirkcudbrightshire");
i18nc("great-britain_counties.kgm", "Kirkcudbright");
i18nc("great-britain_counties.kgm", "Dumfriesshire");
i18nc("great-britain_counties.kgm", "Dumfries");
i18nc("great-britain_counties.kgm", "Peeblesshire");
i18nc("great-britain_counties.kgm", "Peebles");
i18nc("great-britain_counties.kgm", "Selkirkshire");
i18nc("great-britain_counties.kgm", "Selkirk");
i18nc("great-britain_counties.kgm", "Roxburghshire");
i18nc("great-britain_counties.kgm", "Roxburgh");
i18nc("great-britain_counties.kgm", "Berwickshire");
i18nc("great-britain_counties.kgm", "Berwick");
i18nc("great-britain_counties.kgm", "Northumberland");
i18nc("great-britain_counties.kgm", "Morpeth");
i18nc("great-britain_counties.kgm", "Cumberland");
i18nc("great-britain_counties.kgm", "Carlisle");
i18nc("great-britain_counties.kgm", "Durham");
i18nc("great-britain_counties.kgm", "Durham");
i18nc("great-britain_counties.kgm", "Westmorland");
i18nc("great-britain_counties.kgm", "Appleby-in-Westmorland");
i18nc("great-britain_counties.kgm", "Lancashire");
i18nc("great-britain_counties.kgm", "Preston");
i18nc("great-britain_counties.kgm", "Yorkshire");
i18nc("great-britain_counties.kgm", "York");
i18nc("great-britain_counties.kgm", "Lincolnshire");
i18nc("great-britain_counties.kgm", "Lincoln");
i18nc("great-britain_counties.kgm", "Nottinghamshire");
i18nc("great-britain_counties.kgm", "West Bridgford");
i18nc("great-britain_counties.kgm", "Derbyshire");
i18nc("great-britain_counties.kgm", "Matlock");
i18nc("great-britain_counties.kgm", "Cheshire");
i18nc("great-britain_counties.kgm", "Chester");
i18nc("great-britain_counties.kgm", "Shropshire");
i18nc("great-britain_counties.kgm", "Shrewbury");
i18nc("great-britain_counties.kgm", "Staffordshire");
i18nc("great-britain_counties.kgm", "Stafford");
i18nc("great-britain_counties.kgm", "Leicestershire");
i18nc("great-britain_counties.kgm", "Glenfield");
i18nc("great-britain_counties.kgm", "Rutland");
i18nc("great-britain_counties.kgm", "Oakham");
i18nc("great-britain_counties.kgm", "Northamptonshire");
i18nc("great-britain_counties.kgm", "Northampton");
i18nc("great-britain_counties.kgm", "Huntingdonshire");
i18nc("great-britain_counties.kgm", "Huntingdon");
i18nc("great-britain_counties.kgm", "Cambridgeshire");
i18nc("great-britain_counties.kgm", "Cambridge");
i18nc("great-britain_counties.kgm", "Norfolk");
i18nc("great-britain_counties.kgm", "Norwich");
i18nc("great-britain_counties.kgm", "Suffolk");
i18nc("great-britain_counties.kgm", "Ipswich");
i18nc("great-britain_counties.kgm", "Essex");
i18nc("great-britain_counties.kgm", "Chelmsford");
i18nc("great-britain_counties.kgm", "Kent");
i18nc("great-britain_counties.kgm", "Maidstone");
i18nc("great-britain_counties.kgm", "Sussex");
i18nc("great-britain_counties.kgm", "Chichester");
i18nc("great-britain_counties.kgm", "Surrey");
i18nc("great-britain_counties.kgm", "Kingston");
i18nc("great-britain_counties.kgm", "Middlesex");
i18nc("great-britain_counties.kgm", "London");
i18nc("great-britain_counties.kgm", "Hertfordshire");
i18nc("great-britain_counties.kgm", "Hertford");
i18nc("great-britain_counties.kgm", "Bedfordshire");
i18nc("great-britain_counties.kgm", "Bedford");
i18nc("great-britain_counties.kgm", "Buckinghamshire");
i18nc("great-britain_counties.kgm", "Aylesbury");
i18nc("great-britain_counties.kgm", "Oxfordshire");
i18nc("great-britain_counties.kgm", "Oxford");
i18nc("great-britain_counties.kgm", "Berkshire");
i18nc("great-britain_counties.kgm", "Reading");
i18nc("great-britain_counties.kgm", "Hampshire");
i18nc("great-britain_counties.kgm", "Winchester");
i18nc("great-britain_counties.kgm", "Dorset");
i18nc("great-britain_counties.kgm", "Dorchester");
i18nc("great-britain_counties.kgm", "Devon");
i18nc("great-britain_counties.kgm", "Exeter");
i18nc("great-britain_counties.kgm", "Cornwall");
i18nc("great-britain_counties.kgm", "Truro");
i18nc("great-britain_counties.kgm", "Somerset");
i18nc("great-britain_counties.kgm", "Taunton");
i18nc("great-britain_counties.kgm", "Wiltshire");
i18nc("great-britain_counties.kgm", "Trowbridge");
i18nc("great-britain_counties.kgm", "Gloucestershire");
i18nc("great-britain_counties.kgm", "Gloucester");
i18nc("great-britain_counties.kgm", "Warwickshire");
i18nc("great-britain_counties.kgm", "Warwick");
i18nc("great-britain_counties.kgm", "Worcestershire");
i18nc("great-britain_counties.kgm", "Worcester");
i18nc("great-britain_counties.kgm", "Herefordshire");
i18nc("great-britain_counties.kgm", "Hereford");
i18nc("great-britain_counties.kgm", "Monmouthshire");
i18nc("great-britain_counties.kgm", "Monmouth");
i18nc("great-britain_counties.kgm", "Glamorgan");
i18nc("great-britain_counties.kgm", "Cardiff");
i18nc("great-britain_counties.kgm", "Carmarthenshire");
i18nc("great-britain_counties.kgm", "Llanelli");
i18nc("great-britain_counties.kgm", "Pembrokeshire");
i18nc("great-britain_counties.kgm", "Haverfordwest");
i18nc("great-britain_counties.kgm", "Cardiganshire");
i18nc("great-britain_counties.kgm", "Cardigan");
i18nc("great-britain_counties.kgm", "Brecknockshire");
i18nc("great-britain_counties.kgm", "Brecon");
i18nc("great-britain_counties.kgm", "Radnorshire");
i18nc("great-britain_counties.kgm", "New Radnor");
i18nc("great-britain_counties.kgm", "Montgomeryshire");
i18nc("great-britain_counties.kgm", "Montgomery");
i18nc("great-britain_counties.kgm", "Merionethshire");
i18nc("great-britain_counties.kgm", "Dolgellau");
i18nc("great-britain_counties.kgm", "Caernarfonshire");
i18nc("great-britain_counties.kgm", "Caernarfon");
i18nc("great-britain_counties.kgm", "Anglesey");
i18nc("great-britain_counties.kgm", "Holyhead");
i18nc("great-britain_counties.kgm", "Denbighshire");
i18nc("great-britain_counties.kgm", "Denbigh");
i18nc("great-britain_counties.kgm", "Flintshire");
i18nc("great-britain_counties.kgm", "Mold");
i18nc("greece.kgm", "Greece");
i18nc("greece.kgm", "Peripheries");
i18nc("greece.kgm", "Border");
i18nc("greece.kgm", "Border");
i18nc("greece.kgm", "Aegean Sea");
i18nc("greece.kgm", "Balkans");
i18nc("greece.kgm", "Sea of Crete");
i18nc("greece.kgm", "Ionian Sea");
i18nc("greece.kgm", "Mediterranean Sea");
i18nc("greece.kgm", "Not Greece");
i18nc("greece.kgm", "Attica");
i18nc("greece.kgm", "Athens");
i18nc("greece.kgm", "Central Greece");
i18nc("greece.kgm", "Lamia");
i18nc("greece.kgm", "Central Macedonia");
i18nc("greece.kgm", "Thessaloniki");
i18nc("greece.kgm", "Crete");
i18nc("greece.kgm", "Heraklion");
i18nc("greece.kgm", "East Macedonia and Thrace");
i18nc("greece.kgm", "Komotini");
i18nc("greece.kgm", "Epirus");
i18nc("greece.kgm", "Ioannina");
i18nc("greece.kgm", "Ionian Islands");
i18nc("greece.kgm", "Corfu");
i18nc("greece.kgm", "North Aegean");
i18nc("greece.kgm", "Mytilene");
i18nc("greece.kgm", "Peloponnese");
i18nc("greece.kgm", "Tripoli");
i18nc("greece.kgm", "South Aegean");
i18nc("greece.kgm", "Ermoupoli");
i18nc("greece.kgm", "Thessaly");
i18nc("greece.kgm", "Larissa");
i18nc("greece.kgm", "West Greece");
i18nc("greece.kgm", "Patras");
i18nc("greece.kgm", "West Macedonia");
i18nc("greece.kgm", "Kozani");
i18nc("greece.kgm", "Mount Athos");
i18nc("greece.kgm", "Karyes");
i18nc("greece_peripheries.kgm", "Greece (Peripheries)");
i18nc("greece_peripheries.kgm", "Peripheries");
i18nc("greece_peripheries.kgm", "Frontier");
i18nc("greece_peripheries.kgm", "Water");
i18nc("greece_peripheries.kgm", "Not Greece (Peripheries)");
i18nc("greece_peripheries.kgm", "Eastern Macedonia and Thrace");
i18nc("greece_peripheries.kgm", "Komotini");
i18nc("greece_peripheries.kgm", "Central Macedonia");
i18nc("greece_peripheries.kgm", "Thessaloniki");
i18nc("greece_peripheries.kgm", "West Macedonia");
i18nc("greece_peripheries.kgm", "Kozani");
i18nc("greece_peripheries.kgm", "Ionian Islands");
i18nc("greece_peripheries.kgm", "Corfu");
i18nc("greece_peripheries.kgm", "Epirus");
i18nc("greece_peripheries.kgm", "Ioannina");
i18nc("greece_peripheries.kgm", "West Greece");
i18nc("greece_peripheries.kgm", "Patra");
i18nc("greece_peripheries.kgm", "Thessaly");
i18nc("greece_peripheries.kgm", "Larisa");
i18nc("greece_peripheries.kgm", "Central Greece");
i18nc("greece_peripheries.kgm", "Lamia");
i18nc("greece_peripheries.kgm", "Attica");
i18nc("greece_peripheries.kgm", "Athens");
i18nc("greece_peripheries.kgm", "Peloponnese");
i18nc("greece_peripheries.kgm", "Tripoli");
i18nc("greece_peripheries.kgm", "North Aegean");
i18nc("greece_peripheries.kgm", "Mytilene");
i18nc("greece_peripheries.kgm", "South Aegean");
i18nc("greece_peripheries.kgm", "Ermoupoli");
i18nc("greece_peripheries.kgm", "Crete");
i18nc("greece_peripheries.kgm", "Iraklio");
i18nc("greece_peripheries.kgm", "Mont Athos autonomous region");
i18nc("greece_peripheries.kgm", "Karyes");
i18nc("greece_prefectures.kgm", "Greece (Prefectures)");
i18nc("greece_prefectures.kgm", "Prefectures");
i18nc("greece_prefectures.kgm", "Frontier");
i18nc("greece_prefectures.kgm", "Water");
i18nc("greece_prefectures.kgm", "Not Greece (Prefectures)");
i18nc("greece_prefectures.kgm", "Drama");
i18nc("greece_prefectures.kgm", "Drama");
i18nc("greece_prefectures.kgm", "Evros");
i18nc("greece_prefectures.kgm", "Alexandroupolis");
i18nc("greece_prefectures.kgm", "Kavala");
i18nc("greece_prefectures.kgm", "Kavala");
i18nc("greece_prefectures.kgm", "Rodopi");
i18nc("greece_prefectures.kgm", "Komotini");
i18nc("greece_prefectures.kgm", "Xanthi");
i18nc("greece_prefectures.kgm", "Xanthi");
i18nc("greece_prefectures.kgm", "Chalcidice");
i18nc("greece_prefectures.kgm", "Polygyros");
i18nc("greece_prefectures.kgm", "Imathia");
i18nc("greece_prefectures.kgm", "Veria");
i18nc("greece_prefectures.kgm", "Kilkis");
i18nc("greece_prefectures.kgm", "Kilkis");
i18nc("greece_prefectures.kgm", "Pella");
i18nc("greece_prefectures.kgm", "Edhessa");
i18nc("greece_prefectures.kgm", "Pieria");
i18nc("greece_prefectures.kgm", "Katerini");
i18nc("greece_prefectures.kgm", "Serres");
i18nc("greece_prefectures.kgm", "Serres");
i18nc("greece_prefectures.kgm", "Thessaloniki");
i18nc("greece_prefectures.kgm", "Thessaloniki");
i18nc("greece_prefectures.kgm", "Florina");
i18nc("greece_prefectures.kgm", "Florina");
i18nc("greece_prefectures.kgm", "Grevena");
i18nc("greece_prefectures.kgm", "Grevena");
i18nc("greece_prefectures.kgm", "Kastoria");
i18nc("greece_prefectures.kgm", "Kastoria");
i18nc("greece_prefectures.kgm", "Kozani");
i18nc("greece_prefectures.kgm", "Kozani");
i18nc("greece_prefectures.kgm", "Arta");
i18nc("greece_prefectures.kgm", "Arta");
i18nc("greece_prefectures.kgm", "Ioannina");
i18nc("greece_prefectures.kgm", "Ioannina");
i18nc("greece_prefectures.kgm", "Preveza");
i18nc("greece_prefectures.kgm", "Preveza");
i18nc("greece_prefectures.kgm", "Thresprotia");
i18nc("greece_prefectures.kgm", "Igoumenitsa");
i18nc("greece_prefectures.kgm", "Karditsa");
i18nc("greece_prefectures.kgm", "Karditsa");
i18nc("greece_prefectures.kgm", "Larisa");
i18nc("greece_prefectures.kgm", "Larisa");
i18nc("greece_prefectures.kgm", "Magnesia");
i18nc("greece_prefectures.kgm", "Volos");
i18nc("greece_prefectures.kgm", "Trikala");
i18nc("greece_prefectures.kgm", "Trikala");
i18nc("greece_prefectures.kgm", "Corfu");
i18nc("greece_prefectures.kgm", "Corfu");
i18nc("greece_prefectures.kgm", "Kefallinia");
i18nc("greece_prefectures.kgm", "Argostoli");
i18nc("greece_prefectures.kgm", "Lefkada");
i18nc("greece_prefectures.kgm", "Lefkada");
i18nc("greece_prefectures.kgm", "Zante");
i18nc("greece_prefectures.kgm", "Zakynthos");
i18nc("greece_prefectures.kgm", "Achaea");
i18nc("greece_prefectures.kgm", "Patras");
i18nc("greece_prefectures.kgm", "Aetolia-Acarnania");
i18nc("greece_prefectures.kgm", "Missolonghi");
i18nc("greece_prefectures.kgm", "Ileia");
i18nc("greece_prefectures.kgm", "Pyrgos");
i18nc("greece_prefectures.kgm", "Euboea");
i18nc("greece_prefectures.kgm", "Chalcis");
i18nc("greece_prefectures.kgm", "Evrytania");
i18nc("greece_prefectures.kgm", "Karpenisi");
i18nc("greece_prefectures.kgm", "Phocis");
i18nc("greece_prefectures.kgm", "Amphissa");
i18nc("greece_prefectures.kgm", "Phtiotis");
i18nc("greece_prefectures.kgm", "Lamia");
i18nc("greece_prefectures.kgm", "Boeotia");
i18nc("greece_prefectures.kgm", "Livadia");
i18nc("greece_prefectures.kgm", "Athens");
i18nc("greece_prefectures.kgm", "Athens");
i18nc("greece_prefectures.kgm", "Piraeus");
i18nc("greece_prefectures.kgm", "Piraeus");
i18nc("greece_prefectures.kgm", "West Attica");
i18nc("greece_prefectures.kgm", "Elefsina");
i18nc("greece_prefectures.kgm", "East Attica");
i18nc("greece_prefectures.kgm", "Pallini");
i18nc("greece_prefectures.kgm", "Arcadia");
i18nc("greece_prefectures.kgm", "Tripoli");
i18nc("greece_prefectures.kgm", "Argolis");
i18nc("greece_prefectures.kgm", "Nauplie");
i18nc("greece_prefectures.kgm", "Corinthia");
i18nc("greece_prefectures.kgm", "Corinthe");
i18nc("greece_prefectures.kgm", "Laconia");
i18nc("greece_prefectures.kgm", "Sparte");
i18nc("greece_prefectures.kgm", "Messinia");
i18nc("greece_prefectures.kgm", "Kalamata");
i18nc("greece_prefectures.kgm", "Chios");
i18nc("greece_prefectures.kgm", "Chios");
i18nc("greece_prefectures.kgm", "Lesbos");
i18nc("greece_prefectures.kgm", "Mytilene");
i18nc("greece_prefectures.kgm", "Samos");
i18nc("greece_prefectures.kgm", "Samos");
i18nc("greece_prefectures.kgm", "Cyclades");
i18nc("greece_prefectures.kgm", "Ermoupoli");
i18nc("greece_prefectures.kgm", "Dodecanese");
i18nc("greece_prefectures.kgm", "Rhodes");
i18nc("greece_prefectures.kgm", "Chania");
i18nc("greece_prefectures.kgm", "Chania");
i18nc("greece_prefectures.kgm", "Heraklion");
i18nc("greece_prefectures.kgm", "Iraklio");
i18nc("greece_prefectures.kgm", "Lasithi");
i18nc("greece_prefectures.kgm", "Nikolaos");
i18nc("greece_prefectures.kgm", "Rethymnon");
i18nc("greece_prefectures.kgm", "Rethymno");
i18nc("greece_prefectures.kgm", "Mont Athos autonomous region");
i18nc("greece_prefectures.kgm", "Karyes");
i18nc("guatemala.kgm", "Guatemala");
i18nc("guatemala.kgm", "Departments");
i18nc("guatemala.kgm", "Frontier");
i18nc("guatemala.kgm", "Frontier");
i18nc("guatemala.kgm", "Water");
i18nc("guatemala.kgm", "Not Guatemala");
i18nc("guatemala.kgm", "Alta Verapaz");
i18nc("guatemala.kgm", "Cobán");
i18nc("guatemala.kgm", "Baja Verapaz");
i18nc("guatemala.kgm", "Salamá");
i18nc("guatemala.kgm", "Chimaltenango");
i18nc("guatemala.kgm", "Chimaltenango");
i18nc("guatemala.kgm", "Chiquimula");
i18nc("guatemala.kgm", "Chiquimula");
i18nc("guatemala.kgm", "Petén");
i18nc("guatemala.kgm", "Flores");
i18nc("guatemala.kgm", "El Progreso");
i18nc("guatemala.kgm", "Guastatoya");
i18nc("guatemala.kgm", "El Quiché");
i18nc("guatemala.kgm", "Santa Cruz del Quiché");
i18nc("guatemala.kgm", "Escuintla");
i18nc("guatemala.kgm", "Escuintla");
i18nc("guatemala.kgm", "Guatemala");
i18nc("guatemala.kgm", "Ciudad Guatemala");
i18nc("guatemala.kgm", "Huehuetenango");
i18nc("guatemala.kgm", "Huehuetenango");
i18nc("guatemala.kgm", "Izabal");
i18nc("guatemala.kgm", "Puerto Barrios");
i18nc("guatemala.kgm", "Jalapa");
i18nc("guatemala.kgm", "Jalapa");
i18nc("guatemala.kgm", "Jutiapa");
i18nc("guatemala.kgm", "Jutiapa");
i18nc("guatemala.kgm", "Quetzaltenango");
i18nc("guatemala.kgm", "Quetzaltenango");
i18nc("guatemala.kgm", "Retalhuleu");
i18nc("guatemala.kgm", "Retalhuleu");
i18nc("guatemala.kgm", "Sacatepéquez");
i18nc("guatemala.kgm", "Antigua Guatemala");
i18nc("guatemala.kgm", "San Marcos");
i18nc("guatemala.kgm", "San Marcos");
i18nc("guatemala.kgm", "Santa Rosa");
i18nc("guatemala.kgm", "Cuilapa");
i18nc("guatemala.kgm", "Sololá");
i18nc("guatemala.kgm", "Sololá");
i18nc("guatemala.kgm", "Suchitepéquez");
i18nc("guatemala.kgm", "Mazatenango");
i18nc("guatemala.kgm", "Totonicapán");
i18nc("guatemala.kgm", "Totonicapán");
i18nc("guatemala.kgm", "Zacapa");
i18nc("guatemala.kgm", "Zacapa");
i18nc("gujarat.kgm", "Gujarat");
i18nc("gujarat.kgm", "District");
i18nc("gujarat.kgm", "Not Gujarat");
i18nc("gujarat.kgm", "Frontier");
i18nc("gujarat.kgm", "Kutch / Kachchh");
i18nc("gujarat.kgm", "Bhuj");
i18nc("gujarat.kgm", "Banaskantha");
i18nc("gujarat.kgm", "Palanpur");
i18nc("gujarat.kgm", "Patan");
i18nc("gujarat.kgm", "Patan");
i18nc("gujarat.kgm", "Mehsana");
i18nc("gujarat.kgm", "Mehsana");
i18nc("gujarat.kgm", "Sabarkantha");
i18nc("gujarat.kgm", "Himmatnagar");
i18nc("gujarat.kgm", "Gandhinagar");
i18nc("gujarat.kgm", "Gandhinagar");
i18nc("gujarat.kgm", "Surendranagar");
i18nc("gujarat.kgm", "Surendranagar");
i18nc("gujarat.kgm", "Ahmedabad");
i18nc("gujarat.kgm", "Ahmedabad");
i18nc("gujarat.kgm", "Kheda");
i18nc("gujarat.kgm", "Kheda");
i18nc("gujarat.kgm", "Panch Mahal / Panchmahal");
i18nc("gujarat.kgm", "Godhra");
i18nc("gujarat.kgm", "Dahod");
i18nc("gujarat.kgm", "Dahod");
i18nc("gujarat.kgm", "Jamnagar");
i18nc("gujarat.kgm", "Jamnagar");
i18nc("gujarat.kgm", "Rajkot");
i18nc("gujarat.kgm", "Rajkot");
i18nc("gujarat.kgm", "Junagadh");
i18nc("gujarat.kgm", "Junagadh");
i18nc("gujarat.kgm", "Amreli");
i18nc("gujarat.kgm", "Amreli");
i18nc("gujarat.kgm", "Bhavnagar");
i18nc("gujarat.kgm", "Bhavnagar");
i18nc("gujarat.kgm", "Anand");
i18nc("gujarat.kgm", "Anand");
i18nc("gujarat.kgm", "Vadodara");
i18nc("gujarat.kgm", "Vadodara");
i18nc("gujarat.kgm", "Bharuch");
i18nc("gujarat.kgm", "Bharuch");
i18nc("gujarat.kgm", "Narmada");
i18nc("gujarat.kgm", "Rajpipla");
i18nc("gujarat.kgm", "Surat");
i18nc("gujarat.kgm", "Surat");
i18nc("gujarat.kgm", "Tapi");
i18nc("gujarat.kgm", "Vyara");
i18nc("gujarat.kgm", "The Dangs / Dang");
i18nc("gujarat.kgm", "Ahwa");
i18nc("gujarat.kgm", "Navsari");
i18nc("gujarat.kgm", "Navsari");
i18nc("gujarat.kgm", "Valsad");
i18nc("gujarat.kgm", "Valsad");
i18nc("gujarat.kgm", "Porbandar");
i18nc("gujarat.kgm", "Porbandar");
i18nc("guyana.kgm", "Guyana");
i18nc("guyana.kgm", "Provinces");
i18nc("guyana.kgm", "Frontier");
i18nc("guyana.kgm", "Frontier");
i18nc("guyana.kgm", "Water");
i18nc("guyana.kgm", "Not Guyana");
i18nc("guyana.kgm", "Barima-Waini");
i18nc("guyana.kgm", "Mabaruma");
i18nc("guyana.kgm", "Pomeroon-Supenaam");
i18nc("guyana.kgm", "Anna Regina");
i18nc("guyana.kgm", "Essequibo Islands-West Demerara");
i18nc("guyana.kgm", "Vreed en Hoop");
i18nc("guyana.kgm", "Demerara-Mahaica");
i18nc("guyana.kgm", "Paradise");
i18nc("guyana.kgm", "Mahaica-Berbice");
i18nc("guyana.kgm", "Fort Wellington");
i18nc("guyana.kgm", "Upper Demerara-Berbice");
i18nc("guyana.kgm", "Linden");
i18nc("guyana.kgm", "Cuyuni-Mazaruni");
i18nc("guyana.kgm", "Bartica");
i18nc("guyana.kgm", "Potaro-Siparuni");
i18nc("guyana.kgm", "Mahdia");
i18nc("guyana.kgm", "Upper Takutu-Upper Essequibo");
i18nc("guyana.kgm", "Lethem");
i18nc("guyana.kgm", "East Berbice-Corentyne");
i18nc("guyana.kgm", "New Amsterdam");
i18nc("haiti.kgm", "Haiti");
i18nc("haiti.kgm", "Departments");
i18nc("haiti.kgm", "Frontier");
i18nc("haiti.kgm", "Frontier");
i18nc("haiti.kgm", "Water");
i18nc("haiti.kgm", "Not Haiti");
i18nc("haiti.kgm", "Artibonite");
i18nc("haiti.kgm", "Les Gonaïves");
i18nc("haiti.kgm", "Centre");
i18nc("haiti.kgm", "Hinche");
i18nc("haiti.kgm", "Grand'Anse");
i18nc("haiti.kgm", "Jérémie");
i18nc("haiti.kgm", "Nippes");
i18nc("haiti.kgm", "Miragoâne");
i18nc("haiti.kgm", "Nord");
i18nc("haiti.kgm", "Cap-Haïtien");
i18nc("haiti.kgm", "Nord-Est");
i18nc("haiti.kgm", "Fort-Liberté");
i18nc("haiti.kgm", "Nord-Ouest");
i18nc("haiti.kgm", "Port-de-Paix");
i18nc("haiti.kgm", "Ouest");
i18nc("haiti.kgm", "Port-au-Prince");
i18nc("haiti.kgm", "Sud");
i18nc("haiti.kgm", "Les Cayes");
i18nc("haiti.kgm", "Sud-Est");
i18nc("haiti.kgm", "Jacmel");
i18nc("haryana.kgm", "Haryana");
i18nc("haryana.kgm", "District");
i18nc("haryana.kgm", "Not Haryana");
i18nc("haryana.kgm", "Frontier");
i18nc("haryana.kgm", "Chandigarh");
i18nc("haryana.kgm", "Chandigarh");
i18nc("haryana.kgm", "Panchkula");
i18nc("haryana.kgm", "Panchkula");
i18nc("haryana.kgm", "Ambala");
i18nc("haryana.kgm", "Ambala");
i18nc("haryana.kgm", "Yamuna Nagar");
i18nc("haryana.kgm", "Yamuna Nagar");
i18nc("haryana.kgm", "Kurukshetra");
i18nc("haryana.kgm", "Kurukshetra");
i18nc("haryana.kgm", "Karnal");
i18nc("haryana.kgm", "Karnal");
i18nc("haryana.kgm", "Kaithal");
i18nc("haryana.kgm", "Kaithal");
i18nc("haryana.kgm", "Jind");
i18nc("haryana.kgm", "Jind");
i18nc("haryana.kgm", "Panipat");
i18nc("haryana.kgm", "Panipat");
i18nc("haryana.kgm", "Sonipat");
i18nc("haryana.kgm", "Sonipat");
i18nc("haryana.kgm", "Faridabad");
i18nc("haryana.kgm", "Faridabad");
i18nc("haryana.kgm", "Mewat");
i18nc("haryana.kgm", "Nuh");
i18nc("haryana.kgm", "Gurgaon");
i18nc("haryana.kgm", "Gurgaon");
i18nc("haryana.kgm", "Rewari");
i18nc("haryana.kgm", "Rewari");
i18nc("haryana.kgm", "Mahendragarh");
i18nc("haryana.kgm", "Narnaul");
i18nc("haryana.kgm", "Jhajjar");
i18nc("haryana.kgm", "Jhajjar");
i18nc("haryana.kgm", "Bhiwani");
i18nc("haryana.kgm", "Bhiwani");
i18nc("haryana.kgm", "Rohtak");
i18nc("haryana.kgm", "Rohtak");
i18nc("haryana.kgm", "Hisar");
i18nc("haryana.kgm", "Hisar");
i18nc("haryana.kgm", "Sirsa");
i18nc("haryana.kgm", "Sirsa");
i18nc("haryana.kgm", "Fatehabad");
i18nc("haryana.kgm", "Fatehabad");
i18nc("haryana.kgm", "Palwal");
i18nc("haryana.kgm", "Palwal");
i18nc("himachal_pradesh.kgm", "Himachal Pradesh");
i18nc("himachal_pradesh.kgm", "District");
i18nc("himachal_pradesh.kgm", "Water");
i18nc("himachal_pradesh.kgm", "Border");
i18nc("himachal_pradesh.kgm", "Chamba");
i18nc("himachal_pradesh.kgm", "Chamba");
i18nc("himachal_pradesh.kgm", "Kangra");
i18nc("himachal_pradesh.kgm", "Dharamsala");
i18nc("himachal_pradesh.kgm", "Una");
i18nc("himachal_pradesh.kgm", "Una");
i18nc("himachal_pradesh.kgm", "Hamirpur");
i18nc("himachal_pradesh.kgm", "Hamirpur");
i18nc("himachal_pradesh.kgm", "Bilaspur");
i18nc("himachal_pradesh.kgm", "Bilaspur");
i18nc("himachal_pradesh.kgm", "Solan");
i18nc("himachal_pradesh.kgm", "Solan");
i18nc("himachal_pradesh.kgm", "Shimla");
i18nc("himachal_pradesh.kgm", "Shimla");
i18nc("himachal_pradesh.kgm", "Mandi");
i18nc("himachal_pradesh.kgm", "Mandi");
i18nc("himachal_pradesh.kgm", "Kullu");
i18nc("himachal_pradesh.kgm", "Kullu");
i18nc("himachal_pradesh.kgm", "Lahaul and Spiti");
i18nc("himachal_pradesh.kgm", "Kyelang");
i18nc("himachal_pradesh.kgm", "Sirmaur");
i18nc("himachal_pradesh.kgm", "Sirmaur");
i18nc("himachal_pradesh.kgm", "Kinnaur");
i18nc("himachal_pradesh.kgm", "Reckong Peo");
i18nc("honduras.kgm", "Honduras");
i18nc("honduras.kgm", "Departments");
i18nc("honduras.kgm", "Frontier");
i18nc("honduras.kgm", "Frontier");
i18nc("honduras.kgm", "Water");
i18nc("honduras.kgm", "Not Honduras");
i18nc("honduras.kgm", "Atlántida");
i18nc("honduras.kgm", "La Ceiba");
i18nc("honduras.kgm", "Choluteca");
i18nc("honduras.kgm", "Choluteca");
i18nc("honduras.kgm", "Colón");
i18nc("honduras.kgm", "Trujillo");
i18nc("honduras.kgm", "Comayagua");
i18nc("honduras.kgm", "Comayagua");
i18nc("honduras.kgm", "Copán");
i18nc("honduras.kgm", "Santa Rosa de Copán");
i18nc("honduras.kgm", "Cortés");
i18nc("honduras.kgm", "San Pedro Sula");
i18nc("honduras.kgm", "El Paraíso");
i18nc("honduras.kgm", "Yuscarán");
i18nc("honduras.kgm", "Francisco Morazán");
i18nc("honduras.kgm", "Tegucigalpa");
i18nc("honduras.kgm", "Gracias a Dios");
i18nc("honduras.kgm", "Puerto Lempira");
i18nc("honduras.kgm", "Intibucá");
i18nc("honduras.kgm", "La Esperanza");
i18nc("honduras.kgm", "Islas de la Bahía");
i18nc("honduras.kgm", "Roatán");
i18nc("honduras.kgm", "La Paz");
i18nc("honduras.kgm", "La Paz");
i18nc("honduras.kgm", "Lempira");
i18nc("honduras.kgm", "Gracias");
i18nc("honduras.kgm", "Ocotepeque");
i18nc("honduras.kgm", "Nueva Octopeque");
i18nc("honduras.kgm", "Olancho");
i18nc("honduras.kgm", "Juticalpa");
i18nc("honduras.kgm", "Santa Bárbara");
i18nc("honduras.kgm", "Santa Bárbara");
i18nc("honduras.kgm", "Valle");
i18nc("honduras.kgm", "Nacaome");
i18nc("honduras.kgm", "Yoro");
i18nc("honduras.kgm", "Yoro");
i18nc("hungary.kgm", "Hungary (Counties)");
i18nc("hungary.kgm", "Counties");
i18nc("hungary.kgm", "Frontier");
i18nc("hungary.kgm", "Frontier");
i18nc("hungary.kgm", "Not Hungary");
i18nc("hungary.kgm", "Bács-Kiskun");
i18nc("hungary.kgm", "Kecskemét");
i18nc("hungary.kgm", "Baranya");
i18nc("hungary.kgm", "Pécs");
i18nc("hungary.kgm", "Békés");
i18nc("hungary.kgm", "Békéscsaba");
i18nc("hungary.kgm", "Borsod-Abaúj-Zemplén");
i18nc("hungary.kgm", "Miskolc");
i18nc("hungary.kgm", "Csongrád");
i18nc("hungary.kgm", "Szeged");
i18nc("hungary.kgm", "Fejér");
i18nc("hungary.kgm", "Székesfehérvár");
i18nc("hungary.kgm", "Győr-Moson-Sopron");
i18nc("hungary.kgm", "Győr");
i18nc("hungary.kgm", "Hajdú-Bihar");
i18nc("hungary.kgm", "Debrecen");
i18nc("hungary.kgm", "Heves");
i18nc("hungary.kgm", "Eger");
i18nc("hungary.kgm", "Jász-Nagykun-Szolnok");
i18nc("hungary.kgm", "Szolnok");
i18nc("hungary.kgm", "Komárom-Esztergom");
i18nc("hungary.kgm", "Tatabánya");
i18nc("hungary.kgm", "Nógrád");
i18nc("hungary.kgm", "Salgótarján");
i18nc("hungary.kgm", "Pest");
i18nc("hungary.kgm", "Budapest");
i18nc("hungary.kgm", "Somogy");
i18nc("hungary.kgm", "Kaposvár");
i18nc("hungary.kgm", "Szabolcs-Szatmár-Bereg");
i18nc("hungary.kgm", "Nyíregyháza");
i18nc("hungary.kgm", "Tolna");
i18nc("hungary.kgm", "Szekszárd");
i18nc("hungary.kgm", "Vas");
i18nc("hungary.kgm", "Szombathely");
i18nc("hungary.kgm", "Veszprém");
i18nc("hungary.kgm", "Veszprém");
i18nc("hungary.kgm", "Zala");
i18nc("hungary.kgm", "Zalaegerszeg");
i18nc("hungary.kgm", "Budapest");
i18nc("hungary_regions.kgm", "Hungary (Regions)");
i18nc("hungary_regions.kgm", "Regions");
i18nc("hungary_regions.kgm", "Frontier");
i18nc("hungary_regions.kgm", "Frontier");
i18nc("hungary_regions.kgm", "Not Hungary (Regions)");
i18nc("hungary_regions.kgm", "Western Transdanubia");
i18nc("hungary_regions.kgm", "Győr");
i18nc("hungary_regions.kgm", "Southern Transdanubia");
i18nc("hungary_regions.kgm", "Pécs");
i18nc("hungary_regions.kgm", "Central Transdanubia");
i18nc("hungary_regions.kgm", "Székesfehérvár");
i18nc("hungary_regions.kgm", "Central Hungary");
i18nc("hungary_regions.kgm", "Budapest");
i18nc("hungary_regions.kgm", "Northern Hungary");
i18nc("hungary_regions.kgm", "Miskolc");
i18nc("hungary_regions.kgm", "Northern Great Plain");
i18nc("hungary_regions.kgm", "Debrecen");
i18nc("hungary_regions.kgm", "Southern Great Plain");
i18nc("hungary_regions.kgm", "Szeged");
i18nc("iceland_regions.kgm", "Iceland (Regions)");
i18nc("iceland_regions.kgm", "Regions");
i18nc("iceland_regions.kgm", "Frontier");
i18nc("iceland_regions.kgm", "Frontier");
i18nc("iceland_regions.kgm", "Not Iceland (Regions)");
i18nc("iceland_regions.kgm", "East Region");
i18nc("iceland_regions.kgm", "Egilsstaðir");
i18nc("iceland_regions.kgm", "Capital Region");
i18nc("iceland_regions.kgm", "Reykjavík");
i18nc("iceland_regions.kgm", "Northeast Region");
i18nc("iceland_regions.kgm", "Akureyri");
i18nc("iceland_regions.kgm", "Northwest Region");
i18nc("iceland_regions.kgm", "Sauðárkrókur");
i18nc("iceland_regions.kgm", "South Region");
i18nc("iceland_regions.kgm", "Selfoss");
i18nc("iceland_regions.kgm", "Southern Peninsula");
i18nc("iceland_regions.kgm", "Keflavík");
i18nc("iceland_regions.kgm", "Westfjords");
i18nc("iceland_regions.kgm", "Ísafjörður");
i18nc("iceland_regions.kgm", "West Region");
i18nc("iceland_regions.kgm", "Borgarnes");
i18nc("iceland_regions.kgm", "Vatnajökull Glacier");
i18nc("iceland_regions.kgm", "Langjökull Glacier");
i18nc("iceland_regions.kgm", "Hofsjökull Glacier");
i18nc("iceland_regions.kgm", "Mýrdalsjökull Glacier");
i18nc("iceland_regions.kgm", "Drangajökull Glacier");
i18nc("india.kgm", "India");
i18nc("india.kgm", "States and Territories");
i18nc("india.kgm", "Frontier");
i18nc("india.kgm", "Water");
i18nc("india.kgm", "Not India");
i18nc("india.kgm", "Andhra Pradesh");
i18nc("india.kgm", "Hyderabad");
i18nc("india.kgm", "Arunachal Pradesh");
i18nc("india.kgm", "Itanagar");
i18nc("india.kgm", "Assam");
i18nc("india.kgm", "Dispur");
i18nc("india.kgm", "Bihar");
i18nc("india.kgm", "Patna");
i18nc("india.kgm", "Chhatisgarh");
i18nc("india.kgm", "Raipur");
i18nc("india.kgm", "Goa");
i18nc("india.kgm", "Panaji");
i18nc("india.kgm", "Gujarat");
i18nc("india.kgm", "Gandhinagar");
i18nc("india.kgm", "Haryana");
i18nc("india.kgm", "Himachal Pradesh");
i18nc("india.kgm", "Shimla");
i18nc("india.kgm", "Jammu and Kashmir");
i18nc("india.kgm", "Srinagar");
i18nc("india.kgm", "Jharkhand");
i18nc("india.kgm", "Ranchi");
i18nc("india.kgm", "Karnataka");
i18nc("india.kgm", "Bangalore");
i18nc("india.kgm", "Kerala");
i18nc("india.kgm", "Thiruvananthapuram");
i18nc("india.kgm", "Madhya Pradesh");
i18nc("india.kgm", "Bhopal");
i18nc("india.kgm", "Maharashtra");
i18nc("india.kgm", "Mumbai");
i18nc("india.kgm", "Manipur");
i18nc("india.kgm", "Imphal");
i18nc("india.kgm", "Meghalaya");
i18nc("india.kgm", "Shillong");
i18nc("india.kgm", "Mizoram");
i18nc("india.kgm", "Aizawl");
i18nc("india.kgm", "Nagaland");
i18nc("india.kgm", "Kohima");
i18nc("india.kgm", "Orissa");
i18nc("india.kgm", "Bhubaneswar");
i18nc("india.kgm", "Punjab");
i18nc("india.kgm", "Rajasthan");
i18nc("india.kgm", "Jaipur");
i18nc("india.kgm", "Sikkim");
i18nc("india.kgm", "Gangtok");
i18nc("india.kgm", "Tamil Nadu");
i18nc("india.kgm", "Chennai");
i18nc("india.kgm", "Tripura");
i18nc("india.kgm", "Agartala");
i18nc("india.kgm", "Uttaranchal");
i18nc("india.kgm", "Dehradun");
i18nc("india.kgm", "Uttar Pradesh");
i18nc("india.kgm", "Lucknow");
i18nc("india.kgm", "West Bengal");
i18nc("india.kgm", "Kolkata");
i18nc("india.kgm", "Andaman and Nicobar Islands");
i18nc("india.kgm", "Port Blair");
i18nc("india.kgm", "Chandigarh");
i18nc("india.kgm", "Dadra and Nagar Haveli");
i18nc("india.kgm", "Dadra");
i18nc("india.kgm", "Daman and Diu");
i18nc("india.kgm", "Daman");
i18nc("india.kgm", "Lakshadweep");
i18nc("india.kgm", "Kavaratti");
i18nc("india.kgm", "Pondicherry");
i18nc("india.kgm", "Pondicherry");
i18nc("india.kgm", "Delhi");
i18nc("indonesia.kgm", "Indonesia");
i18nc("indonesia.kgm", "Provinces");
i18nc("indonesia.kgm", "Frontier");
i18nc("indonesia.kgm", "Water");
i18nc("indonesia.kgm", "Not Indonesia");
i18nc("indonesia.kgm", "Nanggroe Aceh Darussalam");
i18nc("indonesia.kgm", "Banda Aceh");
i18nc("indonesia.kgm", "North Sumatra");
i18nc("indonesia.kgm", "Medan");
i18nc("indonesia.kgm", "West Sumatra");
i18nc("indonesia.kgm", "Padang");
i18nc("indonesia.kgm", "Riau");
i18nc("indonesia.kgm", "Pekanbaru");
i18nc("indonesia.kgm", "Riau Islands");
i18nc("indonesia.kgm", "Tanjung Pinang");
i18nc("indonesia.kgm", "Jambi");
i18nc("indonesia.kgm", "Jambi");
i18nc("indonesia.kgm", "Bengkulu");
i18nc("indonesia.kgm", "Bengkulu");
i18nc("indonesia.kgm", "South Sumatra");
i18nc("indonesia.kgm", "Palembang");
i18nc("indonesia.kgm", "Bangka-Belitung");
i18nc("indonesia.kgm", "Pangkal Pinang");
i18nc("indonesia.kgm", "Lampung");
i18nc("indonesia.kgm", "Bandar Lampung");
i18nc("indonesia.kgm", "Jakarta Special Capital Region");
i18nc("indonesia.kgm", "Jakarta");
i18nc("indonesia.kgm", "Banten");
i18nc("indonesia.kgm", "Serang");
i18nc("indonesia.kgm", "West Java");
i18nc("indonesia.kgm", "Bandung");
i18nc("indonesia.kgm", "Central Java");
i18nc("indonesia.kgm", "Semarang");
i18nc("indonesia.kgm", "Yogyakarta Special Region");
i18nc("indonesia.kgm", "Yogyakarta");
i18nc("indonesia.kgm", "East Java");
i18nc("indonesia.kgm", "Surabaya");
i18nc("indonesia.kgm", "Bali");
i18nc("indonesia.kgm", "Denpasar");
i18nc("indonesia.kgm", "West Nusa Tenggara");
i18nc("indonesia.kgm", "Mataram");
i18nc("indonesia.kgm", "East Nusa Tenggara");
i18nc("indonesia.kgm", "Kupang");
i18nc("indonesia.kgm", "West Kalimantan");
i18nc("indonesia.kgm", "Pontianak");
i18nc("indonesia.kgm", "Central Kalimantan");
i18nc("indonesia.kgm", "Palangkaraya");
i18nc("indonesia.kgm", "South Kalimantan");
i18nc("indonesia.kgm", "Banjarmasin");
i18nc("indonesia.kgm", "East Kalimantan");
i18nc("indonesia.kgm", "Samarinda");
i18nc("indonesia.kgm", "North Sulawesi");
i18nc("indonesia.kgm", "Manado");
i18nc("indonesia.kgm", "Gorontalo");
i18nc("indonesia.kgm", "Gorontalo");
i18nc("indonesia.kgm", "Central Sulawesi");
i18nc("indonesia.kgm", "Palu");
i18nc("indonesia.kgm", "South East Sulawesi");
i18nc("indonesia.kgm", "Kendari");
i18nc("indonesia.kgm", "South Sulawesi");
i18nc("indonesia.kgm", "Makassar");
i18nc("indonesia.kgm", "West Sulawesi");
i18nc("indonesia.kgm", "Mamuju");
i18nc("indonesia.kgm", "Maluku");
i18nc("indonesia.kgm", "Ambon");
i18nc("indonesia.kgm", "North Maluku");
i18nc("indonesia.kgm", "Ternate");
i18nc("indonesia.kgm", "Papua");
i18nc("indonesia.kgm", "Jayapura");
i18nc("indonesia.kgm", "West Irian Jaya");
i18nc("indonesia.kgm", "Manokwari");
i18nc("iran.kgm", "Iran");
i18nc("iran.kgm", "Provinces");
i18nc("iran.kgm", "Frontier");
i18nc("iran.kgm", "Frontier");
i18nc("iran.kgm", "Tehran");
i18nc("iran.kgm", "Tehran");
i18nc("iran.kgm", "Alborz");
i18nc("iran.kgm", "Karaj");
i18nc("iran.kgm", "Qom");
i18nc("iran.kgm", "Qom");
i18nc("iran.kgm", "Markazi");
i18nc("iran.kgm", "Arak");
i18nc("iran.kgm", "Qazvin");
i18nc("iran.kgm", "Qazvin");
i18nc("iran.kgm", "Gilan");
i18nc("iran.kgm", "Rasht");
i18nc("iran.kgm", "Ardabil");
i18nc("iran.kgm", "Ardabil");
i18nc("iran.kgm", "Zanjan");
i18nc("iran.kgm", "Zanjan");
i18nc("iran.kgm", "East Azarbaijan");
i18nc("iran.kgm", "Tabriz");
i18nc("iran.kgm", "West Azarbaijan");
i18nc("iran.kgm", "Oroomieh");
i18nc("iran.kgm", "Kurdistan");
i18nc("iran.kgm", "Sanandaj");
i18nc("iran.kgm", "Hamedan");
i18nc("iran.kgm", "Hamedan");
i18nc("iran.kgm", "Kermanshah");
i18nc("iran.kgm", "Kermanshah");
i18nc("iran.kgm", "Ilam");
i18nc("iran.kgm", "Ilam");
i18nc("iran.kgm", "Lorestan");
i18nc("iran.kgm", "Khoram Abad");
i18nc("iran.kgm", "Khuzestan");
i18nc("iran.kgm", "Ahvaz");
i18nc("iran.kgm", "Chaharmahal and Bakhtiari");
i18nc("iran.kgm", "shahr-e Kord");
i18nc("iran.kgm", "Kohkiluyeh and Buyer Ahmah");
i18nc("iran.kgm", "Yasooj");
i18nc("iran.kgm", "Bushehr");
i18nc("iran.kgm", "Bushehr");
i18nc("iran.kgm", "Fars");
i18nc("iran.kgm", "Shiraz");
i18nc("iran.kgm", "Hormozgan");
i18nc("iran.kgm", "Bandar-e Abbas");
i18nc("iran.kgm", "Systan and Baluchistan");
i18nc("iran.kgm", "Zahedan");
i18nc("iran.kgm", "Kerman");
i18nc("iran.kgm", "Kerman");
i18nc("iran.kgm", "Yazd");
i18nc("iran.kgm", "Yazd");
i18nc("iran.kgm", "Esfahan");
i18nc("iran.kgm", "Esfahan");
i18nc("iran.kgm", "Semnan");
i18nc("iran.kgm", "Semnan");
i18nc("iran.kgm", "Mazandaran");
i18nc("iran.kgm", "Sari");
i18nc("iran.kgm", "Golestan");
i18nc("iran.kgm", "Gorgan");
i18nc("iran.kgm", "South Khorasan");
i18nc("iran.kgm", "Birjand");
i18nc("iran.kgm", "Razavi Khorasan");
i18nc("iran.kgm", "Mashhad");
i18nc("iran.kgm", "North Khorasan");
i18nc("iran.kgm", "Bojnoord");
i18nc("iran.kgm", "Persian Gulf");
i18nc("iran.kgm", "Gulf of Oman");
i18nc("iran.kgm", "Caspian Sea");
i18nc("iran.kgm", "Oroomieh Lake");
i18nc("iran.kgm", "Saudi Arabia");
i18nc("iran.kgm", "Oman");
i18nc("iran.kgm", "Iraq");
i18nc("iran.kgm", "Kuwait");
i18nc("iran.kgm", "Turkmenistan");
i18nc("iran.kgm", "Afghanistan");
i18nc("iran.kgm", "Pakistan");
i18nc("iran.kgm", "Azerbaijan");
i18nc("iran.kgm", "Armenia");
i18nc("iran.kgm", "Turkey");
i18nc("iran.kgm", "Qatar");
i18nc("iran.kgm", "United Arab Emirates");
i18nc("iraq.kgm", "Iraq");
i18nc("iraq.kgm", "Provinces");
i18nc("iraq.kgm", "Frontier");
i18nc("iraq.kgm", "Water");
i18nc("iraq.kgm", "Not Iraq");
i18nc("iraq.kgm", "Baghdad");
i18nc("iraq.kgm", "Salah ad Din");
i18nc("iraq.kgm", "Diyala");
i18nc("iraq.kgm", "Wasit");
i18nc("iraq.kgm", "Maysan");
i18nc("iraq.kgm", "Al Basrah");
i18nc("iraq.kgm", "Dhi Qar");
i18nc("iraq.kgm", "Al Muthanna");
i18nc("iraq.kgm", "Al-Qādisiyyah");
i18nc("iraq.kgm", "Babil");
i18nc("iraq.kgm", "Karbala");
i18nc("iraq.kgm", "An Najaf");
i18nc("iraq.kgm", "Al Anbar");
i18nc("iraq.kgm", "Ninawa");
i18nc("iraq.kgm", "Dahuk");
i18nc("iraq.kgm", "Arbil");
i18nc("iraq.kgm", "At Ta'mim (Kirkuk)");
i18nc("iraq.kgm", "As Sulaymaniyah");
i18nc("ireland_provinces.kgm", "Ireland (Provinces)");
i18nc("ireland_provinces.kgm", "Provinces");
i18nc("ireland_provinces.kgm", "Frontier");
i18nc("ireland_provinces.kgm", "Not Ireland (Provinces)");
i18nc("ireland_provinces.kgm", "Leinster");
i18nc("ireland_provinces.kgm", "Dublin");
i18nc("ireland_provinces.kgm", "Munster");
i18nc("ireland_provinces.kgm", "Cork");
i18nc("ireland_provinces.kgm", "Connacht");
i18nc("ireland_provinces.kgm", "Galway");
i18nc("ireland_provinces.kgm", "Ulster");
i18nc("ireland_provinces.kgm", "Belfast");
i18nc("israel.kgm", "Israel");
i18nc("israel.kgm", "Districts");
i18nc("israel.kgm", "Frontier");
i18nc("israel.kgm", "Water");
i18nc("israel.kgm", "Not Israel");
i18nc("israel.kgm", "Jerusalem");
i18nc("israel.kgm", "Northern");
i18nc("israel.kgm", "Nazareth");
i18nc("israel.kgm", "Haifa");
i18nc("israel.kgm", "Center");
i18nc("israel.kgm", "Ramla");
i18nc("israel.kgm", "Tel Aviv");
i18nc("israel.kgm", "Southern");
i18nc("israel.kgm", "Beersheba");
i18nc("italy.kgm", "Italy");
i18nc("italy.kgm", "Regions");
i18nc("italy.kgm", "Not Italy");
i18nc("italy.kgm", "Frontier");
i18nc("italy.kgm", "Frontier");
i18nc("italy.kgm", "Sicily");
i18nc("italy.kgm", "Palermo");
i18nc("italy.kgm", "Friuli Venezia Giulia");
i18nc("italy.kgm", "Trieste");
i18nc("italy.kgm", "Abruzzo");
i18nc("italy.kgm", "L'Aquila");
i18nc("italy.kgm", "Latium");
i18nc("italy.kgm", "Rome");
i18nc("italy.kgm", "Calabria");
i18nc("italy.kgm", "Catanzaro");
i18nc("italy.kgm", "Piedmont");
i18nc("italy.kgm", "Turin");
i18nc("italy.kgm", "Apulia");
i18nc("italy.kgm", "Bari");
i18nc("italy.kgm", "Lombardy");
i18nc("italy.kgm", "Milan");
i18nc("italy.kgm", "Umbria");
i18nc("italy.kgm", "Perugia");
i18nc("italy.kgm", "Trentino Alto Adige");
i18nc("italy.kgm", "Trento");
i18nc("italy.kgm", "Molise");
i18nc("italy.kgm", "Campobasso");
i18nc("italy.kgm", "Tuscany");
i18nc("italy.kgm", "Florence");
i18nc("italy.kgm", "Emilia Romagna");
i18nc("italy.kgm", "Bologna");
i18nc("italy.kgm", "Val d'Aosta");
i18nc("italy.kgm", "Aosta");
i18nc("italy.kgm", "Campania");
i18nc("italy.kgm", "Naples");
i18nc("italy.kgm", "Basilicata");
i18nc("italy.kgm", "Potenza");
i18nc("italy.kgm", "Liguria");
i18nc("italy.kgm", "Genoa");
i18nc("italy.kgm", "Sardinia");
i18nc("italy.kgm", "Cagliari");
i18nc("italy.kgm", "Marches");
i18nc("italy.kgm", "Ancona");
i18nc("italy.kgm", "Veneto");
i18nc("italy.kgm", "Venice");
i18nc("italyprovince.kgm", "Italy by Provinces");
i18nc("italyprovince.kgm", "Provinces");
i18nc("italyprovince.kgm", "Frontier");
i18nc("italyprovince.kgm", "Not Italy");
i18nc("italyprovince.kgm", "Alessandria");
i18nc("italyprovince.kgm", "Asti");
i18nc("italyprovince.kgm", "Biella");
i18nc("italyprovince.kgm", "Cuneo");
i18nc("italyprovince.kgm", "Novara");
i18nc("italyprovince.kgm", "Turin");
i18nc("italyprovince.kgm", "Verbano-Cusio-Ossola");
i18nc("italyprovince.kgm", "Vercelli");
i18nc("italyprovince.kgm", "Bergamo");
i18nc("italyprovince.kgm", "Brescia");
i18nc("italyprovince.kgm", "Como");
i18nc("italyprovince.kgm", "Cremona");
i18nc("italyprovince.kgm", "Lecco");
i18nc("italyprovince.kgm", "Lodi");
i18nc("italyprovince.kgm", "Mantova");
i18nc("italyprovince.kgm", "Milan");
i18nc("italyprovince.kgm", "Pavia");
i18nc("italyprovince.kgm", "Sondrio");
i18nc("italyprovince.kgm", "Varese");
i18nc("italyprovince.kgm", "Aosta");
i18nc("italyprovince.kgm", "Bolzano");
i18nc("italyprovince.kgm", "Trento");
i18nc("italyprovince.kgm", "Belluno");
i18nc("italyprovince.kgm", "Padova");
i18nc("italyprovince.kgm", "Rovigo");
i18nc("italyprovince.kgm", "Treviso");
i18nc("italyprovince.kgm", "Venice");
i18nc("italyprovince.kgm", "Verona");
i18nc("italyprovince.kgm", "Vicenza");
i18nc("italyprovince.kgm", "Gorizia");
i18nc("italyprovince.kgm", "Pordenone");
i18nc("italyprovince.kgm", "Trieste");
i18nc("italyprovince.kgm", "Udine");
i18nc("italyprovince.kgm", "Genoa");
i18nc("italyprovince.kgm", "Imperia");
i18nc("italyprovince.kgm", "La Spezia");
i18nc("italyprovince.kgm", "Savona");
i18nc("italyprovince.kgm", "Bologna");
i18nc("italyprovince.kgm", "Ferrara");
i18nc("italyprovince.kgm", "Forlì-Cesena");
i18nc("italyprovince.kgm", "Modena");
i18nc("italyprovince.kgm", "Parma");
i18nc("italyprovince.kgm", "Piacenza");
i18nc("italyprovince.kgm", "Ravenna");
i18nc("italyprovince.kgm", "Reggio nell'Emilia");
i18nc("italyprovince.kgm", "Rimini");
i18nc("italyprovince.kgm", "Arezzo");
i18nc("italyprovince.kgm", "Florence");
i18nc("italyprovince.kgm", "Grosseto");
i18nc("italyprovince.kgm", "Livorno");
i18nc("italyprovince.kgm", "Lucca");
i18nc("italyprovince.kgm", "Massa-Carrara");
i18nc("italyprovince.kgm", "Pisa");
i18nc("italyprovince.kgm", "Pistoia");
i18nc("italyprovince.kgm", "Prato");
i18nc("italyprovince.kgm", "Siena");
i18nc("italyprovince.kgm", "Perugia");
i18nc("italyprovince.kgm", "Terni");
i18nc("italyprovince.kgm", "Ancona");
i18nc("italyprovince.kgm", "Ascoli Piceno");
i18nc("italyprovince.kgm", "Macerata");
i18nc("italyprovince.kgm", "Pesaro and Urbino");
i18nc("italyprovince.kgm", "Frosinone");
i18nc("italyprovince.kgm", "Latina");
i18nc("italyprovince.kgm", "Rieti");
i18nc("italyprovince.kgm", "Rome");
i18nc("italyprovince.kgm", "Viterbo");
i18nc("italyprovince.kgm", "Chieti");
i18nc("italyprovince.kgm", "L'Aquila");
i18nc("italyprovince.kgm", "Pescara");
i18nc("italyprovince.kgm", "Teramo");
i18nc("italyprovince.kgm", "Campobasso");
i18nc("italyprovince.kgm", "Isernia");
i18nc("italyprovince.kgm", "Avellino");
i18nc("italyprovince.kgm", "Benevento");
i18nc("italyprovince.kgm", "Caserta");
i18nc("italyprovince.kgm", "Naples");
i18nc("italyprovince.kgm", "Salerno");
i18nc("italyprovince.kgm", "Bari");
i18nc("italyprovince.kgm", "Brindisi");
i18nc("italyprovince.kgm", "Foggia");
i18nc("italyprovince.kgm", "Lecce");
i18nc("italyprovince.kgm", "Taranto");
i18nc("italyprovince.kgm", "Matera");
i18nc("italyprovince.kgm", "Potenza");
i18nc("italyprovince.kgm", "Catanzaro");
i18nc("italyprovince.kgm", "Cosenza");
i18nc("italyprovince.kgm", "Crotone");
i18nc("italyprovince.kgm", "Reggio di Calabria");
i18nc("italyprovince.kgm", "Vibo Valentia");
i18nc("italyprovince.kgm", "Agrigento");
i18nc("italyprovince.kgm", "Caltanissetta");
i18nc("italyprovince.kgm", "Catania");
i18nc("italyprovince.kgm", "Enna");
i18nc("italyprovince.kgm", "Messina");
i18nc("italyprovince.kgm", "Palermo");
i18nc("italyprovince.kgm", "Ragusa");
i18nc("italyprovince.kgm", "Syracuse");
i18nc("italyprovince.kgm", "Trapani");
i18nc("italyprovince.kgm", "Cagliari");
i18nc("italyprovince.kgm", "Nuoro");
i18nc("italyprovince.kgm", "Oristano");
i18nc("italyprovince.kgm", "Sassari");
i18nc("jamaica.kgm", "Jamaica");
i18nc("jamaica.kgm", "Parishes");
i18nc("jamaica.kgm", "Frontier");
i18nc("jamaica.kgm", "Frontier");
i18nc("jamaica.kgm", "Not Jamaica");
i18nc("jamaica.kgm", "Kingston");
i18nc("jamaica.kgm", "Kingston");
i18nc("jamaica.kgm", "Portland");
i18nc("jamaica.kgm", "Port Antonio");
i18nc("jamaica.kgm", "Saint Andrew");
i18nc("jamaica.kgm", "Half Way Tree");
i18nc("jamaica.kgm", "Saint Thomas");
i18nc("jamaica.kgm", "Morant Bay");
i18nc("jamaica.kgm", "Clarendon");
i18nc("jamaica.kgm", "May Pen");
i18nc("jamaica.kgm", "Manchester");
i18nc("jamaica.kgm", "Mandeville");
i18nc("jamaica.kgm", "Saint Ann");
i18nc("jamaica.kgm", "Saint Ann's Bay");
i18nc("jamaica.kgm", "Saint Catherine");
i18nc("jamaica.kgm", "Spanish Town");
i18nc("jamaica.kgm", "Saint Mary");
i18nc("jamaica.kgm", "Port Maria");
i18nc("jamaica.kgm", "Hanover");
i18nc("jamaica.kgm", "Lucea");
i18nc("jamaica.kgm", "Saint Elizabeth");
i18nc("jamaica.kgm", "Black River");
i18nc("jamaica.kgm", "Saint James");
i18nc("jamaica.kgm", "Montego Bay");
i18nc("jamaica.kgm", "Trelawny");
i18nc("jamaica.kgm", "Falmouth");
i18nc("jamaica.kgm", "Westmoreland");
i18nc("jamaica.kgm", "Savanna-la-Mar");
i18nc("japan.kgm", "Japan");
i18nc("japan.kgm", "Prefectures");
i18nc("japan.kgm", "Out of Bounds");
i18nc("japan.kgm", "Border");
i18nc("japan.kgm", "Hokkaido");
i18nc("japan.kgm", "Sapporo");
i18nc("japan.kgm", "Aomori");
i18nc("japan.kgm", "Aomori");
i18nc("japan.kgm", "Iwate");
i18nc("japan.kgm", "Morioka");
i18nc("japan.kgm", "Akita");
i18nc("japan.kgm", "Akita");
i18nc("japan.kgm", "Yamagata");
i18nc("japan.kgm", "Yamagata");
i18nc("japan.kgm", "Miyagi");
i18nc("japan.kgm", "Sendai");
i18nc("japan.kgm", "Niigata");
i18nc("japan.kgm", "Niigata");
i18nc("japan.kgm", "Fukushima");
i18nc("japan.kgm", "Fukushima");
i18nc("japan.kgm", "Nagano");
i18nc("japan.kgm", "Nagano");
i18nc("japan.kgm", "Gunma");
i18nc("japan.kgm", "Maebashi");
i18nc("japan.kgm", "Tochigi");
i18nc("japan.kgm", "Utsunomiya");
i18nc("japan.kgm", "Ibaraki");
i18nc("japan.kgm", "Mito");
i18nc("japan.kgm", "Chiba");
i18nc("japan.kgm", "Chiba");
i18nc("japan.kgm", "Gifu");
i18nc("japan.kgm", "Gifu");
i18nc("japan.kgm", "Shizuoka");
i18nc("japan.kgm", "Shizuoka");
i18nc("japan.kgm", "Saitama");
i18nc("japan.kgm", "Saitama");
i18nc("japan.kgm", "Yamanashi");
i18nc("japan.kgm", "Koufu");
i18nc("japan.kgm", "Toyama");
i18nc("japan.kgm", "Toyama");
i18nc("japan.kgm", "Ishikawa");
i18nc("japan.kgm", "Kanazawa");
i18nc("japan.kgm", "Aichi");
i18nc("japan.kgm", "Nagoya");
i18nc("japan.kgm", "Fukui");
i18nc("japan.kgm", "Fukui");
i18nc("japan.kgm", "Shiga");
i18nc("japan.kgm", "Otsu");
i18nc("japan.kgm", "Mie");
i18nc("japan.kgm", "Tsu");
i18nc("japan.kgm", "Kyoto");
i18nc("japan.kgm", "Kyoto");
i18nc("japan.kgm", "Hyogo");
i18nc("japan.kgm", "Kobe");
i18nc("japan.kgm", "Nara");
i18nc("japan.kgm", "Nara");
i18nc("japan.kgm", "Osaka");
i18nc("japan.kgm", "Osaka");
i18nc("japan.kgm", "Wakayama");
i18nc("japan.kgm", "Wakayama");
i18nc("japan.kgm", "Okayama");
i18nc("japan.kgm", "Okayama");
i18nc("japan.kgm", "Tottori");
i18nc("japan.kgm", "Tottori");
i18nc("japan.kgm", "Shimane");
i18nc("japan.kgm", "Matsue");
i18nc("japan.kgm", "Hiroshima");
i18nc("japan.kgm", "Hiroshima");
i18nc("japan.kgm", "Yamaguchi");
i18nc("japan.kgm", "Yamaguchi");
i18nc("japan.kgm", "Fukuoka");
i18nc("japan.kgm", "Fukuoka");
i18nc("japan.kgm", "Oita");
i18nc("japan.kgm", "Oita");
i18nc("japan.kgm", "Miyazaki");
i18nc("japan.kgm", "Miyazaki");
i18nc("japan.kgm", "Kagoshima");
i18nc("japan.kgm", "Kagoshima");
i18nc("japan.kgm", "Kumamoto");
i18nc("japan.kgm", "Kumamoto");
i18nc("japan.kgm", "Saga");
i18nc("japan.kgm", "Saga");
i18nc("japan.kgm", "Nagasaki");
i18nc("japan.kgm", "Nagasaki");
i18nc("japan.kgm", "Ehime");
i18nc("japan.kgm", "Matsuyama");
i18nc("japan.kgm", "Kochi");
i18nc("japan.kgm", "Kochi");
i18nc("japan.kgm", "Tokushima");
i18nc("japan.kgm", "Tokushima");
i18nc("japan.kgm", "Kagawa");
i18nc("japan.kgm", "Takamatsu");
i18nc("japan.kgm", "Kanagawa");
i18nc("japan.kgm", "Yokohama");
i18nc("japan.kgm", "Tokyo");
i18nc("japan.kgm", "Tokyo");
i18nc("japan.kgm", "Okinawa");
i18nc("japan.kgm", "Naha");
i18nc("jharkhand.kgm", "Jharkhand");
i18nc("jharkhand.kgm", "District");
i18nc("jharkhand.kgm", "Not Jharkhand");
i18nc("jharkhand.kgm", "Frontier");
i18nc("jharkhand.kgm", "Garhwa");
i18nc("jharkhand.kgm", "Garhwa");
i18nc("jharkhand.kgm", "Latehar");
i18nc("jharkhand.kgm", "Latehar");
i18nc("jharkhand.kgm", "Gumla");
i18nc("jharkhand.kgm", "Gumla");
i18nc("jharkhand.kgm", "Lohardaga");
i18nc("jharkhand.kgm", "Lohardaga");
i18nc("jharkhand.kgm", "Simdega");
i18nc("jharkhand.kgm", "Simdega");
i18nc("jharkhand.kgm", "Paschim Singhbhum");
i18nc("jharkhand.kgm", "Chaibasa");
i18nc("jharkhand.kgm", "Ranchi");
i18nc("jharkhand.kgm", "Ranchi");
i18nc("jharkhand.kgm", "Seraikela");
i18nc("jharkhand.kgm", "Seraikela");
i18nc("jharkhand.kgm", "Purba Singhbhum");
i18nc("jharkhand.kgm", "Jamshedpur");
i18nc("jharkhand.kgm", "Hazaribag");
i18nc("jharkhand.kgm", "Hazaribag");
i18nc("jharkhand.kgm", "Koderma");
i18nc("jharkhand.kgm", "Koderma");
i18nc("jharkhand.kgm", "Giridih");
i18nc("jharkhand.kgm", "Giridih");
i18nc("jharkhand.kgm", "Bokaro");
i18nc("jharkhand.kgm", "Bokaro");
i18nc("jharkhand.kgm", "Dhanbad");
i18nc("jharkhand.kgm", "Dhanbad");
i18nc("jharkhand.kgm", "Jamtara");
i18nc("jharkhand.kgm", "Jamtara");
i18nc("jharkhand.kgm", "Deoghar");
i18nc("jharkhand.kgm", "Deoghar");
i18nc("jharkhand.kgm", "Santhal Pargana");
i18nc("jharkhand.kgm", "Dumka");
i18nc("jharkhand.kgm", "Pakur");
i18nc("jharkhand.kgm", "Pakur");
i18nc("jharkhand.kgm", "Sahibganj");
i18nc("jharkhand.kgm", "Sahibganj");
i18nc("jharkhand.kgm", "Godda");
i18nc("jharkhand.kgm", "Godda");
i18nc("jharkhand.kgm", "Palamu");
i18nc("jharkhand.kgm", "Daltonganj");
i18nc("jharkhand.kgm", "Chatra");
i18nc("jharkhand.kgm", "Chatra");
i18nc("kazakhstan.kgm", "Kazakhstan");
i18nc("kazakhstan.kgm", "Provinces");
i18nc("kazakhstan.kgm", "Frontier");
i18nc("kazakhstan.kgm", "Water");
i18nc("kazakhstan.kgm", "Not Kazakhstan");
i18nc("kazakhstan.kgm", "Astana");
i18nc("kazakhstan.kgm", "Almaty city");
i18nc("kazakhstan.kgm", "Baikonur");
i18nc("kazakhstan.kgm", "Almaty");
i18nc("kazakhstan.kgm", "Taldykorgan");
i18nc("kazakhstan.kgm", "Aqmola");
i18nc("kazakhstan.kgm", "Koksetau");
i18nc("kazakhstan.kgm", "Aqtöbe");
i18nc("kazakhstan.kgm", "Aqtöbe");
i18nc("kazakhstan.kgm", "Atyrau");
i18nc("kazakhstan.kgm", "Atyrau");
i18nc("kazakhstan.kgm", "Batys Qazaqstan");
i18nc("kazakhstan.kgm", "Oral");
i18nc("kazakhstan.kgm", "Mangghystau");
i18nc("kazakhstan.kgm", "Aqtau");
i18nc("kazakhstan.kgm", "Ongtüstik Qazaqstan");
i18nc("kazakhstan.kgm", "Shymkent");
i18nc("kazakhstan.kgm", "Pavlodar");
i18nc("kazakhstan.kgm", "Pavlodar");
i18nc("kazakhstan.kgm", "Qaraghandy");
i18nc("kazakhstan.kgm", "Karaganda");
i18nc("kazakhstan.kgm", "Qostanay");
i18nc("kazakhstan.kgm", "Kostanai");
i18nc("kazakhstan.kgm", "Qyzylorda");
i18nc("kazakhstan.kgm", "Qyzylorda");
i18nc("kazakhstan.kgm", "Shyghys Qazaqstan");
i18nc("kazakhstan.kgm", "Öskemen");
i18nc("kazakhstan.kgm", "Soltustik Qazaqstan");
i18nc("kazakhstan.kgm", "Petropavl");
i18nc("kazakhstan.kgm", "Zhambyl");
i18nc("kazakhstan.kgm", "Taraz");
i18nc("kyrgyzstan.kgm", "Kyrgyzstan");
i18nc("kyrgyzstan.kgm", "Provinces");
i18nc("kyrgyzstan.kgm", "Frontier");
i18nc("kyrgyzstan.kgm", "Water");
i18nc("kyrgyzstan.kgm", "Not Kyrgyzstan");
i18nc("kyrgyzstan.kgm", "Bishkek");
i18nc("kyrgyzstan.kgm", "Batken");
i18nc("kyrgyzstan.kgm", "Chui");
i18nc("kyrgyzstan.kgm", "Jalal-Abad");
i18nc("kyrgyzstan.kgm", "Naryn");
i18nc("kyrgyzstan.kgm", "Osh");
i18nc("kyrgyzstan.kgm", "Talas");
i18nc("kyrgyzstan.kgm", "Issyk Kul");
i18nc("kyrgyzstan.kgm", "Osh city");
i18nc("latvia.kgm", "Latvia Districts (Pre 2009)");
i18nc("latvia.kgm", "Districts");
i18nc("latvia.kgm", "Frontier");
i18nc("latvia.kgm", "Frontier");
i18nc("latvia.kgm", "Water");
i18nc("latvia.kgm", "Lithuania");
i18nc("latvia.kgm", "Belarus");
i18nc("latvia.kgm", "Russia");
i18nc("latvia.kgm", "Estonia");
i18nc("latvia.kgm", "Aizkraukle");
i18nc("latvia.kgm", "Alūksne");
i18nc("latvia.kgm", "Balvi");
i18nc("latvia.kgm", "Bauska");
i18nc("latvia.kgm", "Cēsis");
i18nc("latvia.kgm", "Daugavpils");
i18nc("latvia.kgm", "Daugavpils city");
i18nc("latvia.kgm", "Dobele");
i18nc("latvia.kgm", "Gulbene");
i18nc("latvia.kgm", "Jēkabpils");
i18nc("latvia.kgm", "Jelgava");
i18nc("latvia.kgm", "Jelgava city");
i18nc("latvia.kgm", "Jūrmala city");
i18nc("latvia.kgm", "Krāslava");
i18nc("latvia.kgm", "Kuldīga");
i18nc("latvia.kgm", "Liepāja");
i18nc("latvia.kgm", "Liepāja city");
i18nc("latvia.kgm", "Limbaži");
i18nc("latvia.kgm", "Ludza");
i18nc("latvia.kgm", "Madona");
i18nc("latvia.kgm", "Ogre");
i18nc("latvia.kgm", "Preiļi");
i18nc("latvia.kgm", "Rēzekne");
i18nc("latvia.kgm", "Rēzekne city");
i18nc("latvia.kgm", "Rīga");
i18nc("latvia.kgm", "Rīga city");
i18nc("latvia.kgm", "Saldus");
i18nc("latvia.kgm", "Talsi");
i18nc("latvia.kgm", "Tukums");
i18nc("latvia.kgm", "Valka");
i18nc("latvia.kgm", "Valmiera");
i18nc("latvia.kgm", "Ventspils");
i18nc("latvia.kgm", "Ventspils city");
i18nc("liechtenstein.kgm", "Liechtenstein");
i18nc("liechtenstein.kgm", "Municipalities");
i18nc("liechtenstein.kgm", "Frontier");
i18nc("liechtenstein.kgm", "Water");
i18nc("liechtenstein.kgm", "Not Liechtenstein");
i18nc("liechtenstein.kgm", "Balzers");
i18nc("liechtenstein.kgm", "Eschen");
i18nc("liechtenstein.kgm", "Gamprin");
i18nc("liechtenstein.kgm", "Mauren");
i18nc("liechtenstein.kgm", "Planken");
i18nc("liechtenstein.kgm", "Ruggell");
i18nc("liechtenstein.kgm", "Schaan");
i18nc("liechtenstein.kgm", "Schelienberg");
i18nc("liechtenstein.kgm", "Triesen");
i18nc("liechtenstein.kgm", "Triesenberg");
i18nc("liechtenstein.kgm", "Vaduz");
i18nc("lithuania_municipalities.kgm", "Lithuania (Municipalities)");
i18nc("lithuania_municipalities.kgm", "Municipalities");
i18nc("lithuania_municipalities.kgm", "Frontier");
i18nc("lithuania_municipalities.kgm", "Water");
i18nc("lithuania_municipalities.kgm", "Not Lithuania (Municipalities)");
i18nc("lithuania_municipalities.kgm", "Akmenė");
i18nc("lithuania_municipalities.kgm", "Naujoji Akmenė");
i18nc("lithuania_municipalities.kgm", "Alytus city");
i18nc("lithuania_municipalities.kgm", "Alytus");
i18nc("lithuania_municipalities.kgm", "Anykščiai");
i18nc("lithuania_municipalities.kgm", "Birštonas");
i18nc("lithuania_municipalities.kgm", "Biržai");
i18nc("lithuania_municipalities.kgm", "Druskininkai");
i18nc("lithuania_municipalities.kgm", "Elektrėnai");
i18nc("lithuania_municipalities.kgm", "Ignalina");
i18nc("lithuania_municipalities.kgm", "Jonava");
i18nc("lithuania_municipalities.kgm", "Joniškis");
i18nc("lithuania_municipalities.kgm", "Jurbarkas");
i18nc("lithuania_municipalities.kgm", "Kaišiadorys");
i18nc("lithuania_municipalities.kgm", "Kalvarija");
i18nc("lithuania_municipalities.kgm", "Kaunas city");
i18nc("lithuania_municipalities.kgm", "Kaunas");
i18nc("lithuania_municipalities.kgm", "Kazlų Rūda");
i18nc("lithuania_municipalities.kgm", "Kėdainiai");
i18nc("lithuania_municipalities.kgm", "Kelmė");
i18nc("lithuania_municipalities.kgm", "Klaipėda city");
i18nc("lithuania_municipalities.kgm", "Klaipėda");
i18nc("lithuania_municipalities.kgm", "Gargždai");
i18nc("lithuania_municipalities.kgm", "Kretinga");
i18nc("lithuania_municipalities.kgm", "Kupiškis");
i18nc("lithuania_municipalities.kgm", "Lazdijai");
i18nc("lithuania_municipalities.kgm", "Marijampolė");
i18nc("lithuania_municipalities.kgm", "Mažeikiai");
i18nc("lithuania_municipalities.kgm", "Molėtai");
i18nc("lithuania_municipalities.kgm", "Neringa");
i18nc("lithuania_municipalities.kgm", "Nida");
i18nc("lithuania_municipalities.kgm", "Pagėgiai");
i18nc("lithuania_municipalities.kgm", "Pakruojis");
i18nc("lithuania_municipalities.kgm", "Palanga city");
i18nc("lithuania_municipalities.kgm", "Panevėžys city");
i18nc("lithuania_municipalities.kgm", "Panevėžys");
i18nc("lithuania_municipalities.kgm", "Pasvalys");
i18nc("lithuania_municipalities.kgm", "Plungė");
i18nc("lithuania_municipalities.kgm", "Prienai");
i18nc("lithuania_municipalities.kgm", "Radviliškis");
i18nc("lithuania_municipalities.kgm", "Raseiniai");
i18nc("lithuania_municipalities.kgm", "Rietavas");
i18nc("lithuania_municipalities.kgm", "Rokiškis");
i18nc("lithuania_municipalities.kgm", "Skuodas");
i18nc("lithuania_municipalities.kgm", "Šakiai");
i18nc("lithuania_municipalities.kgm", "Šalčininkai");
i18nc("lithuania_municipalities.kgm", "Šiauliai city");
i18nc("lithuania_municipalities.kgm", "Šiauliai");
i18nc("lithuania_municipalities.kgm", "Šilalė");
i18nc("lithuania_municipalities.kgm", "Šilutė");
i18nc("lithuania_municipalities.kgm", "Širvintos");
i18nc("lithuania_municipalities.kgm", "Švenčionys");
i18nc("lithuania_municipalities.kgm", "Tauragė");
i18nc("lithuania_municipalities.kgm", "Telšiai");
i18nc("lithuania_municipalities.kgm", "Trakai");
i18nc("lithuania_municipalities.kgm", "Ukmergė");
i18nc("lithuania_municipalities.kgm", "Utena");
i18nc("lithuania_municipalities.kgm", "Varėna");
i18nc("lithuania_municipalities.kgm", "Vilkaviškis");
i18nc("lithuania_municipalities.kgm", "Vilnius city");
i18nc("lithuania_municipalities.kgm", "Vilnius");
i18nc("lithuania_municipalities.kgm", "Visaginas city");
i18nc("lithuania_municipalities.kgm", "Zarasai");
i18nc("luxembourg_cantons.kgm", "Luxembourg (Cantons)");
i18nc("luxembourg_cantons.kgm", "Cantons");
i18nc("luxembourg_cantons.kgm", "Frontier");
i18nc("luxembourg_cantons.kgm", "Not Luxembourg (Cantons)");
i18nc("luxembourg_cantons.kgm", "Clervaux");
i18nc("luxembourg_cantons.kgm", "Diekirch");
i18nc("luxembourg_cantons.kgm", "Redange");
i18nc("luxembourg_cantons.kgm", "Vianden");
i18nc("luxembourg_cantons.kgm", "Wiltz");
i18nc("luxembourg_cantons.kgm", "Echternach");
i18nc("luxembourg_cantons.kgm", "Grevenmacher");
i18nc("luxembourg_cantons.kgm", "Remich");
i18nc("luxembourg_cantons.kgm", "Capellen");
i18nc("luxembourg_cantons.kgm", "Esch-sur-Alzette");
i18nc("luxembourg_cantons.kgm", "Luxembourg");
i18nc("luxembourg_cantons.kgm", "Mersch");
i18nc("malaysia.kgm", "Malaysia");
i18nc("malaysia.kgm", "States");
i18nc("malaysia.kgm", "Frontier");
i18nc("malaysia.kgm", "Water");
i18nc("malaysia.kgm", "Not Malaysia");
i18nc("malaysia.kgm", "Kedah");
i18nc("malaysia.kgm", "Alor Star");
i18nc("malaysia.kgm", "Johor");
i18nc("malaysia.kgm", "Johor Bahru (Pasir Pelangi)");
i18nc("malaysia.kgm", "Kelantan");
i18nc("malaysia.kgm", "Kota Bahru");
i18nc("malaysia.kgm", "Malacca");
i18nc("malaysia.kgm", "Malacca");
i18nc("malaysia.kgm", "Negeri Sembilan");
i18nc("malaysia.kgm", "Seremban");
i18nc("malaysia.kgm", "Pahang");
i18nc("malaysia.kgm", "Kuantan");
i18nc("malaysia.kgm", "Perak");
i18nc("malaysia.kgm", "Ipoh");
i18nc("malaysia.kgm", "Perlis");
i18nc("malaysia.kgm", "Kangar");
i18nc("malaysia.kgm", "Penang");
i18nc("malaysia.kgm", "George Town");
i18nc("malaysia.kgm", "Sabah");
i18nc("malaysia.kgm", "Kota Kinabalu");
i18nc("malaysia.kgm", "Sarawak");
i18nc("malaysia.kgm", "Kuching");
i18nc("malaysia.kgm", "Selangor");
i18nc("malaysia.kgm", "Shah Alam");
i18nc("malaysia.kgm", "Terengganu");
i18nc("malaysia.kgm", "Kuala Terengganu");
i18nc("manipur.kgm", "Manipur");
i18nc("manipur.kgm", "District");
i18nc("manipur.kgm", "Not Manipur");
i18nc("manipur.kgm", "Border");
i18nc("manipur.kgm", "Tamenglong");
i18nc("manipur.kgm", "Tamenglong");
i18nc("manipur.kgm", "Senapati");
i18nc("manipur.kgm", "Senapati");
i18nc("manipur.kgm", "Imphal West");
i18nc("manipur.kgm", "Lamphelpat");
i18nc("manipur.kgm", "Thoubal");
i18nc("manipur.kgm", "Thoubal");
i18nc("manipur.kgm", "Bishnupur");
i18nc("manipur.kgm", "Bishnupur");
i18nc("manipur.kgm", "Ukhrul");
i18nc("manipur.kgm", "Ukhrul");
i18nc("manipur.kgm", "Imphal East");
i18nc("manipur.kgm", "Porompat");
i18nc("manipur.kgm", "Chandel");
i18nc("manipur.kgm", "Chandel");
i18nc("manipur.kgm", "Churachandpur");
i18nc("manipur.kgm", "Churachandpur");
i18nc("mexico_states.kgm", "Mexico (States)");
i18nc("mexico_states.kgm", "States");
i18nc("mexico_states.kgm", "Frontier");
i18nc("mexico_states.kgm", "Water");
i18nc("mexico_states.kgm", "Not Mexico (States)");
i18nc("mexico_states.kgm", "Aguascalientes");
i18nc("mexico_states.kgm", "Aguascalientes");
i18nc("mexico_states.kgm", "Baja California");
i18nc("mexico_states.kgm", "Mexicali");
i18nc("mexico_states.kgm", "Baja California Sur");
i18nc("mexico_states.kgm", "La Paz");
i18nc("mexico_states.kgm", "Campeche");
i18nc("mexico_states.kgm", "Campeche");
i18nc("mexico_states.kgm", "Chiapas");
i18nc("mexico_states.kgm", "Tuxtla Gutiérrez");
i18nc("mexico_states.kgm", "Chihuahua");
i18nc("mexico_states.kgm", "Chihuahua");
i18nc("mexico_states.kgm", "Coahuila");
i18nc("mexico_states.kgm", "Saltillo");
i18nc("mexico_states.kgm", "Colima");
i18nc("mexico_states.kgm", "Colima");
i18nc("mexico_states.kgm", "Durango");
i18nc("mexico_states.kgm", "Durango");
i18nc("mexico_states.kgm", "Guanajuato");
i18nc("mexico_states.kgm", "Guanajuato");
i18nc("mexico_states.kgm", "Guerrero");
i18nc("mexico_states.kgm", "Chilpancingo");
i18nc("mexico_states.kgm", "Hidalgo");
i18nc("mexico_states.kgm", "Pachuca");
i18nc("mexico_states.kgm", "Jalisco");
i18nc("mexico_states.kgm", "Guadalajara");
i18nc("mexico_states.kgm", "México");
i18nc("mexico_states.kgm", "Toluca");
i18nc("mexico_states.kgm", "Michoacán");
i18nc("mexico_states.kgm", "Morelia");
i18nc("mexico_states.kgm", "Morelos");
i18nc("mexico_states.kgm", "Cuernavaca");
i18nc("mexico_states.kgm", "Nayarit");
i18nc("mexico_states.kgm", "Tepic");
i18nc("mexico_states.kgm", "Nuevo León");
i18nc("mexico_states.kgm", "Monterrey");
i18nc("mexico_states.kgm", "Oaxaca");
i18nc("mexico_states.kgm", "Oaxaca");
i18nc("mexico_states.kgm", "Puebla");
i18nc("mexico_states.kgm", "Puebla");
i18nc("mexico_states.kgm", "Querétaro");
i18nc("mexico_states.kgm", "Santiago de Querétaro");
i18nc("mexico_states.kgm", "Quintana Roo");
i18nc("mexico_states.kgm", "Chetumal");
i18nc("mexico_states.kgm", "San Luis Potosí");
i18nc("mexico_states.kgm", "San Luis Potosí");
i18nc("mexico_states.kgm", "Sinaloa");
i18nc("mexico_states.kgm", "Culiacán");
i18nc("mexico_states.kgm", "Sonora");
i18nc("mexico_states.kgm", "Hermosillo");
i18nc("mexico_states.kgm", "Tabasco");
i18nc("mexico_states.kgm", "Villahermosa");
i18nc("mexico_states.kgm", "Tamaulipas");
i18nc("mexico_states.kgm", "Ciudad Victoria");
i18nc("mexico_states.kgm", "Tlaxcala");
i18nc("mexico_states.kgm", "Tlaxcala");
i18nc("mexico_states.kgm", "Veracruz");
i18nc("mexico_states.kgm", "Xalapa");
i18nc("mexico_states.kgm", "Yucatán");
i18nc("mexico_states.kgm", "Mérida");
i18nc("mexico_states.kgm", "Zacatecas");
i18nc("mexico_states.kgm", "Zacatecas");
i18nc("mexico_states.kgm", "Federal District");
i18nc("mexico_states.kgm", "Mexico City");
i18nc("mongolia.kgm", "Mongolia");
i18nc("mongolia.kgm", "Provinces");
i18nc("mongolia.kgm", "Not Mongolia");
i18nc("mongolia.kgm", "Frontier");
i18nc("mongolia.kgm", "Water");
i18nc("mongolia.kgm", "Arhangay");
i18nc("mongolia.kgm", "Tsetserleg");
i18nc("mongolia.kgm", "Bayan-Ölgiy");
i18nc("mongolia.kgm", "Ölgiy");
i18nc("mongolia.kgm", "Bayanhongor");
i18nc("mongolia.kgm", "Bayanhongor");
i18nc("mongolia.kgm", "Bulgan");
i18nc("mongolia.kgm", "Bulgan");
i18nc("mongolia.kgm", "Darhan-Uul");
i18nc("mongolia.kgm", "Darhan");
i18nc("mongolia.kgm", "Dornod");
i18nc("mongolia.kgm", "Choybalsan");
i18nc("mongolia.kgm", "Dornogovĭ");
i18nc("mongolia.kgm", "Saynshand");
i18nc("mongolia.kgm", "Dundgovĭ");
i18nc("mongolia.kgm", "Mandalgovĭ");
i18nc("mongolia.kgm", "Govĭ-Altay");
i18nc("mongolia.kgm", "Altay");
i18nc("mongolia.kgm", "Govĭsümber");
i18nc("mongolia.kgm", "Choyr");
i18nc("mongolia.kgm", "Hentiy");
i18nc("mongolia.kgm", "Öndörhaan");
i18nc("mongolia.kgm", "Hovd");
i18nc("mongolia.kgm", "Hovd");
i18nc("mongolia.kgm", "Hövsgöl");
i18nc("mongolia.kgm", "Mörön");
i18nc("mongolia.kgm", "Ömnögovĭ");
i18nc("mongolia.kgm", "Dalanzadgad");
i18nc("mongolia.kgm", "Orhon");
i18nc("mongolia.kgm", "Erdenet");
i18nc("mongolia.kgm", "Övörhangay");
i18nc("mongolia.kgm", "Arvayheer");
i18nc("mongolia.kgm", "Selenge");
i18nc("mongolia.kgm", "Sühbaatar");
i18nc("mongolia.kgm", "Sühbaatar");
i18nc("mongolia.kgm", "Baruun-Urt");
i18nc("mongolia.kgm", "Töv");
i18nc("mongolia.kgm", "Zuunmod");
i18nc("mongolia.kgm", "Uvs");
i18nc("mongolia.kgm", "Ulaangom");
i18nc("mongolia.kgm", "Zavhan");
i18nc("mongolia.kgm", "Uliastay");
i18nc("mongolia.kgm", "Ulan Bator");
i18nc("ncamerica.kgm", "North and Central America");
i18nc("ncamerica.kgm", "Countries");
i18nc("ncamerica.kgm", "Water");
i18nc("ncamerica.kgm", "Not North and Central America");
i18nc("ncamerica.kgm", "Frontier");
i18nc("ncamerica.kgm", "Canada");
i18nc("ncamerica.kgm", "Ottawa");
i18nc("ncamerica.kgm", "El Salvador");
i18nc("ncamerica.kgm", "San Salvador");
i18nc("ncamerica.kgm", "The United States of America");
i18nc("ncamerica.kgm", "Washington D.C.");
i18nc("ncamerica.kgm", "The Bahamas");
i18nc("ncamerica.kgm", "Nassau");
i18nc("ncamerica.kgm", "The Dominican Republic");
i18nc("ncamerica.kgm", "Santo Domingo");
i18nc("ncamerica.kgm", "Haiti");
i18nc("ncamerica.kgm", "Port-au-Prince");
i18nc("ncamerica.kgm", "Cuba");
i18nc("ncamerica.kgm", "Havana");
i18nc("ncamerica.kgm", "Jamaica");
i18nc("ncamerica.kgm", "Kingston");
i18nc("ncamerica.kgm", "Dominica");
i18nc("ncamerica.kgm", "Roseau");
i18nc("ncamerica.kgm", "Antigua and Barbuda");
i18nc("ncamerica.kgm", "St. John's");
i18nc("ncamerica.kgm", "Barbados");
i18nc("ncamerica.kgm", "Bridgetown");
i18nc("ncamerica.kgm", "Trinidad and Tobago");
i18nc("ncamerica.kgm", "Port of Spain");
i18nc("ncamerica.kgm", "Mexico");
i18nc("ncamerica.kgm", "Mexico City");
i18nc("ncamerica.kgm", "Guatemala");
i18nc("ncamerica.kgm", "Guatemala City");
i18nc("ncamerica.kgm", "Belize");
i18nc("ncamerica.kgm", "Belmopan");
i18nc("ncamerica.kgm", "Honduras");
i18nc("ncamerica.kgm", "Tegucigalpa");
i18nc("ncamerica.kgm", "Nicaragua");
i18nc("ncamerica.kgm", "Managua");
i18nc("ncamerica.kgm", "Costa Rica");
i18nc("ncamerica.kgm", "San José");
i18nc("ncamerica.kgm", "Panama");
i18nc("ncamerica.kgm", "Panama City");
i18nc("ncamerica.kgm", "Greenland [Denmark]");
i18nc("ncamerica.kgm", "Guyana");
i18nc("ncamerica.kgm", "Venezuela");
i18nc("ncamerica.kgm", "Colombia");
i18nc("nepal_zones.kgm", "Nepal (Zones)");
i18nc("nepal_zones.kgm", "Zones");
i18nc("nepal_zones.kgm", "Frontier");
i18nc("nepal_zones.kgm", "Water");
i18nc("nepal_zones.kgm", "Not Nepal (Zones)");
i18nc("nepal_zones.kgm", "Bagmati");
i18nc("nepal_zones.kgm", "Bheri");
i18nc("nepal_zones.kgm", "Dhawalagiri");
i18nc("nepal_zones.kgm", "Gandaki");
i18nc("nepal_zones.kgm", "Janakpur");
i18nc("nepal_zones.kgm", "Karnali");
i18nc("nepal_zones.kgm", "Koshi");
i18nc("nepal_zones.kgm", "Lumbini");
i18nc("nepal_zones.kgm", "Mahakali");
i18nc("nepal_zones.kgm", "Mechi");
i18nc("nepal_zones.kgm", "Narayani");
i18nc("nepal_zones.kgm", "Rapti");
i18nc("nepal_zones.kgm", "Sagarmatha");
i18nc("nepal_zones.kgm", "Seti");
i18nc("netherlands.kgm", "The Netherlands");
i18nc("netherlands.kgm", "Provinces");
i18nc("netherlands.kgm", "Frontier");
i18nc("netherlands.kgm", "Not The Netherlands");
i18nc("netherlands.kgm", "Water");
i18nc("netherlands.kgm", "Friesland");
i18nc("netherlands.kgm", "Leeuwarden");
i18nc("netherlands.kgm", "Groningen");
i18nc("netherlands.kgm", "Groningen");
i18nc("netherlands.kgm", "Drenthe");
i18nc("netherlands.kgm", "Assen");
i18nc("netherlands.kgm", "Overijssel");
i18nc("netherlands.kgm", "Zwolle");
i18nc("netherlands.kgm", "Gelderland");
i18nc("netherlands.kgm", "Arnhem");
i18nc("netherlands.kgm", "North Brabant");
i18nc("netherlands.kgm", "'s Hertogenbosch");
i18nc("netherlands.kgm", "Limburg");
i18nc("netherlands.kgm", "Maastricht");
i18nc("netherlands.kgm", "Flevoland");
i18nc("netherlands.kgm", "Lelystad");
i18nc("netherlands.kgm", "Utrecht");
i18nc("netherlands.kgm", "Utrecht");
i18nc("netherlands.kgm", "Zeeland");
i18nc("netherlands.kgm", "Middelburg");
i18nc("netherlands.kgm", "North Holland");
i18nc("netherlands.kgm", "Haarlem");
i18nc("netherlands.kgm", "South Holland");
i18nc("netherlands.kgm", "The Hague");
i18nc("new-zealand.kgm", "New-Zealand");
i18nc("new-zealand.kgm", "Regions");
i18nc("new-zealand.kgm", "Frontier");
i18nc("new-zealand.kgm", "Not New-Zealand");
i18nc("new-zealand.kgm", "Northland");
i18nc("new-zealand.kgm", "Whangarei");
i18nc("new-zealand.kgm", "Auckland");
i18nc("new-zealand.kgm", "Auckland City");
i18nc("new-zealand.kgm", "Waikato");
i18nc("new-zealand.kgm", "Hamilton");
i18nc("new-zealand.kgm", "Bay of Plenty");
i18nc("new-zealand.kgm", "Whakatane");
i18nc("new-zealand.kgm", "Gisborne");
i18nc("new-zealand.kgm", "Gisborne");
i18nc("new-zealand.kgm", "Hawke's Bay");
i18nc("new-zealand.kgm", "Napier/Hastings");
i18nc("new-zealand.kgm", "Taranaki");
i18nc("new-zealand.kgm", "New Plymouth");
i18nc("new-zealand.kgm", "Manawatu-Wanganui");
i18nc("new-zealand.kgm", "Wanganui");
i18nc("new-zealand.kgm", "Wellington");
i18nc("new-zealand.kgm", "Wellington");
i18nc("new-zealand.kgm", "Tasman");
i18nc("new-zealand.kgm", "Nelson City");
i18nc("new-zealand.kgm", "Marlborough");
i18nc("new-zealand.kgm", "Blenheim");
i18nc("new-zealand.kgm", "West Coast");
i18nc("new-zealand.kgm", "Grey Mouth");
i18nc("new-zealand.kgm", "Canterbury");
i18nc("new-zealand.kgm", "Christchurch");
i18nc("new-zealand.kgm", "Otago");
i18nc("new-zealand.kgm", "Dunedin");
i18nc("new-zealand.kgm", "Southland");
i18nc("new-zealand.kgm", "Invercargil");
i18nc("nicaragua.kgm", "Nicaragua");
i18nc("nicaragua.kgm", "Departments");
i18nc("nicaragua.kgm", "Frontier");
i18nc("nicaragua.kgm", "Frontier");
i18nc("nicaragua.kgm", "Water");
i18nc("nicaragua.kgm", "Not Nicaragua");
i18nc("nicaragua.kgm", "Nueva Segovia");
i18nc("nicaragua.kgm", "Ocotal");
i18nc("nicaragua.kgm", "Madriz");
i18nc("nicaragua.kgm", "Somoto");
i18nc("nicaragua.kgm", "Estelí");
i18nc("nicaragua.kgm", "Estelí");
i18nc("nicaragua.kgm", "Chinandega");
i18nc("nicaragua.kgm", "Chinandega");
i18nc("nicaragua.kgm", "León");
i18nc("nicaragua.kgm", "León");
i18nc("nicaragua.kgm", "Managua");
i18nc("nicaragua.kgm", "Managua");
i18nc("nicaragua.kgm", "Masaya");
i18nc("nicaragua.kgm", "Masaya");
i18nc("nicaragua.kgm", "Carazo");
i18nc("nicaragua.kgm", "Jinotepe");
i18nc("nicaragua.kgm", "Granada");
i18nc("nicaragua.kgm", "Granada");
i18nc("nicaragua.kgm", "Rivas");
i18nc("nicaragua.kgm", "Rivas");
i18nc("nicaragua.kgm", "Chontales");
i18nc("nicaragua.kgm", "Juigalpa");
i18nc("nicaragua.kgm", "Boaco");
i18nc("nicaragua.kgm", "Boaco");
i18nc("nicaragua.kgm", "Matagalpa");
i18nc("nicaragua.kgm", "Matagalpa");
i18nc("nicaragua.kgm", "Jinotega");
i18nc("nicaragua.kgm", "Jinotega");
i18nc("nicaragua.kgm", "Río San Juan");
i18nc("nicaragua.kgm", "San Carlos");
i18nc("nicaragua.kgm", "Atlántico Norte");
i18nc("nicaragua.kgm", "Puerto Cabezas");
i18nc("nicaragua.kgm", "Atlántico Sur");
i18nc("nicaragua.kgm", "Bluefields");
i18nc("north_korea.kgm", "North Korea");
i18nc("north_korea.kgm", "Provinces");
i18nc("north_korea.kgm", "Frontier");
i18nc("north_korea.kgm", "Water");
i18nc("north_korea.kgm", "Not North (Korea)");
i18nc("north_korea.kgm", "Chagang");
i18nc("north_korea.kgm", "Chagang-do");
i18nc("north_korea.kgm", "North Hamgyŏng");
i18nc("north_korea.kgm", "Hamgyŏng-pukto");
i18nc("north_korea.kgm", "South Hamgyŏng");
i18nc("north_korea.kgm", "Hamgyŏng-namdo");
i18nc("north_korea.kgm", "North Hwanghae");
i18nc("north_korea.kgm", "Hwanghae-pukto");
i18nc("north_korea.kgm", "South Hwanghae");
i18nc("north_korea.kgm", "Hwanghae-namdo");
i18nc("north_korea.kgm", "Kangwŏn");
i18nc("north_korea.kgm", "Kangwŏndo");
i18nc("north_korea.kgm", "North P'yŏngan");
i18nc("north_korea.kgm", "P'yŏngan-pukto");
i18nc("north_korea.kgm", "South P'yŏngan");
i18nc("north_korea.kgm", "P'yŏngan-namdo");
i18nc("north_korea.kgm", "Ryanggang");
i18nc("north_korea.kgm", "Ryanggang-do");
i18nc("north_korea.kgm", "Kaesŏng Industrial Region");
i18nc("north_korea.kgm", "Kaesŏng Kong-ŏp Chigu");
i18nc("north_korea.kgm", "Kŭmgangsan Tourist Region");
i18nc("north_korea.kgm", "Kŭmgangsan Kwangwang Chigu");
i18nc("north_korea.kgm", "Sinŭiju Special Administrative Region");
i18nc("north_korea.kgm", "Sinŭiju T'ŭkpyŏl Haengjŏnggu");
i18nc("north_korea.kgm", "P'yŏngyang");
i18nc("north_korea.kgm", "P'yŏngyang Chikhalsi");
i18nc("north_korea.kgm", "Rasŏn (Rajin-Sŏnbong)");
i18nc("north_korea.kgm", "Rasŏn (Rajin-Sŏnbong) Chikhalsi");
i18nc("norway.kgm", "Norway");
i18nc("norway.kgm", "Counties");
i18nc("norway.kgm", "Frontier");
i18nc("norway.kgm", "Not Norway");
i18nc("norway.kgm", "Finnmark");
i18nc("norway.kgm", "Vadsø");
i18nc("norway.kgm", "Troms");
i18nc("norway.kgm", "Tromsø");
i18nc("norway.kgm", "Nordland");
i18nc("norway.kgm", "Bodø");
i18nc("norway.kgm", "Nord-Trøndelag");
i18nc("norway.kgm", "Steinkjer");
i18nc("norway.kgm", "Sør-Trøndelag");
i18nc("norway.kgm", "Trondheim");
i18nc("norway.kgm", "Møre Og Romsdal");
i18nc("norway.kgm", "Molde");
i18nc("norway.kgm", "Oppland");
i18nc("norway.kgm", "Lillehammer");
i18nc("norway.kgm", "Hedmark");
i18nc("norway.kgm", "Hamar");
i18nc("norway.kgm", "Sogn Og Fjordane");
i18nc("norway.kgm", "Hermansverk");
i18nc("norway.kgm", "Hordaland");
i18nc("norway.kgm", "Bergen");
i18nc("norway.kgm", "Rogaland");
i18nc("norway.kgm", "Stavanger");
i18nc("norway.kgm", "Vest-Agder");
i18nc("norway.kgm", "Kristiansand");
i18nc("norway.kgm", "Aust-Agder");
i18nc("norway.kgm", "Arendal");
i18nc("norway.kgm", "Telemark");
i18nc("norway.kgm", "Skien");
i18nc("norway.kgm", "Buskerud");
i18nc("norway.kgm", "Drammen");
i18nc("norway.kgm", "Vestfold");
i18nc("norway.kgm", "Tønsberg");
i18nc("norway.kgm", "Oslo");
i18nc("norway.kgm", "Oslo");
i18nc("norway.kgm", "Akershus");
i18nc("norway.kgm", "Oslo");
i18nc("norway.kgm", "Østfold");
i18nc("norway.kgm", "Sarpsborg");
i18nc("oceania.kgm", "Oceania");
i18nc("oceania.kgm", "Countries");
i18nc("oceania.kgm", "Frontier");
i18nc("oceania.kgm", "Water");
i18nc("oceania.kgm", "Not Oceania");
i18nc("oceania.kgm", "Australia");
i18nc("oceania.kgm", "Canberra");
i18nc("oceania.kgm", "Norfolk island (Australia)");
i18nc("oceania.kgm", "Kingston");
i18nc("oceania.kgm", "New Zealand");
i18nc("oceania.kgm", "Wellington");
i18nc("oceania.kgm", "Cook islands (New Zealand)");
i18nc("oceania.kgm", "Avarua");
i18nc("oceania.kgm", "Niue (New Zealand)");
i18nc("oceania.kgm", "Alofi");
i18nc("oceania.kgm", "Tokelau (New Zealand)");
i18nc("oceania.kgm", "East Timor");
i18nc("oceania.kgm", "Dili");
i18nc("oceania.kgm", "Easter Island");
i18nc("oceania.kgm", "Hanga Roa");
i18nc("oceania.kgm", "Fiji");
i18nc("oceania.kgm", "Suva");
i18nc("oceania.kgm", "Indonesia");
i18nc("oceania.kgm", "Jakarta");
i18nc("oceania.kgm", "Papua New Guinea");
i18nc("oceania.kgm", "Port Moresby");
i18nc("oceania.kgm", "Solomon Islands");
i18nc("oceania.kgm", "Honiara");
i18nc("oceania.kgm", "Vanuatu");
i18nc("oceania.kgm", "Port Vila");
i18nc("oceania.kgm", "Federated States of Micronesia");
i18nc("oceania.kgm", "Palikir");
i18nc("oceania.kgm", "Kiribati");
i18nc("oceania.kgm", "South Tarawa");
i18nc("oceania.kgm", "Marshall Islands");
i18nc("oceania.kgm", "Majuro");
i18nc("oceania.kgm", "Nauru");
i18nc("oceania.kgm", "Yaren");
i18nc("oceania.kgm", "Palau");
i18nc("oceania.kgm", "Melekeok");
i18nc("oceania.kgm", "New Caledonia (France)");
i18nc("oceania.kgm", "Noumea");
i18nc("oceania.kgm", "French Polynesia (France)");
i18nc("oceania.kgm", "Papeete");
i18nc("oceania.kgm", "Wallis and Futuna (France)");
i18nc("oceania.kgm", "Mata Utu");
i18nc("oceania.kgm", "Samoa");
i18nc("oceania.kgm", "Apia");
i18nc("oceania.kgm", "Tonga");
i18nc("oceania.kgm", "Nuku'alofa");
i18nc("oceania.kgm", "Tuvalu");
i18nc("oceania.kgm", "Funafuti");
i18nc("oceania.kgm", "Pitcairn islands (United Kingdom)");
i18nc("oceania.kgm", "Adamstown");
i18nc("oceania.kgm", "Hawaii (USA)");
i18nc("oceania.kgm", "Honolulu");
i18nc("oceania.kgm", "American Samoa (USA)");
i18nc("oceania.kgm", "Pago Pago");
i18nc("oceania.kgm", "Guam (USA)");
i18nc("oceania.kgm", "Hagåtña");
i18nc("oceania.kgm", "Northern Mariana islands (USA)");
i18nc("oceania.kgm", "Saipan");
i18nc("oceania.kgm", "United States Minor Outlying Islands");
i18nc("oman.kgm", "Oman");
i18nc("oman.kgm", "Regions");
i18nc("oman.kgm", "Frontier");
i18nc("oman.kgm", "Water");
i18nc("oman.kgm", "Not Oman");
i18nc("oman.kgm", "Ad Dakhiliyah");
i18nc("oman.kgm", "Al Batinah");
i18nc("oman.kgm", "Al Wusta");
i18nc("oman.kgm", "Ash Sharqiyah");
i18nc("oman.kgm", "Ad Dhahirah");
i18nc("oman.kgm", "Muscat");
i18nc("oman.kgm", "Musandam");
i18nc("oman.kgm", "Dhofar");
i18nc("pakistan.kgm", "Pakistan");
i18nc("pakistan.kgm", "Provinces");
i18nc("pakistan.kgm", "Frontier");
i18nc("pakistan.kgm", "Water");
i18nc("pakistan.kgm", "Not Pakistan");
i18nc("pakistan.kgm", "Balochistan");
i18nc("pakistan.kgm", "Quetta");
i18nc("pakistan.kgm", "Khyber Pakhtunkhwa");
i18nc("pakistan.kgm", "Peshawar");
i18nc("pakistan.kgm", "Punjab");
i18nc("pakistan.kgm", "Lahore");
i18nc("pakistan.kgm", "Sindh");
i18nc("pakistan.kgm", "Karachi");
i18nc("pakistan.kgm", "Islamabad Capital Territory");
i18nc("pakistan.kgm", "Islamabad");
i18nc("pakistan.kgm", "Federally Administered Tribal Areas");
i18nc("pakistan.kgm", "Peshawar and Islamabad");
i18nc("pakistan.kgm", "Azad Kashmir");
i18nc("pakistan.kgm", "Muzaffarabad");
i18nc("pakistan.kgm", "Gilgit-Baltistan");
i18nc("pakistan.kgm", "Gilgit");
i18nc("panama.kgm", "Panama");
i18nc("panama.kgm", "Regions");
i18nc("panama.kgm", "Frontier");
i18nc("panama.kgm", "Frontier");
i18nc("panama.kgm", "Water");
i18nc("panama.kgm", "Not Panama");
i18nc("panama.kgm", "Bocas del Toro");
i18nc("panama.kgm", "Bocas del Toro");
i18nc("panama.kgm", "Chiriquí");
i18nc("panama.kgm", "David");
i18nc("panama.kgm", "Coclé");
i18nc("panama.kgm", "Penonomé");
i18nc("panama.kgm", "Colón");
i18nc("panama.kgm", "Colón");
i18nc("panama.kgm", "Darién");
i18nc("panama.kgm", "La Palma");
i18nc("panama.kgm", "Herrera");
i18nc("panama.kgm", "Chitré");
i18nc("panama.kgm", "Los Santos");
i18nc("panama.kgm", "Las Tablas");
i18nc("panama.kgm", "Panamá");
i18nc("panama.kgm", "Panamá");
i18nc("panama.kgm", "Veraguas");
i18nc("panama.kgm", "Santiago de Veraguas");
i18nc("panama.kgm", "Emberá");
i18nc("panama.kgm", "Union Choco");
i18nc("panama.kgm", "Kuna Yala");
i18nc("panama.kgm", "El Porvenir");
i18nc("panama.kgm", "Ngöbe-Buglé");
i18nc("panama.kgm", "Chichica");
i18nc("paraguay.kgm", "Paraguay");
i18nc("paraguay.kgm", "Departments");
i18nc("paraguay.kgm", "Frontier");
i18nc("paraguay.kgm", "Frontier");
i18nc("paraguay.kgm", "Not Paraguay");
i18nc("paraguay.kgm", "Alto Paraguay");
i18nc("paraguay.kgm", "Fuerte Olimpo");
i18nc("paraguay.kgm", "Alto Paraná");
i18nc("paraguay.kgm", "Ciudad del Este");
i18nc("paraguay.kgm", "Amambay");
i18nc("paraguay.kgm", "Pedro Juan Caballero");
i18nc("paraguay.kgm", "Asunción Capital District");
i18nc("paraguay.kgm", "Asunción");
i18nc("paraguay.kgm", "Boquerón");
i18nc("paraguay.kgm", "Filadelfia");
i18nc("paraguay.kgm", "Caaguazú");
i18nc("paraguay.kgm", "Coronel Oviedo");
i18nc("paraguay.kgm", "Caazapá");
i18nc("paraguay.kgm", "Caazapá");
i18nc("paraguay.kgm", "Canindeyú");
i18nc("paraguay.kgm", "Salto del Guairá");
i18nc("paraguay.kgm", "Central");
i18nc("paraguay.kgm", "Areguá");
i18nc("paraguay.kgm", "Concepción");
i18nc("paraguay.kgm", "Concepción");
i18nc("paraguay.kgm", "Cordillera");
i18nc("paraguay.kgm", "Caacupé");
i18nc("paraguay.kgm", "Guairá");
i18nc("paraguay.kgm", "Villarrica");
i18nc("paraguay.kgm", "Itapúa");
i18nc("paraguay.kgm", "Encarnación");
i18nc("paraguay.kgm", "Misiones");
i18nc("paraguay.kgm", "San Juan Bautista");
i18nc("paraguay.kgm", "Ñeembucú");
i18nc("paraguay.kgm", "Pilar");
i18nc("paraguay.kgm", "Paraguarí");
i18nc("paraguay.kgm", "Paraguarí");
i18nc("paraguay.kgm", "Presidente Hayes");
i18nc("paraguay.kgm", "Pozo Colorado");
i18nc("paraguay.kgm", "San Pedro");
i18nc("paraguay.kgm", "San Pedro");
i18nc("peru.kgm", "Peru");
i18nc("peru.kgm", "Regions");
i18nc("peru.kgm", "Frontier");
i18nc("peru.kgm", "Pacific Ocean");
i18nc("peru.kgm", "Ecuador");
i18nc("peru.kgm", "Colombia");
i18nc("peru.kgm", "Brazil");
i18nc("peru.kgm", "Bolivia");
i18nc("peru.kgm", "Chile");
i18nc("peru.kgm", "Amazonas");
i18nc("peru.kgm", "Chachapoyas");
i18nc("peru.kgm", "Ancash");
i18nc("peru.kgm", "Huaraz");
i18nc("peru.kgm", "Apurimac");
i18nc("peru.kgm", "Abancay");
i18nc("peru.kgm", "Arequipa");
i18nc("peru.kgm", "Arequipa");
i18nc("peru.kgm", "Ayacucho");
i18nc("peru.kgm", "Ayacucho");
i18nc("peru.kgm", "Cajamarca");
i18nc("peru.kgm", "Cajamarca");
i18nc("peru.kgm", "Cusco");
i18nc("peru.kgm", "Cusco");
i18nc("peru.kgm", "Huancavelica");
i18nc("peru.kgm", "Huancavelica");
i18nc("peru.kgm", "Huanuco");
i18nc("peru.kgm", "Huanuco");
i18nc("peru.kgm", "Ica");
i18nc("peru.kgm", "Ica");
i18nc("peru.kgm", "Junin");
i18nc("peru.kgm", "Huancayo");
i18nc("peru.kgm", "Lambayeque");
i18nc("peru.kgm", "Chiclayo");
i18nc("peru.kgm", "La Libertad");
i18nc("peru.kgm", "Trujillo");
i18nc("peru.kgm", "Lima");
i18nc("peru.kgm", "Huacho");
i18nc("peru.kgm", "Loreto");
i18nc("peru.kgm", "Iquitos");
i18nc("peru.kgm", "Madre de Dios");
i18nc("peru.kgm", "Puerto Maldonado");
i18nc("peru.kgm", "Moquegua");
i18nc("peru.kgm", "Moquegua");
i18nc("peru.kgm", "Piura");
i18nc("peru.kgm", "Piura");
i18nc("peru.kgm", "Tacna");
i18nc("peru.kgm", "Tacna");
i18nc("peru.kgm", "Tumbes");
i18nc("peru.kgm", "Tumbes");
i18nc("peru.kgm", "Pasco");
i18nc("peru.kgm", "Cerro de Pasco");
i18nc("peru.kgm", "Puno");
i18nc("peru.kgm", "Puno");
i18nc("peru.kgm", "San Martin");
i18nc("peru.kgm", "Moyobamba");
i18nc("peru.kgm", "Ucayali");
i18nc("peru.kgm", "Pucallpa");
i18nc("philippines.kgm", "Philippines");
i18nc("philippines.kgm", "Provinces");
i18nc("philippines.kgm", "Frontier");
i18nc("philippines.kgm", "Water");
i18nc("philippines.kgm", "Not Philippines");
i18nc("philippines.kgm", "Abra");
i18nc("philippines.kgm", "Bangued");
i18nc("philippines.kgm", "Agusan del Norte");
i18nc("philippines.kgm", "Cabadbaran");
i18nc("philippines.kgm", "Agusan del Sur");
i18nc("philippines.kgm", "Prosperidad");
i18nc("philippines.kgm", "Aklan");
i18nc("philippines.kgm", "Kalibo");
i18nc("philippines.kgm", "Albay");
i18nc("philippines.kgm", "Legazpi City");
i18nc("philippines.kgm", "Antique");
i18nc("philippines.kgm", "San Jose");
i18nc("philippines.kgm", "Apayao");
i18nc("philippines.kgm", "Kabugao");
i18nc("philippines.kgm", "Aurora");
i18nc("philippines.kgm", "Baler");
i18nc("philippines.kgm", "Basilan");
i18nc("philippines.kgm", "Isabela City");
i18nc("philippines.kgm", "Bataan");
i18nc("philippines.kgm", "Balanga City");
i18nc("philippines.kgm", "Batanes");
i18nc("philippines.kgm", "Basco");
i18nc("philippines.kgm", "Batangas");
i18nc("philippines.kgm", "Batangas City");
i18nc("philippines.kgm", "Benguet");
i18nc("philippines.kgm", "La Trinidad");
i18nc("philippines.kgm", "Biliran");
i18nc("philippines.kgm", "Naval");
i18nc("philippines.kgm", "Bohol");
i18nc("philippines.kgm", "Tagbilaran City");
i18nc("philippines.kgm", "Bukidnon");
i18nc("philippines.kgm", "Malaybalay City");
i18nc("philippines.kgm", "Bulacan");
i18nc("philippines.kgm", "Malolos");
i18nc("philippines.kgm", "Cagayan");
i18nc("philippines.kgm", "Tuguegarao City");
i18nc("philippines.kgm", "Camarines Norte");
i18nc("philippines.kgm", "Daet");
i18nc("philippines.kgm", "Camarines Sur");
i18nc("philippines.kgm", "Pili");
i18nc("philippines.kgm", "Camiguin");
i18nc("philippines.kgm", "Mambajao");
i18nc("philippines.kgm", "Capiz");
i18nc("philippines.kgm", "Roxas City");
i18nc("philippines.kgm", "Catanduanes");
i18nc("philippines.kgm", "Virac");
i18nc("philippines.kgm", "Cavite");
i18nc("philippines.kgm", "Trece Martires City");
i18nc("philippines.kgm", "Cebu");
i18nc("philippines.kgm", "Cebu City");
i18nc("philippines.kgm", "Compostela Valley");
i18nc("philippines.kgm", "Nabunturan");
i18nc("philippines.kgm", "Cotabato");
i18nc("philippines.kgm", "Kidapawan City");
i18nc("philippines.kgm", "Davao del Norte");
i18nc("philippines.kgm", "Tagum City");
i18nc("philippines.kgm", "Davao del Sur");
i18nc("philippines.kgm", "Digos City");
i18nc("philippines.kgm", "Davao Oriental");
i18nc("philippines.kgm", "Mati");
i18nc("philippines.kgm", "Eastern Samar");
i18nc("philippines.kgm", "Borongan");
i18nc("philippines.kgm", "Guimaras");
i18nc("philippines.kgm", "Jordan");
i18nc("philippines.kgm", "Ifugao");
i18nc("philippines.kgm", "Lagawe");
i18nc("philippines.kgm", "Ilocos Norte");
i18nc("philippines.kgm", "Laoag City");
i18nc("philippines.kgm", "Ilocos Sur");
i18nc("philippines.kgm", "Vigan City");
i18nc("philippines.kgm", "Iloilo");
i18nc("philippines.kgm", "Iloilo City");
i18nc("philippines.kgm", "Isabela");
i18nc("philippines.kgm", "Ilagan");
i18nc("philippines.kgm", "Kalinga");
i18nc("philippines.kgm", "Tabuk");
i18nc("philippines.kgm", "La Union");
i18nc("philippines.kgm", "San Fernando City");
i18nc("philippines.kgm", "Laguna");
i18nc("philippines.kgm", "Santa Cruz");
i18nc("philippines.kgm", "Lanao del Norte");
i18nc("philippines.kgm", "Tubod");
i18nc("philippines.kgm", "Lanao del Sur");
i18nc("philippines.kgm", "Marawi City");
i18nc("philippines.kgm", "Leyte");
i18nc("philippines.kgm", "Tacloban City");
i18nc("philippines.kgm", "Maguindanao");
i18nc("philippines.kgm", "Shariff Aguak");
i18nc("philippines.kgm", "Marinduque");
i18nc("philippines.kgm", "Boac");
i18nc("philippines.kgm", "Masbate");
i18nc("philippines.kgm", "Masbate City");
i18nc("philippines.kgm", "Misamis Occidental");
i18nc("philippines.kgm", "Oroquieta City");
i18nc("philippines.kgm", "Misamis Oriental");
i18nc("philippines.kgm", "Cagayan de Oro City");
i18nc("philippines.kgm", "Mountain Province");
i18nc("philippines.kgm", "Bontoc");
i18nc("philippines.kgm", "Negros Occidental [2]");
i18nc("philippines.kgm", "Bacolod City");
i18nc("philippines.kgm", "Negros Oriental");
i18nc("philippines.kgm", "Dumaguete City");
i18nc("philippines.kgm", "Northern Samar");
i18nc("philippines.kgm", "Catarman");
i18nc("philippines.kgm", "Nueva Ecija");
i18nc("philippines.kgm", "Palayan City");
i18nc("philippines.kgm", "Nueva Vizcaya");
i18nc("philippines.kgm", "Bayombong");
i18nc("philippines.kgm", "Occidental Mindoro");
i18nc("philippines.kgm", "Mamburao");
i18nc("philippines.kgm", "Oriental Mindoro");
i18nc("philippines.kgm", "Calapan City");
i18nc("philippines.kgm", "Palawan");
i18nc("philippines.kgm", "Puerto Princesa City");
i18nc("philippines.kgm", "Pampanga");
i18nc("philippines.kgm", "San Fernando City");
i18nc("philippines.kgm", "Pangasinan");
i18nc("philippines.kgm", "Lingayen");
i18nc("philippines.kgm", "Quezon");
i18nc("philippines.kgm", "Lucena City");
i18nc("philippines.kgm", "Quirino");
i18nc("philippines.kgm", "Cabarroguis");
i18nc("philippines.kgm", "Rizal");
i18nc("philippines.kgm", "Antipolo City");
i18nc("philippines.kgm", "Romblon");
i18nc("philippines.kgm", "Romblon");
i18nc("philippines.kgm", "Samar");
i18nc("philippines.kgm", "Catbalogan");
i18nc("philippines.kgm", "Sarangani");
i18nc("philippines.kgm", "Alabel");
i18nc("philippines.kgm", "Siquijor");
i18nc("philippines.kgm", "Siquijor");
i18nc("philippines.kgm", "Sorsogon");
i18nc("philippines.kgm", "Sorsogon City");
i18nc("philippines.kgm", "South Cotabato");
i18nc("philippines.kgm", "Koronadal City");
i18nc("philippines.kgm", "Southern Leyte");
i18nc("philippines.kgm", "Maasin City");
i18nc("philippines.kgm", "Sultan Kudarat");
i18nc("philippines.kgm", "Isulan");
i18nc("philippines.kgm", "Sulu");
i18nc("philippines.kgm", "Jolo");
i18nc("philippines.kgm", "Surigao del Norte");
i18nc("philippines.kgm", "Surigao City");
i18nc("philippines.kgm", "Surigao del Sur");
i18nc("philippines.kgm", "Tandag");
i18nc("philippines.kgm", "Tarlac");
i18nc("philippines.kgm", "Tarlac City");
i18nc("philippines.kgm", "Tawi-Tawi");
i18nc("philippines.kgm", "Panglima Sugala");
i18nc("philippines.kgm", "Zambales");
i18nc("philippines.kgm", "Iba");
i18nc("philippines.kgm", "Zamboanga del Norte");
i18nc("philippines.kgm", "Dipolog City");
i18nc("philippines.kgm", "Zamboanga del Sur");
i18nc("philippines.kgm", "Pagadian City");
i18nc("philippines.kgm", "Zamboanga Sibugay");
i18nc("philippines.kgm", "Ipil");
i18nc("philippines.kgm", "National Capital");
i18nc("philippines.kgm", "Manila");
i18nc("poland.kgm", "Poland");
i18nc("poland.kgm", "Provinces");
i18nc("poland.kgm", "Frontier");
i18nc("poland.kgm", "Not Poland");
i18nc("poland.kgm", "Masovia");
i18nc("poland.kgm", "Warsaw");
i18nc("poland.kgm", "Warmia and Masuria");
i18nc("poland.kgm", "Olsztyn");
i18nc("poland.kgm", "Podlachia");
i18nc("poland.kgm", "Białystok");
i18nc("poland.kgm", "Lublin");
i18nc("poland.kgm", "Lublin");
i18nc("poland.kgm", "Subcarpathia");
i18nc("poland.kgm", "Rzeszów");
i18nc("poland.kgm", "Świętokrzyskie");
i18nc("poland.kgm", "Kielce");
i18nc("poland.kgm", "Lesser Poland");
i18nc("poland.kgm", "Kraków");
i18nc("poland.kgm", "Łódź");
i18nc("poland.kgm", "Łódź");
i18nc("poland.kgm", "Silesia");
i18nc("poland.kgm", "Katowice");
i18nc("poland.kgm", "Opole");
i18nc("poland.kgm", "Opole");
i18nc("poland.kgm", "Pomerania");
i18nc("poland.kgm", "Gdańsk");
i18nc("poland.kgm", "West Pomerania");
i18nc("poland.kgm", "Szczecin");
i18nc("poland.kgm", "Greater Poland");
i18nc("poland.kgm", "Poznań");
i18nc("poland.kgm", "Lower Silesia");
i18nc("poland.kgm", "Wrocław");
i18nc("poland.kgm", "Lubusz");
i18nc("poland.kgm", "Zielona Góra, Gorzów Wielkopolski");
i18nc("poland.kgm", "Kuyavia-Pomerania");
i18nc("poland.kgm", "Bydgoszcz, Toruń");
i18nc("portugal_districts.kgm", "Portugal Districts");
i18nc("portugal_districts.kgm", "Districts");
i18nc("portugal_districts.kgm", "Water");
i18nc("portugal_districts.kgm", "Border");
i18nc("portugal_districts.kgm", "Spain");
i18nc("portugal_districts.kgm", "Border2");
i18nc("portugal_districts.kgm", "Viana do Castelo");
i18nc("portugal_districts.kgm", "Viana do Castelo");
i18nc("portugal_districts.kgm", "Açores");
i18nc("portugal_districts.kgm", "Ponta Delgada");
i18nc("portugal_districts.kgm", "Madeira");
i18nc("portugal_districts.kgm", "Funchal");
i18nc("portugal_districts.kgm", "Braga");
i18nc("portugal_districts.kgm", "Braga");
i18nc("portugal_districts.kgm", "Vila Real");
i18nc("portugal_districts.kgm", "Vila Real");
i18nc("portugal_districts.kgm", "Bragança");
i18nc("portugal_districts.kgm", "Bragança");
i18nc("portugal_districts.kgm", "Porto");
i18nc("portugal_districts.kgm", "Porto");
i18nc("portugal_districts.kgm", "Aveiro");
i18nc("portugal_districts.kgm", "Aveiro");
i18nc("portugal_districts.kgm", "Viseu");
i18nc("portugal_districts.kgm", "Viseu");
i18nc("portugal_districts.kgm", "Guarda");
i18nc("portugal_districts.kgm", "Guarda");
i18nc("portugal_districts.kgm", "Coimbra");
i18nc("portugal_districts.kgm", "Coimbra");
i18nc("portugal_districts.kgm", "Castelo Branco");
i18nc("portugal_districts.kgm", "Castelo Branco");
i18nc("portugal_districts.kgm", "Leiria");
i18nc("portugal_districts.kgm", "Leiria");
i18nc("portugal_districts.kgm", "Santarém");
i18nc("portugal_districts.kgm", "Santarém");
i18nc("portugal_districts.kgm", "Lisboa");
i18nc("portugal_districts.kgm", "Lisboa");
i18nc("portugal_districts.kgm", "Évora");
i18nc("portugal_districts.kgm", "Évora");
i18nc("portugal_districts.kgm", "Setúbal");
i18nc("portugal_districts.kgm", "Setúbal");
i18nc("portugal_districts.kgm", "Beja");
i18nc("portugal_districts.kgm", "Beja");
i18nc("portugal_districts.kgm", "Faro");
i18nc("portugal_districts.kgm", "Faro");
i18nc("portugal_districts.kgm", "Portalegre");
i18nc("portugal_districts.kgm", "Portalegre");
i18nc("portugal_provinces.kgm", "Portugal Provinces (traditional)");
i18nc("portugal_provinces.kgm", "Provinces (traditional)");
i18nc("portugal_provinces.kgm", "Water");
i18nc("portugal_provinces.kgm", "Border");
i18nc("portugal_provinces.kgm", "Spain");
i18nc("portugal_provinces.kgm", "Border2");
i18nc("portugal_provinces.kgm", "Minho");
i18nc("portugal_provinces.kgm", "Braga");
i18nc("portugal_provinces.kgm", "Trás-os-Montes e Alto Douro");
i18nc("portugal_provinces.kgm", "Vila Real");
i18nc("portugal_provinces.kgm", "Douro Litoral");
i18nc("portugal_provinces.kgm", "Porto");
i18nc("portugal_provinces.kgm", "Beira Alta");
i18nc("portugal_provinces.kgm", "Viseu");
i18nc("portugal_provinces.kgm", "Beira Litoral");
i18nc("portugal_provinces.kgm", "Coimbra");
i18nc("portugal_provinces.kgm", "Beira Baixa");
i18nc("portugal_provinces.kgm", "Castelo Branco");
i18nc("portugal_provinces.kgm", "Ribatejo");
i18nc("portugal_provinces.kgm", "Santarém");
i18nc("portugal_provinces.kgm", "Estremadura");
i18nc("portugal_provinces.kgm", "Lisboa");
i18nc("portugal_provinces.kgm", "Alto Alentejo");
i18nc("portugal_provinces.kgm", "Évora");
i18nc("portugal_provinces.kgm", "Baixo Alentejo");
i18nc("portugal_provinces.kgm", "Beja");
i18nc("portugal_provinces.kgm", "Algarve");
i18nc("portugal_provinces.kgm", "Faro");
i18nc("portugal_provinces.kgm", "Açores");
i18nc("portugal_provinces.kgm", "Ponta Delgada");
i18nc("portugal_provinces.kgm", "Madeira");
i18nc("portugal_provinces.kgm", "Funchal");
i18nc("portugal_regions.kgm", "Portugal (Regions)");
i18nc("portugal_regions.kgm", "Regions");
i18nc("portugal_regions.kgm", "Frontier");
i18nc("portugal_regions.kgm", "Not Portugal (Regions)");
i18nc("portugal_regions.kgm", "Water");
i18nc("portugal_regions.kgm", "Alentejo");
i18nc("portugal_regions.kgm", "Evora");
i18nc("portugal_regions.kgm", "Algarve");
i18nc("portugal_regions.kgm", "Faro");
i18nc("portugal_regions.kgm", "Centro");
i18nc("portugal_regions.kgm", "Coimbra");
i18nc("portugal_regions.kgm", "Lisboa(region)");
i18nc("portugal_regions.kgm", "Lisboa");
i18nc("portugal_regions.kgm", "Norte");
i18nc("portugal_regions.kgm", "Porto");
i18nc("portugal_regions.kgm", "Madeira");
i18nc("portugal_regions.kgm", "Funchal");
i18nc("portugal_regions.kgm", "Azores");
i18nc("portugal_regions.kgm", "Ponta Delgada");
i18nc("puertorico.kgm", "Puerto Rico");
i18nc("puertorico.kgm", "Municipalities");
i18nc("puertorico.kgm", "Frontier");
i18nc("puertorico.kgm", "Frontier");
i18nc("puertorico.kgm", "Water");
i18nc("puertorico.kgm", "Mona");
i18nc("puertorico.kgm", "Adjuntas");
i18nc("puertorico.kgm", "Aguada");
i18nc("puertorico.kgm", "Aguadilla");
i18nc("puertorico.kgm", "Aguas Buenas");
i18nc("puertorico.kgm", "Aibonito");
i18nc("puertorico.kgm", "Añasco");
i18nc("puertorico.kgm", "Arecibo");
i18nc("puertorico.kgm", "Arroyo");
i18nc("puertorico.kgm", "Barceloneta");
i18nc("puertorico.kgm", "Barranquitas");
i18nc("puertorico.kgm", "Bayamón");
i18nc("puertorico.kgm", "Cabo Rojo");
i18nc("puertorico.kgm", "Caguas");
i18nc("puertorico.kgm", "Camuy");
i18nc("puertorico.kgm", "Canóvanas");
i18nc("puertorico.kgm", "Carolina");
i18nc("puertorico.kgm", "Cataño");
i18nc("puertorico.kgm", "Cayey");
i18nc("puertorico.kgm", "Ceiba");
i18nc("puertorico.kgm", "Ciales");
i18nc("puertorico.kgm", "Cidra");
i18nc("puertorico.kgm", "Coamo");
i18nc("puertorico.kgm", "Comerío");
i18nc("puertorico.kgm", "Corozal");
i18nc("puertorico.kgm", "Culebra");
i18nc("puertorico.kgm", "Dorado");
i18nc("puertorico.kgm", "Fajardo");
i18nc("puertorico.kgm", "Florida");
i18nc("puertorico.kgm", "Guánica");
i18nc("puertorico.kgm", "Guayama");
i18nc("puertorico.kgm", "Guayanilla");
i18nc("puertorico.kgm", "Guaynabo");
i18nc("puertorico.kgm", "Gurabo");
i18nc("puertorico.kgm", "Hatillo");
i18nc("puertorico.kgm", "Hormigueros");
i18nc("puertorico.kgm", "Humacao");
i18nc("puertorico.kgm", "Isabela");
i18nc("puertorico.kgm", "Jayuya");
i18nc("puertorico.kgm", "Juana Díaz");
i18nc("puertorico.kgm", "Juncos");
i18nc("puertorico.kgm", "Lajas");
i18nc("puertorico.kgm", "Lares");
i18nc("puertorico.kgm", "Las Marías");
i18nc("puertorico.kgm", "Las Piedras");
i18nc("puertorico.kgm", "Loíza");
i18nc("puertorico.kgm", "Luquillo");
i18nc("puertorico.kgm", "Manatí");
i18nc("puertorico.kgm", "Maricao");
i18nc("puertorico.kgm", "Maunabo");
i18nc("puertorico.kgm", "Mayagüez");
i18nc("puertorico.kgm", "Moca");
i18nc("puertorico.kgm", "Morovis");
i18nc("puertorico.kgm", "Nagüabo");
i18nc("puertorico.kgm", "Naranjito");
i18nc("puertorico.kgm", "Orocovis");
i18nc("puertorico.kgm", "Patillas");
i18nc("puertorico.kgm", "Peñuelas");
i18nc("puertorico.kgm", "Ponce");
i18nc("puertorico.kgm", "Quebradillas");
i18nc("puertorico.kgm", "Rincón");
i18nc("puertorico.kgm", "Río Grande");
i18nc("puertorico.kgm", "Sabana Grande");
i18nc("puertorico.kgm", "Salinas");
i18nc("puertorico.kgm", "San Germán");
i18nc("puertorico.kgm", "San Juan");
i18nc("puertorico.kgm", "San Lorenzo");
i18nc("puertorico.kgm", "San Sebastián");
i18nc("puertorico.kgm", "Santa Isabel");
i18nc("puertorico.kgm", "Toa Alta");
i18nc("puertorico.kgm", "Toa Baja");
i18nc("puertorico.kgm", "Trujillo Alto");
i18nc("puertorico.kgm", "Utuado");
i18nc("puertorico.kgm", "Vega Alta");
i18nc("puertorico.kgm", "Vega Baja");
i18nc("puertorico.kgm", "Vieques");
i18nc("puertorico.kgm", "Villalba");
i18nc("puertorico.kgm", "Yabucoa");
i18nc("puertorico.kgm", "Yauco");
i18nc("republic_of_ireland.kgm", "Republic Of Ireland");
i18nc("republic_of_ireland.kgm", "Counties");
i18nc("republic_of_ireland.kgm", "Frontier");
i18nc("republic_of_ireland.kgm", "Water");
i18nc("republic_of_ireland.kgm", "Not Republic Of Ireland");
i18nc("republic_of_ireland.kgm", "Dublin");
i18nc("republic_of_ireland.kgm", "Dublin");
i18nc("republic_of_ireland.kgm", "Wicklow");
i18nc("republic_of_ireland.kgm", "Wicklow");
i18nc("republic_of_ireland.kgm", "Wexford");
i18nc("republic_of_ireland.kgm", "Wexford");
i18nc("republic_of_ireland.kgm", "Carlow");
i18nc("republic_of_ireland.kgm", "Carlow");
i18nc("republic_of_ireland.kgm", "Kildare");
i18nc("republic_of_ireland.kgm", "Naas");
i18nc("republic_of_ireland.kgm", "Meath");
i18nc("republic_of_ireland.kgm", "Navan");
i18nc("republic_of_ireland.kgm", "Louth");
i18nc("republic_of_ireland.kgm", "Dundalk");
i18nc("republic_of_ireland.kgm", "Monaghan");
i18nc("republic_of_ireland.kgm", "Monaghan");
i18nc("republic_of_ireland.kgm", "Cavan");
i18nc("republic_of_ireland.kgm", "Cavan");
i18nc("republic_of_ireland.kgm", "Longford");
i18nc("republic_of_ireland.kgm", "Longford");
i18nc("republic_of_ireland.kgm", "Westmeath");
i18nc("republic_of_ireland.kgm", "Mullingar");
i18nc("republic_of_ireland.kgm", "Offaly");
i18nc("republic_of_ireland.kgm", "Tullamore");
i18nc("republic_of_ireland.kgm", "Laois");
i18nc("republic_of_ireland.kgm", "Portlaois");
i18nc("republic_of_ireland.kgm", "Kilkenny");
i18nc("republic_of_ireland.kgm", "Kilkenny");
i18nc("republic_of_ireland.kgm", "Waterford");
i18nc("republic_of_ireland.kgm", "Waterford");
i18nc("republic_of_ireland.kgm", "Cork");
i18nc("republic_of_ireland.kgm", "Cork");
i18nc("republic_of_ireland.kgm", "Kerry");
i18nc("republic_of_ireland.kgm", "Tralee");
i18nc("republic_of_ireland.kgm", "Limerick");
i18nc("republic_of_ireland.kgm", "Limerick");
i18nc("republic_of_ireland.kgm", "North Tipperary");
i18nc("republic_of_ireland.kgm", "Nenagh");
i18nc("republic_of_ireland.kgm", "South Tipperary");
i18nc("republic_of_ireland.kgm", "Clonmel");
i18nc("republic_of_ireland.kgm", "Clare");
i18nc("republic_of_ireland.kgm", "Ennis");
i18nc("republic_of_ireland.kgm", "Galway");
i18nc("republic_of_ireland.kgm", "Galway");
i18nc("republic_of_ireland.kgm", "Mayo");
i18nc("republic_of_ireland.kgm", "Castlebar");
i18nc("republic_of_ireland.kgm", "Roscommon");
i18nc("republic_of_ireland.kgm", "Roscommon");
i18nc("republic_of_ireland.kgm", "Sligo");
i18nc("republic_of_ireland.kgm", "Sligo");
i18nc("republic_of_ireland.kgm", "Leitrim");
i18nc("republic_of_ireland.kgm", "Carrick-on-Shannon");
i18nc("republic_of_ireland.kgm", "Donegal");
i18nc("republic_of_ireland.kgm", "Lifford");
i18nc("romania.kgm", "Romania");
i18nc("romania.kgm", "Counties");
i18nc("romania.kgm", "Frontier");
i18nc("romania.kgm", "Water");
i18nc("romania.kgm", "Not Romania");
i18nc("romania.kgm", "Alba");
i18nc("romania.kgm", "Alba Iulia");
i18nc("romania.kgm", "Arad");
i18nc("romania.kgm", "Arad");
i18nc("romania.kgm", "Argeş");
i18nc("romania.kgm", "Piteşti");
i18nc("romania.kgm", "Bacău");
i18nc("romania.kgm", "Bacău");
i18nc("romania.kgm", "Bihor");
i18nc("romania.kgm", "Oradea");
i18nc("romania.kgm", "Bistriţa-Năsăud");
i18nc("romania.kgm", "Bistriţa");
i18nc("romania.kgm", "Botoşani");
i18nc("romania.kgm", "Botoşani");
i18nc("romania.kgm", "Braşov");
i18nc("romania.kgm", "Braşov");
i18nc("romania.kgm", "Brăila");
i18nc("romania.kgm", "Brăila");
i18nc("romania.kgm", "Buzău");
i18nc("romania.kgm", "Buzău");
i18nc("romania.kgm", "Caraş-Severin");
i18nc("romania.kgm", "Reşiţa");
i18nc("romania.kgm", "Călăraşi");
i18nc("romania.kgm", "Călăraşi");
i18nc("romania.kgm", "Cluj");
i18nc("romania.kgm", "Cluj-Napoca");
i18nc("romania.kgm", "Constanţa");
i18nc("romania.kgm", "Constanţa");
i18nc("romania.kgm", "Covasna");
i18nc("romania.kgm", "Sfântu Gheorghe");
i18nc("romania.kgm", "Dâmboviţa");
i18nc("romania.kgm", "Târgovişte");
i18nc("romania.kgm", "Dolj");
i18nc("romania.kgm", "Craiova");
i18nc("romania.kgm", "Galaţi");
i18nc("romania.kgm", "Galaţi");
i18nc("romania.kgm", "Giurgiu");
i18nc("romania.kgm", "Giurgiu");
i18nc("romania.kgm", "Gorj");
i18nc("romania.kgm", "Târgu Jiu");
i18nc("romania.kgm", "Harghita");
i18nc("romania.kgm", "Miercurea Ciuc");
i18nc("romania.kgm", "Hunedoara");
i18nc("romania.kgm", "Deva");
i18nc("romania.kgm", "Ialomiţa");
i18nc("romania.kgm", "Slobozia");
i18nc("romania.kgm", "Iaşi");
i18nc("romania.kgm", "Iaşi");
i18nc("romania.kgm", "Ilfov");
i18nc("romania.kgm", "Buftea");
i18nc("romania.kgm", "Maramureş");
i18nc("romania.kgm", "Baia Mare");
i18nc("romania.kgm", "Mehedinţi");
i18nc("romania.kgm", "Drobeta-Turnu Severin");
i18nc("romania.kgm", "Mureş");
i18nc("romania.kgm", "Târgu Mureş");
i18nc("romania.kgm", "Neamţ");
i18nc("romania.kgm", "Piatra Neamţ");
i18nc("romania.kgm", "Olt");
i18nc("romania.kgm", "Slatina");
i18nc("romania.kgm", "Prahova");
i18nc("romania.kgm", "Ploieşti");
i18nc("romania.kgm", "Satu Mare");
i18nc("romania.kgm", "Satu Mare");
i18nc("romania.kgm", "Sălaj");
i18nc("romania.kgm", "Zalău");
i18nc("romania.kgm", "Sibiu");
i18nc("romania.kgm", "Sibiu");
i18nc("romania.kgm", "Suceava");
i18nc("romania.kgm", "Suceava");
i18nc("romania.kgm", "Teleorman");
i18nc("romania.kgm", "Alexandria");
i18nc("romania.kgm", "Timiş");
i18nc("romania.kgm", "Timişoara");
i18nc("romania.kgm", "Tulcea");
i18nc("romania.kgm", "Tulcea");
i18nc("romania.kgm", "Vaslui");
i18nc("romania.kgm", "Vaslui");
i18nc("romania.kgm", "Vâlcea");
i18nc("romania.kgm", "Râmnicu Vâlcea");
i18nc("romania.kgm", "Vrancea");
i18nc("romania.kgm", "Focşani");
i18nc("romania.kgm", "Bucureşti");
i18nc("romania.kgm", "(Bucharest municipality)");
i18nc("russia_districts.kgm", "Russia (Districts)");
i18nc("russia_districts.kgm", "Districts");
i18nc("russia_districts.kgm", "Frontier");
i18nc("russia_districts.kgm", "Water");
i18nc("russia_districts.kgm", "Not Russia (Districts)");
i18nc("russia_districts.kgm", "Central");
i18nc("russia_districts.kgm", "Moscow");
i18nc("russia_districts.kgm", "Far Eastern");
i18nc("russia_districts.kgm", "Khabarovsk");
i18nc("russia_districts.kgm", "Northwestern");
i18nc("russia_districts.kgm", "St. Petersburg");
i18nc("russia_districts.kgm", "Siberian");
i18nc("russia_districts.kgm", "Novosibirsk");
i18nc("russia_districts.kgm", "Southern");
i18nc("russia_districts.kgm", "Rostov-na-Donu");
i18nc("russia_districts.kgm", "Urals");
i18nc("russia_districts.kgm", "Yekaterinburg");
i18nc("russia_districts.kgm", "Privolzhsky");
i18nc("russia_districts.kgm", "Nizhny Novgorod");
i18nc("russia_subjects.kgm", "Russia (Subjects)");
i18nc("russia_subjects.kgm", "Districts");
i18nc("russia_subjects.kgm", "Frontier");
i18nc("russia_subjects.kgm", "Water");
i18nc("russia_subjects.kgm", "Not Russia (Subjects)");
i18nc("russia_subjects.kgm", "Adygeya");
i18nc("russia_subjects.kgm", "Maykop");
i18nc("russia_subjects.kgm", "Bashkortostan");
i18nc("russia_subjects.kgm", "Ufa");
i18nc("russia_subjects.kgm", "Buryatia");
i18nc("russia_subjects.kgm", "Ulan-Ude");
i18nc("russia_subjects.kgm", "Altai Republic");
i18nc("russia_subjects.kgm", "Gorno-Altaysk");
i18nc("russia_subjects.kgm", "Dagestan");
i18nc("russia_subjects.kgm", "Makhachkala");
i18nc("russia_subjects.kgm", "Ingushetia");
i18nc("russia_subjects.kgm", "Magas");
i18nc("russia_subjects.kgm", "Kabardino-Balkaria");
i18nc("russia_subjects.kgm", "Nalchik");
i18nc("russia_subjects.kgm", "Kalmykia");
i18nc("russia_subjects.kgm", "Elista");
i18nc("russia_subjects.kgm", "Karachay-Cherkessia");
i18nc("russia_subjects.kgm", "Cherkessk");
i18nc("russia_subjects.kgm", "Karelia");
i18nc("russia_subjects.kgm", "Petrozavodsk");
i18nc("russia_subjects.kgm", "Komi");
i18nc("russia_subjects.kgm", "Syktyvkar");
i18nc("russia_subjects.kgm", "Mari El");
i18nc("russia_subjects.kgm", "Yoshkar-Ola");
i18nc("russia_subjects.kgm", "Mordovia");
i18nc("russia_subjects.kgm", "Saransk");
i18nc("russia_subjects.kgm", "Sakha");
i18nc("russia_subjects.kgm", "Yakutsk");
i18nc("russia_subjects.kgm", "North Ossetia-Alania");
i18nc("russia_subjects.kgm", "Vladikavkaz");
i18nc("russia_subjects.kgm", "Tatarstan");
i18nc("russia_subjects.kgm", "Kazan");
i18nc("russia_subjects.kgm", "Tyva");
i18nc("russia_subjects.kgm", "Kyzyl");
i18nc("russia_subjects.kgm", "Udmurtia");
i18nc("russia_subjects.kgm", "Izhevsk");
i18nc("russia_subjects.kgm", "Khakassia");
i18nc("russia_subjects.kgm", "Abakan");
i18nc("russia_subjects.kgm", "Chechnya");
i18nc("russia_subjects.kgm", "Grozny");
i18nc("russia_subjects.kgm", "Chuvashia");
i18nc("russia_subjects.kgm", "Cheboksary");
i18nc("russia_subjects.kgm", "Altai Krai");
i18nc("russia_subjects.kgm", "Barnaul");
i18nc("russia_subjects.kgm", "Krasnodar Krai");
i18nc("russia_subjects.kgm", "Krasnodar");
i18nc("russia_subjects.kgm", "Krasnoyarsk Krai");
i18nc("russia_subjects.kgm", "Krasnoyarsk");
i18nc("russia_subjects.kgm", "Primorsky Krai");
i18nc("russia_subjects.kgm", "Vladivostok");
i18nc("russia_subjects.kgm", "Stavropol Krai");
i18nc("russia_subjects.kgm", "Stavropol");
i18nc("russia_subjects.kgm", "Khabarovsk Krai");
i18nc("russia_subjects.kgm", "Khabarovsk");
i18nc("russia_subjects.kgm", "Perm Krai");
i18nc("russia_subjects.kgm", "Perm");
i18nc("russia_subjects.kgm", "Amur Oblast");
i18nc("russia_subjects.kgm", "Blagoveshchensk");
i18nc("russia_subjects.kgm", "Arkhangelsk Oblast");
i18nc("russia_subjects.kgm", "Arkhangelsk");
i18nc("russia_subjects.kgm", "Astrakhan Oblast");
i18nc("russia_subjects.kgm", "Astrakhan");
i18nc("russia_subjects.kgm", "Belgorod Oblast");
i18nc("russia_subjects.kgm", "Belgorod");
i18nc("russia_subjects.kgm", "Bryansk Oblast");
i18nc("russia_subjects.kgm", "Bryansk");
i18nc("russia_subjects.kgm", "Vladimir Oblast");
i18nc("russia_subjects.kgm", "Vladimir");
i18nc("russia_subjects.kgm", "Volgograd Oblast");
i18nc("russia_subjects.kgm", "Volgograd");
i18nc("russia_subjects.kgm", "Vologda Oblast");
i18nc("russia_subjects.kgm", "Vologda");
i18nc("russia_subjects.kgm", "Voronezh Oblast");
i18nc("russia_subjects.kgm", "Voronezh");
i18nc("russia_subjects.kgm", "Ivanovo Oblast");
i18nc("russia_subjects.kgm", "Ivanovo");
i18nc("russia_subjects.kgm", "Irkutsk Oblast");
i18nc("russia_subjects.kgm", "Irkutsk");
i18nc("russia_subjects.kgm", "Kaliningrad Oblast");
i18nc("russia_subjects.kgm", "Kaliningrad");
i18nc("russia_subjects.kgm", "Kaluga Oblast");
i18nc("russia_subjects.kgm", "Kaluga");
i18nc("russia_subjects.kgm", "Kamchatka Krai");
i18nc("russia_subjects.kgm", "Petropavlovsk-Kamchatsky");
i18nc("russia_subjects.kgm", "Kemerovo Oblast");
i18nc("russia_subjects.kgm", "Kemerovo");
i18nc("russia_subjects.kgm", "Kirov Oblast");
i18nc("russia_subjects.kgm", "Kirov");
i18nc("russia_subjects.kgm", "Kostroma Oblast");
i18nc("russia_subjects.kgm", "Kostroma");
i18nc("russia_subjects.kgm", "Kurgan Oblast");
i18nc("russia_subjects.kgm", "Kurgan");
i18nc("russia_subjects.kgm", "Kursk Oblast");
i18nc("russia_subjects.kgm", "Kursk");
i18nc("russia_subjects.kgm", "Leningrad Oblast");
i18nc("russia_subjects.kgm", "St. Petersburg");
i18nc("russia_subjects.kgm", "Lipetsk Oblast");
i18nc("russia_subjects.kgm", "Lipetsk");
i18nc("russia_subjects.kgm", "Magadan Oblast");
i18nc("russia_subjects.kgm", "Magadan");
i18nc("russia_subjects.kgm", "Moscow Oblast");
i18nc("russia_subjects.kgm", "Moscow");
i18nc("russia_subjects.kgm", "Murmansk Oblast");
i18nc("russia_subjects.kgm", "Murmansk");
i18nc("russia_subjects.kgm", "Nizhny Novgorod Oblast");
i18nc("russia_subjects.kgm", "Nizhny Novgorod");
i18nc("russia_subjects.kgm", "Novgorod Oblast");
i18nc("russia_subjects.kgm", "Novgorod");
i18nc("russia_subjects.kgm", "Novosibirsk Oblast");
i18nc("russia_subjects.kgm", "Novosibirsk");
i18nc("russia_subjects.kgm", "Omsk Oblast");
i18nc("russia_subjects.kgm", "Omsk");
i18nc("russia_subjects.kgm", "Orenburg Oblast");
i18nc("russia_subjects.kgm", "Orenburg");
i18nc("russia_subjects.kgm", "Oryol Oblast");
i18nc("russia_subjects.kgm", "Oryol");
i18nc("russia_subjects.kgm", "Penza Oblast");
i18nc("russia_subjects.kgm", "Penza");
i18nc("russia_subjects.kgm", "Pskov Oblast");
i18nc("russia_subjects.kgm", "Pskov");
i18nc("russia_subjects.kgm", "Rostov Oblast");
i18nc("russia_subjects.kgm", "Rostov-na-Donu");
i18nc("russia_subjects.kgm", "Ryazan Oblast");
i18nc("russia_subjects.kgm", "Ryazan");
i18nc("russia_subjects.kgm", "Samara Oblast");
i18nc("russia_subjects.kgm", "Samara");
i18nc("russia_subjects.kgm", "Saratov Oblast");
i18nc("russia_subjects.kgm", "Saratov");
i18nc("russia_subjects.kgm", "Sakhalin Oblast");
i18nc("russia_subjects.kgm", "Yuzhno-Sakhalinsk");
i18nc("russia_subjects.kgm", "Sverdlovsk Oblast");
i18nc("russia_subjects.kgm", "Yekaterinburg");
i18nc("russia_subjects.kgm", "Smolensk Oblast");
i18nc("russia_subjects.kgm", "Smolensk");
i18nc("russia_subjects.kgm", "Tambov Oblast");
i18nc("russia_subjects.kgm", "Tambov");
i18nc("russia_subjects.kgm", "Tver Oblast");
i18nc("russia_subjects.kgm", "Tver");
i18nc("russia_subjects.kgm", "Tomsk Oblast");
i18nc("russia_subjects.kgm", "Tomsk");
i18nc("russia_subjects.kgm", "Tula Oblast");
i18nc("russia_subjects.kgm", "Tula");
i18nc("russia_subjects.kgm", "Tyumen Oblast");
i18nc("russia_subjects.kgm", "Tyumen");
i18nc("russia_subjects.kgm", "Ulyanovsk Oblast");
i18nc("russia_subjects.kgm", "Ulyanovsk");
i18nc("russia_subjects.kgm", "Chelyabinsk Oblast");
i18nc("russia_subjects.kgm", "Chelyabinsk");
i18nc("russia_subjects.kgm", "Zabaykalsky Krai");
i18nc("russia_subjects.kgm", "Chita");
i18nc("russia_subjects.kgm", "Yaroslavl Oblast");
i18nc("russia_subjects.kgm", "Yaroslavl");
i18nc("russia_subjects.kgm", "Moscow");
i18nc("russia_subjects.kgm", "Moscow");
i18nc("russia_subjects.kgm", "St. Petersburg");
i18nc("russia_subjects.kgm", "St. Petersburg");
i18nc("russia_subjects.kgm", "Jewish Autonomous Oblast");
i18nc("russia_subjects.kgm", "Birobidzhan");
i18nc("russia_subjects.kgm", "Nenetsia");
i18nc("russia_subjects.kgm", "Naryan-Mar");
i18nc("russia_subjects.kgm", "Khantia-Mansia");
i18nc("russia_subjects.kgm", "Khanty-Mansiysk");
i18nc("russia_subjects.kgm", "Chukotka");
i18nc("russia_subjects.kgm", "Anadyr");
i18nc("russia_subjects.kgm", "Yamalia");
i18nc("russia_subjects.kgm", "Salekhard");
i18nc("san-marino.kgm", "San Marino");
i18nc("san-marino.kgm", "Municipalities");
i18nc("san-marino.kgm", "Frontier");
i18nc("san-marino.kgm", "Not San-Marino");
i18nc("san-marino.kgm", "Acquaviva");
i18nc("san-marino.kgm", "Città di San Marino");
i18nc("san-marino.kgm", "Chiesanouva");
i18nc("san-marino.kgm", "Fiorentino");
i18nc("san-marino.kgm", "Montegiardino");
i18nc("san-marino.kgm", "Featano");
i18nc("san-marino.kgm", "Domagnano");
i18nc("san-marino.kgm", "Serravalle");
i18nc("san-marino.kgm", "Borgo Maggiore");
i18nc("saudi_arabia.kgm", "Saudi Arabia");
i18nc("saudi_arabia.kgm", "Provinces");
i18nc("saudi_arabia.kgm", "Frontier");
i18nc("saudi_arabia.kgm", "Water");
i18nc("saudi_arabia.kgm", "Not Saudi (Arabia)");
i18nc("saudi_arabia.kgm", "Al-Bahah");
i18nc("saudi_arabia.kgm", "Al Hudud ash Shamaliyah");
i18nc("saudi_arabia.kgm", "Al Jawf");
i18nc("saudi_arabia.kgm", "Al Madinah");
i18nc("saudi_arabia.kgm", "Al Gassim");
i18nc("saudi_arabia.kgm", "Ar-Riyad");
i18nc("saudi_arabia.kgm", "Ash-Sharqiyah");
i18nc("saudi_arabia.kgm", "'Asir");
i18nc("saudi_arabia.kgm", "Ha'il");
i18nc("saudi_arabia.kgm", "Jizan");
i18nc("saudi_arabia.kgm", "Makkah");
i18nc("saudi_arabia.kgm", "Najran");
i18nc("saudi_arabia.kgm", "Tabuk");
i18nc("sikkim.kgm", "Sikkim");
i18nc("sikkim.kgm", "District");
i18nc("sikkim.kgm", "Not Sikkim");
i18nc("sikkim.kgm", "Border");
i18nc("sikkim.kgm", "North Sikkim");
i18nc("sikkim.kgm", "Mangan");
i18nc("sikkim.kgm", "West Sikkim");
i18nc("sikkim.kgm", "Geyzing");
i18nc("sikkim.kgm", "South Sikkim");
i18nc("sikkim.kgm", "Namchi");
i18nc("sikkim.kgm", "East Sikkim");
i18nc("sikkim.kgm", "Gangtok");
i18nc("slovakia.kgm", "Slovakia");
i18nc("slovakia.kgm", "Regions");
i18nc("slovakia.kgm", "Frontier");
i18nc("slovakia.kgm", "Frontier");
i18nc("slovakia.kgm", "Not Slovakia");
i18nc("slovakia.kgm", "Bratislava");
i18nc("slovakia.kgm", "Trnava");
i18nc("slovakia.kgm", "Trenčín");
i18nc("slovakia.kgm", "Nitra");
i18nc("slovakia.kgm", "Žilina");
i18nc("slovakia.kgm", "Banská Bystrica");
i18nc("slovakia.kgm", "Prešov");
i18nc("slovakia.kgm", "Košice");
i18nc("slovenia_traditional.kgm", "Slovenia (Traditional)");
i18nc("slovenia_traditional.kgm", "Regions");
i18nc("slovenia_traditional.kgm", "Frontier");
i18nc("slovenia_traditional.kgm", "Water");
i18nc("slovenia_traditional.kgm", "Not Slovenia (Traditional)");
i18nc("slovenia_traditional.kgm", "Upper Carniola");
i18nc("slovenia_traditional.kgm", "Kranj");
i18nc("slovenia_traditional.kgm", "Styria");
i18nc("slovenia_traditional.kgm", "Maribor");
i18nc("slovenia_traditional.kgm", "Prekmurje");
i18nc("slovenia_traditional.kgm", "Murska Sobota");
i18nc("slovenia_traditional.kgm", "Carinthia");
i18nc("slovenia_traditional.kgm", "Dravograd");
i18nc("slovenia_traditional.kgm", "Inner Carniola");
i18nc("slovenia_traditional.kgm", "Postojna");
i18nc("slovenia_traditional.kgm", "Lower Carniola");
i18nc("slovenia_traditional.kgm", "Novo Mesto");
i18nc("slovenia_traditional.kgm", "Goriška");
i18nc("slovenia_traditional.kgm", "Nova Gorica");
i18nc("slovenia_traditional.kgm", "Slovenian Istria");
i18nc("slovenia_traditional.kgm", "Koper");
i18nc("south_africa.kgm", "South Africa");
i18nc("south_africa.kgm", "Provinces");
i18nc("south_africa.kgm", "Frontier");
i18nc("south_africa.kgm", "Not South Africa");
i18nc("south_africa.kgm", "Water");
i18nc("south_africa.kgm", "Eastern Cape");
i18nc("south_africa.kgm", "Bisho");
i18nc("south_africa.kgm", "Free State");
i18nc("south_africa.kgm", "Bloemfontein");
i18nc("south_africa.kgm", "Gauteng");
i18nc("south_africa.kgm", "Johannesburg");
i18nc("south_africa.kgm", "KwaZulu-Natal");
i18nc("south_africa.kgm", "Pietermaritzburg");
i18nc("south_africa.kgm", "Mpumalanga");
i18nc("south_africa.kgm", "Nelspruit");
i18nc("south_africa.kgm", "Limpopo");
i18nc("south_africa.kgm", "Polokwane");
i18nc("south_africa.kgm", "Northern Cape");
i18nc("south_africa.kgm", "Kimberley");
i18nc("south_africa.kgm", "North West");
i18nc("south_africa.kgm", "Mafikeng");
i18nc("south_africa.kgm", "Western Cape");
i18nc("south_africa.kgm", "Cape Town");
i18nc("southamerica.kgm", "South America");
i18nc("southamerica.kgm", "Countries");
i18nc("southamerica.kgm", "Frontier");
i18nc("southamerica.kgm", "Water");
i18nc("southamerica.kgm", "Coast");
i18nc("southamerica.kgm", "Panama");
i18nc("southamerica.kgm", "Colombia");
i18nc("southamerica.kgm", "Bogotá");
i18nc("southamerica.kgm", "Venezuela");
i18nc("southamerica.kgm", "Caracas");
i18nc("southamerica.kgm", "Guyana");
i18nc("southamerica.kgm", "Georgetown");
i18nc("southamerica.kgm", "Suriname");
i18nc("southamerica.kgm", "Paramaribo");
i18nc("southamerica.kgm", "French Guiana");
i18nc("southamerica.kgm", "Cayenne");
i18nc("southamerica.kgm", "Ecuador");
i18nc("southamerica.kgm", "Quito");
i18nc("southamerica.kgm", "Peru");
i18nc("southamerica.kgm", "Lima");
i18nc("southamerica.kgm", "Brazil");
i18nc("southamerica.kgm", "Brasilia");
i18nc("southamerica.kgm", "Bolivia");
i18nc("southamerica.kgm", "La Paz");
i18nc("southamerica.kgm", "Chile");
i18nc("southamerica.kgm", "Santiago");
i18nc("southamerica.kgm", "Paraguay");
i18nc("southamerica.kgm", "Asunción");
i18nc("southamerica.kgm", "Argentina");
i18nc("southamerica.kgm", "Buenos Aires");
i18nc("southamerica.kgm", "Uruguay");
i18nc("southamerica.kgm", "Montevideo");
i18nc("southkorea.kgm", "Republic of Korea");
i18nc("southkorea.kgm", "Regions");
i18nc("southkorea.kgm", "Out of Bounds");
i18nc("southkorea.kgm", "Frontier");
i18nc("southkorea.kgm", "Chungcheongbuk-do");
i18nc("southkorea.kgm", "Cheongju");
i18nc("southkorea.kgm", "Chungcheongnam-do");
i18nc("southkorea.kgm", "Daejon");
i18nc("southkorea.kgm", "Daejon");
i18nc("southkorea.kgm", "Jeollabuk-do");
i18nc("southkorea.kgm", "Jeonju");
i18nc("southkorea.kgm", "Jeollanam-do");
i18nc("southkorea.kgm", "Muan");
i18nc("southkorea.kgm", "Jeju-do");
i18nc("southkorea.kgm", "Jeju");
i18nc("southkorea.kgm", "Gyeongsangnam-do");
i18nc("southkorea.kgm", "Changwon");
i18nc("southkorea.kgm", "Gyeongsangbuk-do");
i18nc("southkorea.kgm", "Daegu");
i18nc("southkorea.kgm", "Daegu");
i18nc("southkorea.kgm", "Gangwon-do");
i18nc("southkorea.kgm", "Chuncheon");
i18nc("southkorea.kgm", "Gyeonggi-do");
i18nc("southkorea.kgm", "Suwon");
i18nc("southkorea.kgm", "Ulsan");
i18nc("southkorea.kgm", "Gwangju");
i18nc("southkorea.kgm", "Busan");
i18nc("southkorea.kgm", "Seoul");
i18nc("southkorea.kgm", "Incheon");
i18nc("spain.kgm", "Spain");
i18nc("spain.kgm", "Autonomous communities");
i18nc("spain.kgm", "Not Spain");
i18nc("spain.kgm", "Frontier");
i18nc("spain.kgm", "External frontier");
i18nc("spain.kgm", "Andalucia");
i18nc("spain.kgm", "Seville");
i18nc("spain.kgm", "Aragon");
i18nc("spain.kgm", "Zaragoza");
i18nc("spain.kgm", "Asturias");
i18nc("spain.kgm", "Oviedo");
i18nc("spain.kgm", "Balearic Islands");
i18nc("spain.kgm", "Palma de Mallorca");
i18nc("spain.kgm", "Basque Country");
i18nc("spain.kgm", "Vitoria");
i18nc("spain.kgm", "Canary Islands");
i18nc("spain.kgm", "Las Palmas de Gran Canaria and Santa Cruz de Tenerife");
i18nc("spain.kgm", "Cantabria");
i18nc("spain.kgm", "Santander");
i18nc("spain.kgm", "Castile-La Mancha");
i18nc("spain.kgm", "Toledo");
i18nc("spain.kgm", "Castile and Leon");
i18nc("spain.kgm", "Valladolid");
i18nc("spain.kgm", "Catalonia");
i18nc("spain.kgm", "Barcelona");
i18nc("spain.kgm", "Extremadura");
i18nc("spain.kgm", "Mérida");
i18nc("spain.kgm", "Galicia");
i18nc("spain.kgm", "Santiago de Compostela");
i18nc("spain.kgm", "La Rioja");
i18nc("spain.kgm", "Logroño");
i18nc("spain.kgm", "Madrid");
i18nc("spain.kgm", "Madrid");
i18nc("spain.kgm", "Murcia");
i18nc("spain.kgm", "Murcia");
i18nc("spain.kgm", "Navarre");
i18nc("spain.kgm", "Pamplona");
i18nc("spain.kgm", "Valencian Community");
i18nc("spain.kgm", "Valencia");
i18nc("spain_provinces.kgm", "Spain (Provinces)");
i18nc("spain_provinces.kgm", "Provinces");
i18nc("spain_provinces.kgm", "Frontier");
i18nc("spain_provinces.kgm", "Frontier");
i18nc("spain_provinces.kgm", "France");
i18nc("spain_provinces.kgm", "Andorra");
i18nc("spain_provinces.kgm", "Portugal");
i18nc("spain_provinces.kgm", "Morocco");
i18nc("spain_provinces.kgm", "Algeria");
i18nc("spain_provinces.kgm", "Water");
i18nc("spain_provinces.kgm", "Álava");
i18nc("spain_provinces.kgm", "Vitoria");
i18nc("spain_provinces.kgm", "Albacete");
i18nc("spain_provinces.kgm", "Albacete");
i18nc("spain_provinces.kgm", "Alicante");
i18nc("spain_provinces.kgm", "Alicante");
i18nc("spain_provinces.kgm", "Almería");
i18nc("spain_provinces.kgm", "Almería");
i18nc("spain_provinces.kgm", "Asturias");
i18nc("spain_provinces.kgm", "Oviedo");
i18nc("spain_provinces.kgm", "Ávila");
i18nc("spain_provinces.kgm", "Ávila");
i18nc("spain_provinces.kgm", "Badajoz");
i18nc("spain_provinces.kgm", "Badajoz");
i18nc("spain_provinces.kgm", "Barcelona");
i18nc("spain_provinces.kgm", "Barcelona");
i18nc("spain_provinces.kgm", "Burgos");
i18nc("spain_provinces.kgm", "Burgos");
i18nc("spain_provinces.kgm", "Cáceres");
i18nc("spain_provinces.kgm", "Cáceres");
i18nc("spain_provinces.kgm", "Cádiz");
i18nc("spain_provinces.kgm", "Cádiz");
i18nc("spain_provinces.kgm", "Cantabria");
i18nc("spain_provinces.kgm", "Santander");
i18nc("spain_provinces.kgm", "Castellón");
i18nc("spain_provinces.kgm", "Castellón de la Plana");
i18nc("spain_provinces.kgm", "Ciudad Real");
i18nc("spain_provinces.kgm", "Ciudad Real");
i18nc("spain_provinces.kgm", "Córdoba");
i18nc("spain_provinces.kgm", "Córdoba");
i18nc("spain_provinces.kgm", "A Coruña");
i18nc("spain_provinces.kgm", "A Coruña");
i18nc("spain_provinces.kgm", "Cuenca");
i18nc("spain_provinces.kgm", "Cuenca");
i18nc("spain_provinces.kgm", "Girona");
i18nc("spain_provinces.kgm", "Gerona/Girona");
i18nc("spain_provinces.kgm", "Granada");
i18nc("spain_provinces.kgm", "Granada");
i18nc("spain_provinces.kgm", "Guadalajara");
i18nc("spain_provinces.kgm", "Guadalajara");
i18nc("spain_provinces.kgm", "Guipúzcoa");
i18nc("spain_provinces.kgm", "San Sebastián");
i18nc("spain_provinces.kgm", "Huelva");
i18nc("spain_provinces.kgm", "Huelva");
i18nc("spain_provinces.kgm", "Huesca");
i18nc("spain_provinces.kgm", "Huesca");
i18nc("spain_provinces.kgm", "Balearic Islands");
i18nc("spain_provinces.kgm", "Palma de Mallorca");
i18nc("spain_provinces.kgm", "Jaén");
i18nc("spain_provinces.kgm", "Jaén");
i18nc("spain_provinces.kgm", "La Rioja");
i18nc("spain_provinces.kgm", "Logroño");
i18nc("spain_provinces.kgm", "León");
i18nc("spain_provinces.kgm", "León");
i18nc("spain_provinces.kgm", "Lérida");
i18nc("spain_provinces.kgm", "Lérida");
i18nc("spain_provinces.kgm", "Lugo");
i18nc("spain_provinces.kgm", "Lugo");
i18nc("spain_provinces.kgm", "Madrid");
i18nc("spain_provinces.kgm", "Madrid");
i18nc("spain_provinces.kgm", "Málaga");
i18nc("spain_provinces.kgm", "Málaga");
i18nc("spain_provinces.kgm", "Murcia");
i18nc("spain_provinces.kgm", "Murcia");
i18nc("spain_provinces.kgm", "Navarre");
i18nc("spain_provinces.kgm", "Pamplona");
i18nc("spain_provinces.kgm", "Ourense");
i18nc("spain_provinces.kgm", "Ourense");
i18nc("spain_provinces.kgm", "Palencia");
i18nc("spain_provinces.kgm", "Palencia");
i18nc("spain_provinces.kgm", "Las Palmas");
i18nc("spain_provinces.kgm", "Las Palmas de Gran Canaria");
i18nc("spain_provinces.kgm", "Pontevedra");
i18nc("spain_provinces.kgm", "Pontevedra");
i18nc("spain_provinces.kgm", "Salamanca");
i18nc("spain_provinces.kgm", "Salamanca");
i18nc("spain_provinces.kgm", "Santa Cruz de Tenerife");
i18nc("spain_provinces.kgm", "Santa Cruz de Tenerife");
i18nc("spain_provinces.kgm", "Segovia");
i18nc("spain_provinces.kgm", "Segovia");
i18nc("spain_provinces.kgm", "Seville");
i18nc("spain_provinces.kgm", "Seville");
i18nc("spain_provinces.kgm", "Soria");
i18nc("spain_provinces.kgm", "Soria");
i18nc("spain_provinces.kgm", "Tarragona");
i18nc("spain_provinces.kgm", "Tarragona");
i18nc("spain_provinces.kgm", "Teruel");
i18nc("spain_provinces.kgm", "Teruel");
i18nc("spain_provinces.kgm", "Toledo");
i18nc("spain_provinces.kgm", "Toledo");
i18nc("spain_provinces.kgm", "Valencia");
i18nc("spain_provinces.kgm", "Valencia");
i18nc("spain_provinces.kgm", "Valladolid");
i18nc("spain_provinces.kgm", "Valladolid");
i18nc("spain_provinces.kgm", "Biscay");
i18nc("spain_provinces.kgm", "Bilbao");
i18nc("spain_provinces.kgm", "Zamora");
i18nc("spain_provinces.kgm", "Zamora");
i18nc("spain_provinces.kgm", "Zaragoza");
i18nc("spain_provinces.kgm", "Zaragoza");
i18nc("sri-lanka.kgm", "Sri-Lanka");
i18nc("sri-lanka.kgm", "Provinces");
i18nc("sri-lanka.kgm", "Frontier");
i18nc("sri-lanka.kgm", "Water");
i18nc("sri-lanka.kgm", "Not Sri-Lanka");
i18nc("sri-lanka.kgm", "Central");
i18nc("sri-lanka.kgm", "Kandy");
i18nc("sri-lanka.kgm", "North Central");
i18nc("sri-lanka.kgm", "Anuradhapura");
i18nc("sri-lanka.kgm", "North");
i18nc("sri-lanka.kgm", "Jaffna");
i18nc("sri-lanka.kgm", "Eastern");
i18nc("sri-lanka.kgm", "Trincomalee");
i18nc("sri-lanka.kgm", "North Western");
i18nc("sri-lanka.kgm", "Kurunegala");
i18nc("sri-lanka.kgm", "Southern");
i18nc("sri-lanka.kgm", "Galle");
i18nc("sri-lanka.kgm", "Uva");
i18nc("sri-lanka.kgm", "Badulla");
i18nc("sri-lanka.kgm", "Sabaragamuwa");
i18nc("sri-lanka.kgm", "Ratnapura");
i18nc("sri-lanka.kgm", "Western");
i18nc("sri-lanka.kgm", "Colombo");
i18nc("sudan.kgm", "Sudan");
i18nc("sudan.kgm", "States");
i18nc("sudan.kgm", "Frontier");
i18nc("sudan.kgm", "Not Sudan");
i18nc("sudan.kgm", "Water");
i18nc("sudan.kgm", "Al Jazirah");
i18nc("sudan.kgm", "Wad-Madani");
i18nc("sudan.kgm", "Blue Nile/Central");
i18nc("sudan.kgm", "Ad-Damazin");
i18nc("sudan.kgm", "Sennar");
i18nc("sudan.kgm", "Sennar");
i18nc("sudan.kgm", "White Nile");
i18nc("sudan.kgm", "Rabak");
i18nc("sudan.kgm", "North Darfur");
i18nc("sudan.kgm", "Al-Fashir");
i18nc("sudan.kgm", "South Darfur");
i18nc("sudan.kgm", "Nyala");
i18nc("sudan.kgm", "West Darfur");
i18nc("sudan.kgm", "Al-Junaynah");
i18nc("sudan.kgm", "Kassala");
i18nc("sudan.kgm", "Kassala");
i18nc("sudan.kgm", "Al Qadarif");
i18nc("sudan.kgm", "Al Qadarif");
i18nc("sudan.kgm", "Red Sea");
i18nc("sudan.kgm", "Port Sudan");
i18nc("sudan.kgm", "Khartoum");
i18nc("sudan.kgm", "Khartoum");
i18nc("sudan.kgm", "North Kurdufan");
i18nc("sudan.kgm", "Al-Ubayyid");
i18nc("sudan.kgm", "South Kurdufan");
i18nc("sudan.kgm", "Kaduqli");
i18nc("sudan.kgm", "Northern");
i18nc("sudan.kgm", "Dongola");
i18nc("sudan.kgm", "River Nile");
i18nc("sudan.kgm", "Ad-Damir");
i18nc("suriname.kgm", "Suriname");
i18nc("suriname.kgm", "Districts");
i18nc("suriname.kgm", "Frontier");
i18nc("suriname.kgm", "Frontier");
i18nc("suriname.kgm", "Water");
i18nc("suriname.kgm", "Not Surinam");
i18nc("suriname.kgm", "Nickerie");
i18nc("suriname.kgm", "Nieuw Nickerie");
i18nc("suriname.kgm", "Coronie");
i18nc("suriname.kgm", "Totness");
i18nc("suriname.kgm", "Saramacca");
i18nc("suriname.kgm", "Groningen");
i18nc("suriname.kgm", "Wanica");
i18nc("suriname.kgm", "Lelydorp");
i18nc("suriname.kgm", "Comewijne");
i18nc("suriname.kgm", "Nieuw Amsterdam");
i18nc("suriname.kgm", "Marowijne");
i18nc("suriname.kgm", "Albina");
i18nc("suriname.kgm", "Para");
i18nc("suriname.kgm", "Onverwacht");
i18nc("suriname.kgm", "Paramaribo");
i18nc("suriname.kgm", "Paramaribo");
i18nc("suriname.kgm", "Brokopondo");
i18nc("suriname.kgm", "Brokopondo");
i18nc("suriname.kgm", "Sipaliwini");
i18nc("sweden.kgm", "Sweden by Counties");
i18nc("sweden.kgm", "Counties");
i18nc("sweden.kgm", "Frontier");
i18nc("sweden.kgm", "County Border");
i18nc("sweden.kgm", "CoastLine");
i18nc("sweden.kgm", "Not Sweden");
i18nc("sweden.kgm", "Stockholm County");
i18nc("sweden.kgm", "Stockholm");
i18nc("sweden.kgm", "Västerbotten County");
i18nc("sweden.kgm", "Umeå");
i18nc("sweden.kgm", "Norrbotten County");
i18nc("sweden.kgm", "Luleå");
i18nc("sweden.kgm", "Uppsala County");
i18nc("sweden.kgm", "Uppsala");
i18nc("sweden.kgm", "Södermanland County");
i18nc("sweden.kgm", "Nyköping");
i18nc("sweden.kgm", "Östergötland County");
i18nc("sweden.kgm", "Linköping");
i18nc("sweden.kgm", "Jönköping County");
i18nc("sweden.kgm", "Jönköping");
i18nc("sweden.kgm", "Kronoberg County");
i18nc("sweden.kgm", "Växjö");
i18nc("sweden.kgm", "Kalmar County");
i18nc("sweden.kgm", "Kalmar");
i18nc("sweden.kgm", "Gotland County");
i18nc("sweden.kgm", "Visby");
i18nc("sweden.kgm", "Blekinge County");
i18nc("sweden.kgm", "Karlskrona");
i18nc("sweden.kgm", "Skåne County");
i18nc("sweden.kgm", "Malmö");
i18nc("sweden.kgm", "Halland County");
i18nc("sweden.kgm", "Halmstad");
i18nc("sweden.kgm", "Västra Götaland County");
i18nc("sweden.kgm", "Göteborg");
i18nc("sweden.kgm", "Värmland County");
i18nc("sweden.kgm", "Karlstad");
i18nc("sweden.kgm", "Örebro County");
i18nc("sweden.kgm", "Örebro");
i18nc("sweden.kgm", "Västmanland County");
i18nc("sweden.kgm", "Västerås");
i18nc("sweden.kgm", "Dalarna County");
i18nc("sweden.kgm", "Falun");
i18nc("sweden.kgm", "Gävleborg County");
i18nc("sweden.kgm", "Gävle");
i18nc("sweden.kgm", "Västernorrland County");
i18nc("sweden.kgm", "Härnösand");
i18nc("sweden.kgm", "Jämtland County");
i18nc("sweden.kgm", "Östersund");
i18nc("switzerland.kgm", "Switzerland");
i18nc("switzerland.kgm", "Cantons");
i18nc("switzerland.kgm", "Frontier");
i18nc("switzerland.kgm", "Not Switzerland");
i18nc("switzerland.kgm", "Water");
i18nc("switzerland.kgm", "Zurich");
i18nc("switzerland.kgm", "Zürich");
i18nc("switzerland.kgm", "Berne");
i18nc("switzerland.kgm", "Bern");
i18nc("switzerland.kgm", "Lucerne");
i18nc("switzerland.kgm", "Lucerne");
i18nc("switzerland.kgm", "Uri");
i18nc("switzerland.kgm", "Altdorf");
i18nc("switzerland.kgm", "Schwyz");
i18nc("switzerland.kgm", "Schwyz");
i18nc("switzerland.kgm", "Obwald");
i18nc("switzerland.kgm", "Sarnen");
i18nc("switzerland.kgm", "Nidwald");
i18nc("switzerland.kgm", "Stans");
i18nc("switzerland.kgm", "Glarus");
i18nc("switzerland.kgm", "Glarus");
i18nc("switzerland.kgm", "Zug");
i18nc("switzerland.kgm", "Zug");
i18nc("switzerland.kgm", "Fribourg");
i18nc("switzerland.kgm", "Fribourg");
i18nc("switzerland.kgm", "Solothurn");
i18nc("switzerland.kgm", "Solothurn");
i18nc("switzerland.kgm", "Basle-City");
i18nc("switzerland.kgm", "Basel");
i18nc("switzerland.kgm", "Basle-Country");
i18nc("switzerland.kgm", "Liestal");
i18nc("switzerland.kgm", "Schaffhausen");
i18nc("switzerland.kgm", "Schaffhausen");
i18nc("switzerland.kgm", "Appenzell Outer Rhodes");
i18nc("switzerland.kgm", "Herisau");
i18nc("switzerland.kgm", "Appenzell Inner Rhodes");
i18nc("switzerland.kgm", "Appenzell");
i18nc("switzerland.kgm", "St. Gall");
i18nc("switzerland.kgm", "St. Gallen");
i18nc("switzerland.kgm", "Grisons");
i18nc("switzerland.kgm", "Chur");
i18nc("switzerland.kgm", "Argovia");
i18nc("switzerland.kgm", "Aarau");
i18nc("switzerland.kgm", "Thurgovia");
i18nc("switzerland.kgm", "Frauenfeld");
i18nc("switzerland.kgm", "Ticino");
i18nc("switzerland.kgm", "Bellinzona");
i18nc("switzerland.kgm", "Vaud");
i18nc("switzerland.kgm", "Lausanne");
i18nc("switzerland.kgm", "Valais");
i18nc("switzerland.kgm", "Sion");
i18nc("switzerland.kgm", "Neuchâtel");
i18nc("switzerland.kgm", "Neuchâtel");
i18nc("switzerland.kgm", "Geneva");
i18nc("switzerland.kgm", "Geneva");
i18nc("switzerland.kgm", "Jura");
i18nc("switzerland.kgm", "Delémont");
i18nc("tajikistan.kgm", "Tajikistan");
i18nc("tajikistan.kgm", "Provinces");
i18nc("tajikistan.kgm", "Frontier");
i18nc("tajikistan.kgm", "Water");
i18nc("tajikistan.kgm", "Not Tajikistan");
i18nc("tajikistan.kgm", "Sughd");
i18nc("tajikistan.kgm", "Khujand");
i18nc("tajikistan.kgm", "Districts of Republican Subordination");
i18nc("tajikistan.kgm", "Dushanbe");
i18nc("tajikistan.kgm", "Khatlon");
i18nc("tajikistan.kgm", "Qurghonteppa");
i18nc("tajikistan.kgm", "Gorno-Badakhshan");
i18nc("tajikistan.kgm", "Khorugh");
i18nc("thailand.kgm", "Thailand");
i18nc("thailand.kgm", "Provinces");
i18nc("thailand.kgm", "Frontier");
i18nc("thailand.kgm", "Water");
i18nc("thailand.kgm", "Not Thailand");
i18nc("thailand.kgm", "Chiang Mai");
i18nc("thailand.kgm", "Chiang Rai");
i18nc("thailand.kgm", "Kamphaeng Phet");
i18nc("thailand.kgm", "Lampang");
i18nc("thailand.kgm", "Lamphun");
i18nc("thailand.kgm", "Mae Hong Son");
i18nc("thailand.kgm", "Nakhon Sawan");
i18nc("thailand.kgm", "Nan");
i18nc("thailand.kgm", "Phayao");
i18nc("thailand.kgm", "Phetchabun");
i18nc("thailand.kgm", "Phichit");
i18nc("thailand.kgm", "Phitsanulok");
i18nc("thailand.kgm", "Phrae");
i18nc("thailand.kgm", "Sukhothai");
i18nc("thailand.kgm", "Tak");
i18nc("thailand.kgm", "Uthai Thani");
i18nc("thailand.kgm", "Uttaradit");
i18nc("thailand.kgm", "Amnat Charoen");
i18nc("thailand.kgm", "Buri Ram");
i18nc("thailand.kgm", "Chaiyaphum");
i18nc("thailand.kgm", "Kalasin");
i18nc("thailand.kgm", "Khon Kaen");
i18nc("thailand.kgm", "Loei");
i18nc("thailand.kgm", "Maha Sarakham");
i18nc("thailand.kgm", "Mukdahan");
i18nc("thailand.kgm", "Nakhon Phanom");
i18nc("thailand.kgm", "Nakhon Ratchasima");
i18nc("thailand.kgm", "Nong Bua Lamphu");
i18nc("thailand.kgm", "Nong Khai");
i18nc("thailand.kgm", "Roi Et");
i18nc("thailand.kgm", "Sakon Nakhon");
i18nc("thailand.kgm", "Si Sa Ket");
i18nc("thailand.kgm", "Surin");
i18nc("thailand.kgm", "Ubon Ratchathani");
i18nc("thailand.kgm", "Udon Thani");
i18nc("thailand.kgm", "Yasothon");
i18nc("thailand.kgm", "Chachoengsao");
i18nc("thailand.kgm", "Chanthaburi");
i18nc("thailand.kgm", "Chon Buri");
i18nc("thailand.kgm", "Prachin Buri");
i18nc("thailand.kgm", "Rayong");
i18nc("thailand.kgm", "Sa Kaeo");
i18nc("thailand.kgm", "Trat");
i18nc("thailand.kgm", "Ang Thong");
i18nc("thailand.kgm", "Phra Nakhon Si Ayutthaya");
i18nc("thailand.kgm", "Bangkok");
i18nc("thailand.kgm", "Chainat");
i18nc("thailand.kgm", "Kanchanaburi");
i18nc("thailand.kgm", "Lop Buri");
i18nc("thailand.kgm", "Nakhon Nayok");
i18nc("thailand.kgm", "Nakhon Pathom");
i18nc("thailand.kgm", "Nonthaburi");
i18nc("thailand.kgm", "Pathum Thani");
i18nc("thailand.kgm", "Phetchaburi");
i18nc("thailand.kgm", "Prachuap Khiri Khan");
i18nc("thailand.kgm", "Ratchaburi");
i18nc("thailand.kgm", "Samut Prakan");
i18nc("thailand.kgm", "Samut Sakhon");
i18nc("thailand.kgm", "Samut Songkhram");
i18nc("thailand.kgm", "Saraburi");
i18nc("thailand.kgm", "Sing Buri");
i18nc("thailand.kgm", "Suphan Buri");
i18nc("thailand.kgm", "Chumphon");
i18nc("thailand.kgm", "Krabi");
i18nc("thailand.kgm", "Nakhon Si Thammarat");
i18nc("thailand.kgm", "Narathiwat");
i18nc("thailand.kgm", "Pattani");
i18nc("thailand.kgm", "Phang Nga");
i18nc("thailand.kgm", "Phatthalung");
i18nc("thailand.kgm", "Phuket");
i18nc("thailand.kgm", "Ranong");
i18nc("thailand.kgm", "Satun");
i18nc("thailand.kgm", "Songkhla");
i18nc("thailand.kgm", "Surat Thani");
i18nc("thailand.kgm", "Trang");
i18nc("thailand.kgm", "Yala");
i18nc("tripura.kgm", "Tripura");
i18nc("tripura.kgm", "District");
i18nc("tripura.kgm", "Not Tripura");
i18nc("tripura.kgm", "Border");
i18nc("tripura.kgm", "Dhalai");
i18nc("tripura.kgm", "Ambassa");
i18nc("tripura.kgm", "North Tripura");
i18nc("tripura.kgm", "Kailashahar");
i18nc("tripura.kgm", "South Tripura");
i18nc("tripura.kgm", "Udaipur");
i18nc("tripura.kgm", "West Tripura");
i18nc("tripura.kgm", "Agartala");
i18nc("turkey.kgm", "Turkey");
i18nc("turkey.kgm", "Provinces");
i18nc("turkey.kgm", "Frontier");
i18nc("turkey.kgm", "Water");
i18nc("turkey.kgm", "Not Turkey");
i18nc("turkey.kgm", "Adana");
i18nc("turkey.kgm", "Adana");
i18nc("turkey.kgm", "Adıyaman");
i18nc("turkey.kgm", "Adıyaman");
i18nc("turkey.kgm", "Afyonkarahisar");
i18nc("turkey.kgm", "Afyon");
i18nc("turkey.kgm", "Ağrı");
i18nc("turkey.kgm", "Ağrı");
i18nc("turkey.kgm", "Amasya");
i18nc("turkey.kgm", "Amasya");
i18nc("turkey.kgm", "Ankara");
i18nc("turkey.kgm", "Ankara");
i18nc("turkey.kgm", "Antalya");
i18nc("turkey.kgm", "Antalya");
i18nc("turkey.kgm", "Artvin");
i18nc("turkey.kgm", "Artvin");
i18nc("turkey.kgm", "Aydın");
i18nc("turkey.kgm", "Aydın");
i18nc("turkey.kgm", "Balıkesir");
i18nc("turkey.kgm", "Balıkesir");
i18nc("turkey.kgm", "Bilecik");
i18nc("turkey.kgm", "Bilecik");
i18nc("turkey.kgm", "Bingöl");
i18nc("turkey.kgm", "Bingöl");
i18nc("turkey.kgm", "Bitlis");
i18nc("turkey.kgm", "Bitlis");
i18nc("turkey.kgm", "Bolu");
i18nc("turkey.kgm", "Bolu");
i18nc("turkey.kgm", "Burdur");
i18nc("turkey.kgm", "Burdur");
i18nc("turkey.kgm", "Bursa");
i18nc("turkey.kgm", "Bursa");
i18nc("turkey.kgm", "Çanakkale");
i18nc("turkey.kgm", "Çanakkale");
i18nc("turkey.kgm", "Çankırı");
i18nc("turkey.kgm", "Çankırı");
i18nc("turkey.kgm", "Çorum");
i18nc("turkey.kgm", "Çorum");
i18nc("turkey.kgm", "Denizli");
i18nc("turkey.kgm", "Denizli");
i18nc("turkey.kgm", "Diyarbakır");
i18nc("turkey.kgm", "Diyarbakır");
i18nc("turkey.kgm", "Edirne");
i18nc("turkey.kgm", "Edirne");
i18nc("turkey.kgm", "Elazığ");
i18nc("turkey.kgm", "Elazığ");
i18nc("turkey.kgm", "Erzincan");
i18nc("turkey.kgm", "Erzincan");
i18nc("turkey.kgm", "Erzurum");
i18nc("turkey.kgm", "Erzurum");
i18nc("turkey.kgm", "Eskişehir");
i18nc("turkey.kgm", "Eskişehir");
i18nc("turkey.kgm", "Gaziantep");
i18nc("turkey.kgm", "Gaziantep");
i18nc("turkey.kgm", "Giresun");
i18nc("turkey.kgm", "Giresun");
i18nc("turkey.kgm", "Gümüşhane");
i18nc("turkey.kgm", "Gümüşhane");
i18nc("turkey.kgm", "Hakkari");
i18nc("turkey.kgm", "Hakkari");
i18nc("turkey.kgm", "Hatay");
i18nc("turkey.kgm", "Antakya");
i18nc("turkey.kgm", "Isparta");
i18nc("turkey.kgm", "Isparta");
i18nc("turkey.kgm", "Mersin");
i18nc("turkey.kgm", "Mersin");
i18nc("turkey.kgm", "İstanbul");
i18nc("turkey.kgm", "İstanbul");
i18nc("turkey.kgm", "İzmir");
i18nc("turkey.kgm", "İzmir");
i18nc("turkey.kgm", "Kars");
i18nc("turkey.kgm", "Kars");
i18nc("turkey.kgm", "Kastamonu");
i18nc("turkey.kgm", "Kastamonu");
i18nc("turkey.kgm", "Kayseri");
i18nc("turkey.kgm", "Kayseri");
i18nc("turkey.kgm", "Kırklareli");
i18nc("turkey.kgm", "Kırklareli");
i18nc("turkey.kgm", "Kırşehir");
i18nc("turkey.kgm", "Kırşehir");
i18nc("turkey.kgm", "Kocaeli");
i18nc("turkey.kgm", "İzmit");
i18nc("turkey.kgm", "Konya");
i18nc("turkey.kgm", "Konya");
i18nc("turkey.kgm", "Kütahya");
i18nc("turkey.kgm", "Kütahya");
i18nc("turkey.kgm", "Malatya");
i18nc("turkey.kgm", "Malatya");
i18nc("turkey.kgm", "Manisa");
i18nc("turkey.kgm", "Manisa");
i18nc("turkey.kgm", "Kahramanmaraş");
i18nc("turkey.kgm", "Kahramanmaraş");
i18nc("turkey.kgm", "Mardin");
i18nc("turkey.kgm", "Mardin");
i18nc("turkey.kgm", "Muğla");
i18nc("turkey.kgm", "Muğla");
i18nc("turkey.kgm", "Muş");
i18nc("turkey.kgm", "Muş");
i18nc("turkey.kgm", "Nevşehir");
i18nc("turkey.kgm", "Nevşehir");
i18nc("turkey.kgm", "Niğde");
i18nc("turkey.kgm", "Niğde");
i18nc("turkey.kgm", "Ordu");
i18nc("turkey.kgm", "Ordu");
i18nc("turkey.kgm", "Rize");
i18nc("turkey.kgm", "Rize");
i18nc("turkey.kgm", "Sakarya");
i18nc("turkey.kgm", "Adapazarı");
i18nc("turkey.kgm", "Samsun");
i18nc("turkey.kgm", "Samsun");
i18nc("turkey.kgm", "Siirt");
i18nc("turkey.kgm", "Siirt");
i18nc("turkey.kgm", "Sinop");
i18nc("turkey.kgm", "Sinop");
i18nc("turkey.kgm", "Sivas");
i18nc("turkey.kgm", "Sivas");
i18nc("turkey.kgm", "Tekirdağ");
i18nc("turkey.kgm", "Tekirdağ");
i18nc("turkey.kgm", "Tokat");
i18nc("turkey.kgm", "Tokat");
i18nc("turkey.kgm", "Trabzon");
i18nc("turkey.kgm", "Trabzon");
i18nc("turkey.kgm", "Tunceli");
i18nc("turkey.kgm", "Tunceli");
i18nc("turkey.kgm", "Şanlıurfa");
i18nc("turkey.kgm", "Şanlıurfa");
i18nc("turkey.kgm", "Uşak");
i18nc("turkey.kgm", "Uşak");
i18nc("turkey.kgm", "Van");
i18nc("turkey.kgm", "Van");
i18nc("turkey.kgm", "Yozgat");
i18nc("turkey.kgm", "Yozgat");
i18nc("turkey.kgm", "Zonguldak");
i18nc("turkey.kgm", "Zonguldak");
i18nc("turkey.kgm", "Aksaray");
i18nc("turkey.kgm", "Aksaray");
i18nc("turkey.kgm", "Bayburt");
i18nc("turkey.kgm", "Bayburt");
i18nc("turkey.kgm", "Karaman");
i18nc("turkey.kgm", "Karaman");
i18nc("turkey.kgm", "Kırıkkale");
i18nc("turkey.kgm", "Kırıkkale");
i18nc("turkey.kgm", "Batman");
i18nc("turkey.kgm", "Batman");
i18nc("turkey.kgm", "Şırnak");
i18nc("turkey.kgm", "Şırnak");
i18nc("turkey.kgm", "Bartın");
i18nc("turkey.kgm", "Bartın");
i18nc("turkey.kgm", "Ardahan");
i18nc("turkey.kgm", "Ardahan");
i18nc("turkey.kgm", "Iğdır");
i18nc("turkey.kgm", "Iğdır");
i18nc("turkey.kgm", "Yalova");
i18nc("turkey.kgm", "Yalova");
i18nc("turkey.kgm", "Karabük");
i18nc("turkey.kgm", "Karabük");
i18nc("turkey.kgm", "Kilis");
i18nc("turkey.kgm", "Kilis");
i18nc("turkey.kgm", "Osmaniye");
i18nc("turkey.kgm", "Osmaniye");
i18nc("turkey.kgm", "Düzce");
i18nc("turkey.kgm", "Düzce");
i18nc("turkmenistan.kgm", "Turkmenistan");
i18nc("turkmenistan.kgm", "Provinces");
i18nc("turkmenistan.kgm", "Frontier");
i18nc("turkmenistan.kgm", "Water");
i18nc("turkmenistan.kgm", "Not Turkmenistan");
i18nc("turkmenistan.kgm", "Ahal");
i18nc("turkmenistan.kgm", "Balkan");
i18nc("turkmenistan.kgm", "Dashhowuz");
i18nc("turkmenistan.kgm", "Lebap");
i18nc("turkmenistan.kgm", "Mary");
i18nc("ukraine.kgm", "Ukraine");
i18nc("ukraine.kgm", "Oblasts");
i18nc("ukraine.kgm", "Volyns'ka oblast'");
i18nc("ukraine.kgm", "Luts'k");
i18nc("ukraine.kgm", "L'vivs'ka oblast'");
i18nc("ukraine.kgm", "L'viv");
i18nc("ukraine.kgm", "Zakarpats'ka oblast'");
i18nc("ukraine.kgm", "Uzhhorod");
i18nc("ukraine.kgm", "Rivnens'ka oblast'");
i18nc("ukraine.kgm", "Rivne");
i18nc("ukraine.kgm", "Ternopil's'ka oblast'");
i18nc("ukraine.kgm", "Ternopil'");
i18nc("ukraine.kgm", "Khmel'nyts'ka oblast'");
i18nc("ukraine.kgm", "Khmel'nyts'ky");
i18nc("ukraine.kgm", "Ivano-Frankivs'ka oblast'");
i18nc("ukraine.kgm", "Ivano-Frankivs'k");
i18nc("ukraine.kgm", "Chernivets'ka oblast'");
i18nc("ukraine.kgm", "Chernivtsi");
i18nc("ukraine.kgm", "Zhytomyrs'ka oblast'");
i18nc("ukraine.kgm", "Zhytomyr");
i18nc("ukraine.kgm", "Vinnyts'ka oblast'");
i18nc("ukraine.kgm", "Vinnytsya");
i18nc("ukraine.kgm", "Kyivs'ka oblast'");
i18nc("ukraine.kgm", "Kyiv");
i18nc("ukraine.kgm", "Cherkas'ka oblast'");
i18nc("ukraine.kgm", "Cherkasy");
i18nc("ukraine.kgm", "Kirovohrads'ka oblast'");
i18nc("ukraine.kgm", "Kirovohrad");
i18nc("ukraine.kgm", "Mykolayivs'ka oblast'");
i18nc("ukraine.kgm", "Mykolayiv");
i18nc("ukraine.kgm", "Odes'ka oblast'");
i18nc("ukraine.kgm", "Odesa");
i18nc("ukraine.kgm", "Chernihivs'ka oblast'");
i18nc("ukraine.kgm", "Chernihiv");
i18nc("ukraine.kgm", "Sums'ka oblast'");
i18nc("ukraine.kgm", "Sumy");
i18nc("ukraine.kgm", "Poltavs'ka oblast'");
i18nc("ukraine.kgm", "Poltava");
i18nc("ukraine.kgm", "Kharkivs'ka oblast'");
i18nc("ukraine.kgm", "Kharkiv");
i18nc("ukraine.kgm", "Dnipropetrovs'ka oblast'");
i18nc("ukraine.kgm", "Dnipropetrovs'k");
i18nc("ukraine.kgm", "Donets'ka oblast'");
i18nc("ukraine.kgm", "Donets'k");
i18nc("ukraine.kgm", "Zaporiz'ka oblast'");
i18nc("ukraine.kgm", "Zaporizhzhia");
i18nc("ukraine.kgm", "Khersons'ka oblast'");
i18nc("ukraine.kgm", "Kherson");
i18nc("ukraine.kgm", "Luhans'ka oblast'");
i18nc("ukraine.kgm", "Luhans'k");
i18nc("ukraine.kgm", "Autonomous Republic of Crimea");
i18nc("ukraine.kgm", "Simferopol'");
i18nc("ukraine.kgm", "City of Kyiv");
i18nc("ukraine.kgm", "City of Sevastopol'");
i18nc("ukraine.kgm", "Dnipro");
i18nc("ukraine.kgm", "Azov Sea");
i18nc("ukraine.kgm", "Black Sea");
i18nc("ukraine.kgm", "Not Ukraine");
i18nc("ukraine.kgm", "Border/Coast");
i18nc("ukraine.kgm", "River");
i18nc("uruguay.kgm", "Uruguay");
i18nc("uruguay.kgm", "Departments");
i18nc("uruguay.kgm", "Frontier");
i18nc("uruguay.kgm", "Frontier");
i18nc("uruguay.kgm", "Water");
i18nc("uruguay.kgm", "Not Uruguay");
i18nc("uruguay.kgm", "Artigas");
i18nc("uruguay.kgm", "Artigas");
i18nc("uruguay.kgm", "Canelones");
i18nc("uruguay.kgm", "Canelones");
i18nc("uruguay.kgm", "Cerro Largo");
i18nc("uruguay.kgm", "Melo");
i18nc("uruguay.kgm", "Colonia");
i18nc("uruguay.kgm", "Colonia");
i18nc("uruguay.kgm", "Durazno");
i18nc("uruguay.kgm", "Durazno");
i18nc("uruguay.kgm", "Flores");
i18nc("uruguay.kgm", "Trinidad");
i18nc("uruguay.kgm", "Florida");
i18nc("uruguay.kgm", "Florida");
i18nc("uruguay.kgm", "Lavalleja");
i18nc("uruguay.kgm", "Minas");
i18nc("uruguay.kgm", "Maldonado");
i18nc("uruguay.kgm", "Maldonado");
i18nc("uruguay.kgm", "Montevideo");
i18nc("uruguay.kgm", "Montevideo");
i18nc("uruguay.kgm", "Paysandú");
i18nc("uruguay.kgm", "Paysandú");
i18nc("uruguay.kgm", "Río Negro");
i18nc("uruguay.kgm", "Fray Bentos");
i18nc("uruguay.kgm", "Rivera");
i18nc("uruguay.kgm", "Rivera");
i18nc("uruguay.kgm", "Rocha");
i18nc("uruguay.kgm", "Rocha");
i18nc("uruguay.kgm", "Salto");
i18nc("uruguay.kgm", "Salto");
i18nc("uruguay.kgm", "San José");
i18nc("uruguay.kgm", "San José");
i18nc("uruguay.kgm", "Soriano");
i18nc("uruguay.kgm", "Mercedes");
i18nc("uruguay.kgm", "Tacuarembó");
i18nc("uruguay.kgm", "Tacuarembó");
i18nc("uruguay.kgm", "Treinta y Tres");
i18nc("uruguay.kgm", "Treinta y Tres");
i18nc("usa.kgm", "USA");
i18nc("usa.kgm", "States");
i18nc("usa.kgm", "Frontier");
i18nc("usa.kgm", "Coast");
i18nc("usa.kgm", "Water");
i18nc("usa.kgm", "Lake Superior");
i18nc("usa.kgm", "Lake Michigan");
i18nc("usa.kgm", "Lake Huron");
i18nc("usa.kgm", "Lake Erie");
i18nc("usa.kgm", "Lake Ontario");
i18nc("usa.kgm", "The Bahamas");
i18nc("usa.kgm", "Cuba");
i18nc("usa.kgm", "Canada");
i18nc("usa.kgm", "Mexico");
i18nc("usa.kgm", "Russia");
i18nc("usa.kgm", "Washington DC");
i18nc("usa.kgm", "Alabama");
i18nc("usa.kgm", "Montgomery");
i18nc("usa.kgm", "Alaska");
i18nc("usa.kgm", "Juneau");
i18nc("usa.kgm", "Arizona");
i18nc("usa.kgm", "Phoenix");
i18nc("usa.kgm", "Arkansas");
i18nc("usa.kgm", "Little Rock");
i18nc("usa.kgm", "California");
i18nc("usa.kgm", "Sacramento");
i18nc("usa.kgm", "Colorado");
i18nc("usa.kgm", "Denver");
i18nc("usa.kgm", "Connecticut");
i18nc("usa.kgm", "Hartford");
i18nc("usa.kgm", "Delaware");
i18nc("usa.kgm", "Dover");
i18nc("usa.kgm", "Florida");
i18nc("usa.kgm", "Tallahassee");
i18nc("usa.kgm", "Georgia");
i18nc("usa.kgm", "Atlanta");
i18nc("usa.kgm", "Hawaii");
i18nc("usa.kgm", "Honolulu");
i18nc("usa.kgm", "Idaho");
i18nc("usa.kgm", "Boise");
i18nc("usa.kgm", "Illinois");
i18nc("usa.kgm", "Springfield");
i18nc("usa.kgm", "Indiana");
i18nc("usa.kgm", "Indianapolis");
i18nc("usa.kgm", "Iowa");
i18nc("usa.kgm", "Des Moines");
i18nc("usa.kgm", "Kansas");
i18nc("usa.kgm", "Topeka");
i18nc("usa.kgm", "Kentucky");
i18nc("usa.kgm", "Frankfort");
i18nc("usa.kgm", "Louisiana");
i18nc("usa.kgm", "Baton Rouge");
i18nc("usa.kgm", "Maine");
i18nc("usa.kgm", "Augusta");
i18nc("usa.kgm", "Maryland");
i18nc("usa.kgm", "Annapolis");
i18nc("usa.kgm", "Massachusetts");
i18nc("usa.kgm", "Boston");
i18nc("usa.kgm", "Michigan");
i18nc("usa.kgm", "Lansing");
i18nc("usa.kgm", "Minnesota");
i18nc("usa.kgm", "Saint Paul");
i18nc("usa.kgm", "Mississippi");
i18nc("usa.kgm", "Jackson");
i18nc("usa.kgm", "Missouri");
i18nc("usa.kgm", "Jefferson City");
i18nc("usa.kgm", "Montana");
i18nc("usa.kgm", "Helena");
i18nc("usa.kgm", "Nebraska");
i18nc("usa.kgm", "Lincoln");
i18nc("usa.kgm", "Nevada");
i18nc("usa.kgm", "Carson City");
i18nc("usa.kgm", "New Hampshire");
i18nc("usa.kgm", "Concord");
i18nc("usa.kgm", "New Jersey");
i18nc("usa.kgm", "Trenton");
i18nc("usa.kgm", "New Mexico");
i18nc("usa.kgm", "Santa Fe");
i18nc("usa.kgm", "New York");
i18nc("usa.kgm", "Albany");
i18nc("usa.kgm", "North Carolina");
i18nc("usa.kgm", "Raleigh");
i18nc("usa.kgm", "North Dakota");
i18nc("usa.kgm", "Bismarck");
i18nc("usa.kgm", "Ohio");
i18nc("usa.kgm", "Columbus");
i18nc("usa.kgm", "Oklahoma");
i18nc("usa.kgm", "Oklahoma City");
i18nc("usa.kgm", "Oregon");
i18nc("usa.kgm", "Salem");
i18nc("usa.kgm", "Pennsylvania");
i18nc("usa.kgm", "Harrisburg");
i18nc("usa.kgm", "Rhode Island");
i18nc("usa.kgm", "Providence");
i18nc("usa.kgm", "South Carolina");
i18nc("usa.kgm", "Columbia");
i18nc("usa.kgm", "South Dakota");
i18nc("usa.kgm", "Pierre");
i18nc("usa.kgm", "Tennessee");
i18nc("usa.kgm", "Nashville");
i18nc("usa.kgm", "Texas");
i18nc("usa.kgm", "Austin");
i18nc("usa.kgm", "Utah");
i18nc("usa.kgm", "Salt Lake City");
i18nc("usa.kgm", "Vermont");
i18nc("usa.kgm", "Montpelier");
i18nc("usa.kgm", "Virginia");
i18nc("usa.kgm", "Richmond");
i18nc("usa.kgm", "Washington");
i18nc("usa.kgm", "Olympia");
i18nc("usa.kgm", "West Virginia");
i18nc("usa.kgm", "Charleston");
i18nc("usa.kgm", "Wisconsin");
i18nc("usa.kgm", "Madison");
i18nc("usa.kgm", "Wyoming");
i18nc("usa.kgm", "Cheyenne");
i18nc("uzbekistan.kgm", "Uzbekistan");
i18nc("uzbekistan.kgm", "Provinces");
i18nc("uzbekistan.kgm", "Frontier");
i18nc("uzbekistan.kgm", "Water");
i18nc("uzbekistan.kgm", "Not Uzbekistan");
i18nc("uzbekistan.kgm", "Andijon");
i18nc("uzbekistan.kgm", "Andijon");
i18nc("uzbekistan.kgm", "Buxoro");
i18nc("uzbekistan.kgm", "Buxoro (Bukhara)");
i18nc("uzbekistan.kgm", "Farg'ona");
i18nc("uzbekistan.kgm", "Farg'ona (Fergana)");
i18nc("uzbekistan.kgm", "Jizzax");
i18nc("uzbekistan.kgm", "Jizzax");
i18nc("uzbekistan.kgm", "Xorazm");
i18nc("uzbekistan.kgm", "Urganch");
i18nc("uzbekistan.kgm", "Namangan");
i18nc("uzbekistan.kgm", "Namangan");
i18nc("uzbekistan.kgm", "Navoiy");
i18nc("uzbekistan.kgm", "Navoiy");
i18nc("uzbekistan.kgm", "Qashqadaryo");
i18nc("uzbekistan.kgm", "Qarshi");
i18nc("uzbekistan.kgm", "Qaraqalpaqstan");
i18nc("uzbekistan.kgm", "Nukus");
i18nc("uzbekistan.kgm", "Samarqand");
i18nc("uzbekistan.kgm", "Samarqand");
i18nc("uzbekistan.kgm", "Sirdaryo");
i18nc("uzbekistan.kgm", "Guliston");
i18nc("uzbekistan.kgm", "Surxondaryo");
i18nc("uzbekistan.kgm", "Termez");
i18nc("uzbekistan.kgm", "Toshkent (Viloyati)");
i18nc("uzbekistan.kgm", "Tashkent");
i18nc("uzbekistan.kgm", "Toshkent (Shahri )");
i18nc("uzbekistan.kgm", "Tashkent");
i18nc("venezuela.kgm", "Venezuela");
i18nc("venezuela.kgm", "States");
i18nc("venezuela.kgm", "Frontier");
i18nc("venezuela.kgm", "Frontier");
i18nc("venezuela.kgm", "Water");
i18nc("venezuela.kgm", "Not Venezuela");
i18nc("venezuela.kgm", "Amazonas");
i18nc("venezuela.kgm", "Puerto Ayacucho");
i18nc("venezuela.kgm", "Anzoátegui");
i18nc("venezuela.kgm", "Barcelona");
i18nc("venezuela.kgm", "Apure");
i18nc("venezuela.kgm", "San Fernando de Apure");
i18nc("venezuela.kgm", "Aragua");
i18nc("venezuela.kgm", "Maracay");
i18nc("venezuela.kgm", "Barinas");
i18nc("venezuela.kgm", "Barinas");
i18nc("venezuela.kgm", "Bolívar");
i18nc("venezuela.kgm", "Ciudad Bolívar");
i18nc("venezuela.kgm", "Carabobo");
i18nc("venezuela.kgm", "Valencia");
i18nc("venezuela.kgm", "Cojedes");
i18nc("venezuela.kgm", "San Carlos");
i18nc("venezuela.kgm", "Delta Amacuro");
i18nc("venezuela.kgm", "Tucupita");
i18nc("venezuela.kgm", "Falcón");
i18nc("venezuela.kgm", "Coro");
i18nc("venezuela.kgm", "Guárico");
i18nc("venezuela.kgm", "San Juan De Los Morros");
i18nc("venezuela.kgm", "Lara");
i18nc("venezuela.kgm", "Barquisimeto");
i18nc("venezuela.kgm", "Mérida");
i18nc("venezuela.kgm", "Mérida");
i18nc("venezuela.kgm", "Miranda");
i18nc("venezuela.kgm", "Los Teques");
i18nc("venezuela.kgm", "Monagas");
i18nc("venezuela.kgm", "Maturín");
i18nc("venezuela.kgm", "Nueva Esparta");
i18nc("venezuela.kgm", "La Asunción");
i18nc("venezuela.kgm", "Portuguesa");
i18nc("venezuela.kgm", "Guanare");
i18nc("venezuela.kgm", "Sucre");
i18nc("venezuela.kgm", "Cumaná");
i18nc("venezuela.kgm", "Táchira");
i18nc("venezuela.kgm", "San Cristóbal");
i18nc("venezuela.kgm", "Trujillo");
i18nc("venezuela.kgm", "Trujillo");
i18nc("venezuela.kgm", "Yaracuy");
i18nc("venezuela.kgm", "San Felipe");
i18nc("venezuela.kgm", "Vargas");
i18nc("venezuela.kgm", "La Guaira");
i18nc("venezuela.kgm", "Zulia");
i18nc("venezuela.kgm", "Maracaibo");
i18nc("venezuela.kgm", "Federal Dependencies");
i18nc("venezuela.kgm", "Caracas");
i18nc("venezuela.kgm", "Capital District");
i18nc("venezuela.kgm", "Caracas ciudad");
i18nc("vietnam.kgm", "Vietnam");
i18nc("vietnam.kgm", "Provinces");
i18nc("vietnam.kgm", "Frontier");
i18nc("vietnam.kgm", "Not Vietnam");
i18nc("vietnam.kgm", "Water");
i18nc("vietnam.kgm", "An Giang");
i18nc("vietnam.kgm", "Long Xuyen");
i18nc("vietnam.kgm", "Bac Giang");
i18nc("vietnam.kgm", "Bac Giang");
i18nc("vietnam.kgm", "Bac Kan");
i18nc("vietnam.kgm", "Bac Kan");
i18nc("vietnam.kgm", "Bac Lieu");
i18nc("vietnam.kgm", "Bac Lieu");
i18nc("vietnam.kgm", "Bac Ninh");
i18nc("vietnam.kgm", "Bac Ninh");
i18nc("vietnam.kgm", "Ba Ria-Vung Tau");
i18nc("vietnam.kgm", "Vung Tau");
i18nc("vietnam.kgm", "Ben Tre");
i18nc("vietnam.kgm", "Ben Tre");
i18nc("vietnam.kgm", "Binh Dinh");
i18nc("vietnam.kgm", "Qui Nhon");
i18nc("vietnam.kgm", "Binh Duong");
i18nc("vietnam.kgm", "Thu Dau Mot");
i18nc("vietnam.kgm", "Binh Phuoc");
i18nc("vietnam.kgm", "Dong Xoai");
i18nc("vietnam.kgm", "Binh Thuan");
i18nc("vietnam.kgm", "Phan Thiet");
i18nc("vietnam.kgm", "Ca Mau");
i18nc("vietnam.kgm", "Ca Mau");
i18nc("vietnam.kgm", "Can Tho");
i18nc("vietnam.kgm", "Cao Bang");
i18nc("vietnam.kgm", "Cao Bang");
i18nc("vietnam.kgm", "Dak Lak");
i18nc("vietnam.kgm", "Buon Ma Thuot");
i18nc("vietnam.kgm", "Dak Nong");
i18nc("vietnam.kgm", "Gia Nghia");
i18nc("vietnam.kgm", "Da Nang");
i18nc("vietnam.kgm", "Dien Bien");
i18nc("vietnam.kgm", "Dien Bien Phu");
i18nc("vietnam.kgm", "Dong Nai");
i18nc("vietnam.kgm", "Bien Hoa");
i18nc("vietnam.kgm", "Dong Thap");
i18nc("vietnam.kgm", "Cao Lanh");
i18nc("vietnam.kgm", "Gia Lai");
i18nc("vietnam.kgm", "PleiKu");
i18nc("vietnam.kgm", "Ha Giang");
i18nc("vietnam.kgm", "Ha Giang");
i18nc("vietnam.kgm", "Hai Duong");
i18nc("vietnam.kgm", "Hai Duong");
i18nc("vietnam.kgm", "Hai Phong");
i18nc("vietnam.kgm", "Ha Nam");
i18nc("vietnam.kgm", "Phu Ly");
i18nc("vietnam.kgm", "Ha Noi");
i18nc("vietnam.kgm", "Ha Tay");
i18nc("vietnam.kgm", "Ha Dong");
i18nc("vietnam.kgm", "Ha Tinh");
i18nc("vietnam.kgm", "Ha Tinh");
i18nc("vietnam.kgm", "Hoa Binh");
i18nc("vietnam.kgm", "Hoa Binh");
i18nc("vietnam.kgm", "Ho Chi Minh");
i18nc("vietnam.kgm", "Hau Giang");
i18nc("vietnam.kgm", "Vi Thanh");
i18nc("vietnam.kgm", "Hung Yen");
i18nc("vietnam.kgm", "Hung Yen");
i18nc("vietnam.kgm", "Khanh Hoa");
i18nc("vietnam.kgm", "Nha Trang");
i18nc("vietnam.kgm", "Kien Giang");
i18nc("vietnam.kgm", "Rach Gia");
i18nc("vietnam.kgm", "Kon Tum");
i18nc("vietnam.kgm", "Kon Tum");
i18nc("vietnam.kgm", "Lai Chau");
i18nc("vietnam.kgm", "Lai Chau");
i18nc("vietnam.kgm", "Lam Dong");
i18nc("vietnam.kgm", "Da Lat");
i18nc("vietnam.kgm", "Lang Son");
i18nc("vietnam.kgm", "Lang Son");
i18nc("vietnam.kgm", "Lao Cai");
i18nc("vietnam.kgm", "Lao Cai");
i18nc("vietnam.kgm", "Long An");
i18nc("vietnam.kgm", "Tan An");
i18nc("vietnam.kgm", "Nam Dinh");
i18nc("vietnam.kgm", "Nam Dinh");
i18nc("vietnam.kgm", "Nghe An");
i18nc("vietnam.kgm", "Vinh");
i18nc("vietnam.kgm", "Ninh Binh");
i18nc("vietnam.kgm", "Ninh Binh");
i18nc("vietnam.kgm", "Ninh Thuan");
i18nc("vietnam.kgm", "Phan Rang-Thap Cham");
i18nc("vietnam.kgm", "Phu Tho");
i18nc("vietnam.kgm", "Viet Tri");
i18nc("vietnam.kgm", "Phu Yen");
i18nc("vietnam.kgm", "Tuy Hoa");
i18nc("vietnam.kgm", "Quang Binh");
i18nc("vietnam.kgm", "Dong Hoi");
i18nc("vietnam.kgm", "Quang Nam");
i18nc("vietnam.kgm", "Tam Ky");
i18nc("vietnam.kgm", "Quang Ngai");
i18nc("vietnam.kgm", "Quang Ngai");
i18nc("vietnam.kgm", "Quang Ninh");
i18nc("vietnam.kgm", "Ha Long");
i18nc("vietnam.kgm", "Quang Tri");
i18nc("vietnam.kgm", "Dong Ha");
i18nc("vietnam.kgm", "Soc Trang");
i18nc("vietnam.kgm", "Soc Trang");
i18nc("vietnam.kgm", "Son La");
i18nc("vietnam.kgm", "Son La");
i18nc("vietnam.kgm", "Tay Ninh");
i18nc("vietnam.kgm", "Tay Ninh");
i18nc("vietnam.kgm", "Thai Binh");
i18nc("vietnam.kgm", "Thai Binh");
i18nc("vietnam.kgm", "Thai Nguyen");
i18nc("vietnam.kgm", "Thai Nguyen");
i18nc("vietnam.kgm", "Thanh Hoa");
i18nc("vietnam.kgm", "Thanh Hoa");
i18nc("vietnam.kgm", "Thua Thien-Hue");
i18nc("vietnam.kgm", "Hue");
i18nc("vietnam.kgm", "Tien Giang");
i18nc("vietnam.kgm", "My Tho");
i18nc("vietnam.kgm", "Tra Vinh");
i18nc("vietnam.kgm", "Tra Vinh");
i18nc("vietnam.kgm", "Tuyen Quang");
i18nc("vietnam.kgm", "Tuyen Quang");
i18nc("vietnam.kgm", "Vinh Long");
i18nc("vietnam.kgm", "Vinh Long");
i18nc("vietnam.kgm", "Vinh Phuc");
i18nc("vietnam.kgm", "Vinh Yen");
i18nc("vietnam.kgm", "Yen Bai");
i18nc("vietnam.kgm", "Yen Bai");
i18nc("waters_world-class.kgm", "Waters (World-Class)");
i18nc("waters_world-class.kgm", "Oceans and basins");
i18nc("waters_world-class.kgm", "Frontier");
i18nc("waters_world-class.kgm", "Not Waters (World-Class)");
i18nc("waters_world-class.kgm", "Water");
i18nc("waters_world-class.kgm", "Arctic ocean");
i18nc("waters_world-class.kgm", "Northern Pacific");
i18nc("waters_world-class.kgm", "Northern Atlantic");
i18nc("waters_world-class.kgm", "Southern Pacific");
i18nc("waters_world-class.kgm", "Southern Atlantic");
i18nc("waters_world-class.kgm", "Indian ocean");
i18nc("waters_world-class.kgm", "Antarctic ocean");
i18nc("waters_world-class.kgm", "Congo");
i18nc("waters_world-class.kgm", "Lake Chad");
i18nc("waters_world-class.kgm", "Jubba");
i18nc("waters_world-class.kgm", "Limpopo");
i18nc("waters_world-class.kgm", "Mangoky");
i18nc("waters_world-class.kgm", "Mania");
i18nc("waters_world-class.kgm", "Niger");
i18nc("waters_world-class.kgm", "Nile");
i18nc("waters_world-class.kgm", "Ogooue");
i18nc("waters_world-class.kgm", "Okavango swamp");
i18nc("waters_world-class.kgm", "Orange");
i18nc("waters_world-class.kgm", "Oued Draa");
i18nc("waters_world-class.kgm", "Senegal");
i18nc("waters_world-class.kgm", "Shabelle");
i18nc("waters_world-class.kgm", "Turkana");
i18nc("waters_world-class.kgm", "Volta");
i18nc("waters_world-class.kgm", "Zambezi");
i18nc("waters_world-class.kgm", "Dalalven");
i18nc("waters_world-class.kgm", "Danube");
i18nc("waters_world-class.kgm", "Daugava");
i18nc("waters_world-class.kgm", "Dnieper");
i18nc("waters_world-class.kgm", "Dniester");
i18nc("waters_world-class.kgm", "Don");
i18nc("waters_world-class.kgm", "Ebro");
i18nc("waters_world-class.kgm", "Elbe");
i18nc("waters_world-class.kgm", "Garonne");
i18nc("waters_world-class.kgm", "Glama");
i18nc("waters_world-class.kgm", "Guadalquivir");
i18nc("waters_world-class.kgm", "Kemijoki");
i18nc("waters_world-class.kgm", "Kura (& Araks)");
i18nc("waters_world-class.kgm", "Loire");
i18nc("waters_world-class.kgm", "Neva");
i18nc("waters_world-class.kgm", "Dvina");
i18nc("waters_world-class.kgm", "Oder");
i18nc("waters_world-class.kgm", "Po");
i18nc("waters_world-class.kgm", "Rhine");
i18nc("waters_world-class.kgm", "Rhone");
i18nc("waters_world-class.kgm", "Seine");
i18nc("waters_world-class.kgm", "Tagus");
i18nc("waters_world-class.kgm", "Tigris (& Euphrates)");
i18nc("waters_world-class.kgm", "Ural");
i18nc("waters_world-class.kgm", "Vistula");
i18nc("waters_world-class.kgm", "Volga");
i18nc("waters_world-class.kgm", "Weser");
i18nc("waters_world-class.kgm", "Amu Darya");
i18nc("waters_world-class.kgm", "Amur");
i18nc("waters_world-class.kgm", "Lake Balkhash");
i18nc("waters_world-class.kgm", "Brahmaputra");
i18nc("waters_world-class.kgm", "Chao Phrya");
i18nc("waters_world-class.kgm", "Fly");
i18nc("waters_world-class.kgm", "Ganges");
i18nc("waters_world-class.kgm", "Godavari");
i18nc("waters_world-class.kgm", "Hong (Red river)");
i18nc("waters_world-class.kgm", "Hwang He");
i18nc("waters_world-class.kgm", "Indigirka");
i18nc("waters_world-class.kgm", "Indus");
i18nc("waters_world-class.kgm", "Irrawaddy");
i18nc("waters_world-class.kgm", "Kapuas");
i18nc("waters_world-class.kgm", "Kolyma");
i18nc("waters_world-class.kgm", "Krishna");
i18nc("waters_world-class.kgm", "Lena");
i18nc("waters_world-class.kgm", "Mahakam");
i18nc("waters_world-class.kgm", "Mahanadi");
i18nc("waters_world-class.kgm", "Mekong");
i18nc("waters_world-class.kgm", "Murray (& Darling)");
i18nc("waters_world-class.kgm", "Narmada");
i18nc("waters_world-class.kgm", "Ob");
i18nc("waters_world-class.kgm", "Salween");
i18nc("waters_world-class.kgm", "Sepik");
i18nc("waters_world-class.kgm", "Syr Daria");
i18nc("waters_world-class.kgm", "Tapti");
i18nc("waters_world-class.kgm", "Tarim");
i18nc("waters_world-class.kgm", "Xi Jiang");
i18nc("waters_world-class.kgm", "Yalu Jiang");
i18nc("waters_world-class.kgm", "Yangtze");
i18nc("waters_world-class.kgm", "Yenisey");
i18nc("waters_world-class.kgm", "Alabama (& Tombigbee)");
i18nc("waters_world-class.kgm", "Balsas");
i18nc("waters_world-class.kgm", "Brazos");
i18nc("waters_world-class.kgm", "Colorado");
i18nc("waters_world-class.kgm", "Columbia");
i18nc("waters_world-class.kgm", "Fraser");
i18nc("waters_world-class.kgm", "Hudson");
i18nc("waters_world-class.kgm", "Mackenzie");
i18nc("waters_world-class.kgm", "Mississippi");
i18nc("waters_world-class.kgm", "Nelson");
i18nc("waters_world-class.kgm", "Rio Grande");
i18nc("waters_world-class.kgm", "Rio Grande de Santiago");
i18nc("waters_world-class.kgm", "Sacramento");
i18nc("waters_world-class.kgm", "Saint Lawrence");
i18nc("waters_world-class.kgm", "Susquehanna");
i18nc("waters_world-class.kgm", "Thelon");
i18nc("waters_world-class.kgm", "Usumacinta");
i18nc("waters_world-class.kgm", "Yaqui");
i18nc("waters_world-class.kgm", "Yukon");
i18nc("waters_world-class.kgm", "Amazon");
i18nc("waters_world-class.kgm", "Chubut");
i18nc("waters_world-class.kgm", "Magdalena");
i18nc("waters_world-class.kgm", "Orinoco");
i18nc("waters_world-class.kgm", "Parana");
i18nc("waters_world-class.kgm", "Pamaiba");
i18nc("waters_world-class.kgm", "Rio Colorado");
i18nc("waters_world-class.kgm", "Sao Francisco");
i18nc("waters_world-class.kgm", "Lake Titicaca");
i18nc("waters_world-class.kgm", "Tocantins");
i18nc("waters_world-class.kgm", "Uruguay");
i18nc("waters_world-class.kgm", "Douro");
i18nc("waters_world-class.kgm", "Guadiana");
i18nc("waters_world-class.kgm", "Meuse");
i18nc("waters_world-class.kgm", "Lake Eyre");
i18nc("waters_world-class.kgm", "Caspian sea");
i18nc("waters_world-class.kgm", "Tiber");
i18nc("westbengal.kgm", "West Bengal");
i18nc("westbengal.kgm", "District");
i18nc("westbengal.kgm", "Not West Bengal");
i18nc("westbengal.kgm", "Border");
i18nc("westbengal.kgm", "Purulia");
i18nc("westbengal.kgm", "Purulia");
i18nc("westbengal.kgm", "Bankura");
i18nc("westbengal.kgm", "Bankura");
i18nc("westbengal.kgm", "Paschim Medinipur");
i18nc("westbengal.kgm", "Midnapore");
i18nc("westbengal.kgm", "Purba Medinipur");
i18nc("westbengal.kgm", "Tamluk");
i18nc("westbengal.kgm", "Howrah");
i18nc("westbengal.kgm", "Howrah");
i18nc("westbengal.kgm", "South 24-Parganas ");
i18nc("westbengal.kgm", "Alipur");
i18nc("westbengal.kgm", "North 24-Parganas");
i18nc("westbengal.kgm", "Barasat");
i18nc("westbengal.kgm", "Kolkata");
i18nc("westbengal.kgm", "Kolkata");
i18nc("westbengal.kgm", "Hooghly ");
i18nc("westbengal.kgm", "Chunchura ");
i18nc("westbengal.kgm", "Burdwan");
i18nc("westbengal.kgm", "Burdwan");
i18nc("westbengal.kgm", "Nadia");
i18nc("westbengal.kgm", "Krishnanagar");
i18nc("westbengal.kgm", "Birbhum");
i18nc("westbengal.kgm", "Suri");
i18nc("westbengal.kgm", "Murshidabad");
i18nc("westbengal.kgm", "Baharampur");
i18nc("westbengal.kgm", "Malda");
i18nc("westbengal.kgm", "Inreg Bazar");
i18nc("westbengal.kgm", "Dakshin Dinajpur");
i18nc("westbengal.kgm", "Balurghat");
i18nc("westbengal.kgm", "Uttar Dinajpur");
i18nc("westbengal.kgm", "Raiganj");
i18nc("westbengal.kgm", "Darjeeling");
i18nc("westbengal.kgm", "Darjeeling");
i18nc("westbengal.kgm", "Jalpaiguri");
i18nc("westbengal.kgm", "Jalpaiguri");
i18nc("westbengal.kgm", "Cooch Behar");
i18nc("westbengal.kgm", "Cooch Behar");
i18nc("world.kgm", "World");
i18nc("world.kgm", "Countries");
i18nc("world.kgm", "Not a Nation");
i18nc("world.kgm", "Frontier");
i18nc("world.kgm", "Algeria");
i18nc("world.kgm", "Algiers");
i18nc("world.kgm", "Angola");
i18nc("world.kgm", "Luanda");
i18nc("world.kgm", "Benin");
i18nc("world.kgm", "Porto Novo");
i18nc("world.kgm", "Botswana");
i18nc("world.kgm", "Gaborone");
i18nc("world.kgm", "Burkina Faso");
i18nc("world.kgm", "Ouagadougou");
i18nc("world.kgm", "Burundi");
i18nc("world.kgm", "Bujumbura");
i18nc("world.kgm", "Cameroon");
i18nc("world.kgm", "Yaoundé");
i18nc("world.kgm", "Central African Republic");
i18nc("world.kgm", "Bangui");
i18nc("world.kgm", "Chad");
i18nc("world.kgm", "N'Djamena");
i18nc("world.kgm", "Côte d'Ivoire");
i18nc("world.kgm", "Yamoussoukro");
i18nc("world.kgm", "Democratic Republic of the Congo");
i18nc("world.kgm", "Kinshasa");
i18nc("world.kgm", "Djibouti");
i18nc("world.kgm", "Djibouti");
i18nc("world.kgm", "Egypt");
i18nc("world.kgm", "Cairo");
i18nc("world.kgm", "Equatorial Guinea");
i18nc("world.kgm", "Malabo");
i18nc("world.kgm", "Eritrea");
i18nc("world.kgm", "Asmara");
i18nc("world.kgm", "Ethiopia");
i18nc("world.kgm", "Addis Ababa");
i18nc("world.kgm", "Gabon");
i18nc("world.kgm", "Libreville");
i18nc("world.kgm", "Ghana");
i18nc("world.kgm", "Accra");
i18nc("world.kgm", "Guinea");
i18nc("world.kgm", "Conakry");
i18nc("world.kgm", "Guinea-Bissau");
i18nc("world.kgm", "Bissau");
i18nc("world.kgm", "Iran");
i18nc("world.kgm", "Tehran");
i18nc("world.kgm", "Iraq");
i18nc("world.kgm", "Baghdad");
i18nc("world.kgm", "Israel");
i18nc("world.kgm", "Jerusalem");
i18nc("world.kgm", "Jordan");
i18nc("world.kgm", "Amman");
i18nc("world.kgm", "Kenya");
i18nc("world.kgm", "Nairobi");
i18nc("world.kgm", "Kuwait");
i18nc("world.kgm", "Kuwait City");
i18nc("world.kgm", "Lebanon");
i18nc("world.kgm", "Beirut");
i18nc("world.kgm", "Lesotho");
i18nc("world.kgm", "Maseru");
i18nc("world.kgm", "Liberia");
i18nc("world.kgm", "Monrovia");
i18nc("world.kgm", "Libya");
i18nc("world.kgm", "Tripoli");
i18nc("world.kgm", "Liechtenstein");
i18nc("world.kgm", "Vaduz");
i18nc("world.kgm", "Madagascar");
i18nc("world.kgm", "Antananarivo");
i18nc("world.kgm", "Malawi");
i18nc("world.kgm", "Lilongwe");
i18nc("world.kgm", "Mali");
i18nc("world.kgm", "Bamako");
i18nc("world.kgm", "Mauritania");
i18nc("world.kgm", "Nouakchott");
i18nc("world.kgm", "Morocco");
i18nc("world.kgm", "Rabat");
i18nc("world.kgm", "Mozambique");
i18nc("world.kgm", "Maputo");
i18nc("world.kgm", "Namibia");
i18nc("world.kgm", "Windhoek");
i18nc("world.kgm", "Niger");
i18nc("world.kgm", "Niamey");
i18nc("world.kgm", "Nigeria");
i18nc("world.kgm", "Abuja");
i18nc("world.kgm", "Qatar");
i18nc("world.kgm", "Doha");
i18nc("world.kgm", "Republic of the Congo");
i18nc("world.kgm", "Brazzaville");
i18nc("world.kgm", "Rwanda");
i18nc("world.kgm", "Kigali");
i18nc("world.kgm", "Saudi Arabia");
i18nc("world.kgm", "Riyadh");
i18nc("world.kgm", "Senegal");
i18nc("world.kgm", "Dakar");
i18nc("world.kgm", "Sierra Leone");
i18nc("world.kgm", "Freetown");
i18nc("world.kgm", "Somalia");
i18nc("world.kgm", "Mogadishu");
i18nc("world.kgm", "South Africa");
i18nc("world.kgm", "Pretoria, Bloemfontein and Cape Town");
i18nc("world.kgm", "Sudan");
i18nc("world.kgm", "Khartoum");
i18nc("world.kgm", "South Sudan");
i18nc("world.kgm", "Juba");
i18nc("world.kgm", "Swaziland");
i18nc("world.kgm", "Mbabane");
i18nc("world.kgm", "Syria");
i18nc("world.kgm", "Damascus");
i18nc("world.kgm", "Tanzania");
i18nc("world.kgm", "Dodoma");
i18nc("world.kgm", "The Gambia");
i18nc("world.kgm", "Banjul");
i18nc("world.kgm", "Togo");
i18nc("world.kgm", "Lomé");
i18nc("world.kgm", "Tunisia");
i18nc("world.kgm", "Tunis");
i18nc("world.kgm", "Uganda");
i18nc("world.kgm", "Kampala");
i18nc("world.kgm", "United Arab Emirates");
i18nc("world.kgm", "Abu Dhabi City");
i18nc("world.kgm", "Oman");
i18nc("world.kgm", "Muscat");
i18nc("world.kgm", "West Bank");
i18nc("world.kgm", "Western Sahara");
i18nc("world.kgm", "Laayoune");
i18nc("world.kgm", "Yemen");
i18nc("world.kgm", "Sana'a");
i18nc("world.kgm", "Zambia");
i18nc("world.kgm", "Lusaka");
i18nc("world.kgm", "Zimbabwe");
i18nc("world.kgm", "Harare");
i18nc("world.kgm", "Albania");
i18nc("world.kgm", "Tirana");
i18nc("world.kgm", "Austria");
i18nc("world.kgm", "Vienna");
i18nc("world.kgm", "Belarus");
i18nc("world.kgm", "Minsk");
i18nc("world.kgm", "Belgium");
i18nc("world.kgm", "Brussels");
i18nc("world.kgm", "Bosnia and Herzegovina");
i18nc("world.kgm", "Sarajevo");
i18nc("world.kgm", "Bulgaria");
i18nc("world.kgm", "Sofia");
i18nc("world.kgm", "Croatia");
i18nc("world.kgm", "Zagreb");
i18nc("world.kgm", "Czech Republic");
i18nc("world.kgm", "Prague");
i18nc("world.kgm", "Denmark");
i18nc("world.kgm", "Copenhagen");
i18nc("world.kgm", "Estonia");
i18nc("world.kgm", "Tallinn");
i18nc("world.kgm", "Finland");
i18nc("world.kgm", "Helsinki");
i18nc("world.kgm", "Macedonia");
i18nc("world.kgm", "Skopje");
i18nc("world.kgm", "France");
i18nc("world.kgm", "Paris");
i18nc("world.kgm", "Germany");
i18nc("world.kgm", "Berlin");
i18nc("world.kgm", "Greece");
i18nc("world.kgm", "Athens");
i18nc("world.kgm", "Hungary");
i18nc("world.kgm", "Budapest");
i18nc("world.kgm", "Iceland");
i18nc("world.kgm", "Reykjavik");
i18nc("world.kgm", "Ireland");
i18nc("world.kgm", "Dublin");
i18nc("world.kgm", "Italy");
i18nc("world.kgm", "Rome");
i18nc("world.kgm", "Latvia");
i18nc("world.kgm", "Riga");
i18nc("world.kgm", "Lithuania");
i18nc("world.kgm", "Vilnius");
i18nc("world.kgm", "Luxembourg");
i18nc("world.kgm", "Luxembourg");
i18nc("world.kgm", "Moldova");
i18nc("world.kgm", "Chisinau");
i18nc("world.kgm", "Netherlands");
i18nc("world.kgm", "Amsterdam");
i18nc("world.kgm", "Norway");
i18nc("world.kgm", "Oslo");
i18nc("world.kgm", "Poland");
i18nc("world.kgm", "Warsaw");
i18nc("world.kgm", "Portugal");
i18nc("world.kgm", "Lisbon");
i18nc("world.kgm", "Romania");
i18nc("world.kgm", "Bucharest");
i18nc("world.kgm", "Russia");
i18nc("world.kgm", "Moscow");
i18nc("world.kgm", "San Marino");
i18nc("world.kgm", "San Marino");
i18nc("world.kgm", "Serbia");
i18nc("world.kgm", "Belgrade");
i18nc("world.kgm", "Montenegro");
i18nc("world.kgm", "Podgorica");
i18nc("world.kgm", "Slovakia");
i18nc("world.kgm", "Bratislava");
i18nc("world.kgm", "Slovenia");
i18nc("world.kgm", "Ljubljana");
i18nc("world.kgm", "Spain");
i18nc("world.kgm", "Madrid");
i18nc("world.kgm", "Sweden");
i18nc("world.kgm", "Stockholm");
i18nc("world.kgm", "Switzerland");
i18nc("world.kgm", "Bern");
i18nc("world.kgm", "Turkey");
i18nc("world.kgm", "Ankara");
i18nc("world.kgm", "Ukraine");
i18nc("world.kgm", "Kiev");
i18nc("world.kgm", "United Kingdom");
i18nc("world.kgm", "London");
i18nc("world.kgm", "Canada");
i18nc("world.kgm", "Ottawa");
i18nc("world.kgm", "El Salvador");
i18nc("world.kgm", "San Salvador");
i18nc("world.kgm", "The United States of America");
i18nc("world.kgm", "Washington D.C.");
i18nc("world.kgm", "The Bahamas");
i18nc("world.kgm", "Nassau");
i18nc("world.kgm", "The Dominican Republic");
i18nc("world.kgm", "Santo Domingo");
i18nc("world.kgm", "Haiti");
i18nc("world.kgm", "Port-au-Prince");
i18nc("world.kgm", "Cuba");
i18nc("world.kgm", "Havana");
i18nc("world.kgm", "Jamaica");
i18nc("world.kgm", "Kingston");
i18nc("world.kgm", "Dominica");
i18nc("world.kgm", "Roseau");
i18nc("world.kgm", "Barbados");
i18nc("world.kgm", "Bridgetown");
i18nc("world.kgm", "Antigua and Barbuda");
i18nc("world.kgm", "St. John's");
i18nc("world.kgm", "Trinidad and Tobago");
i18nc("world.kgm", "Port of Spain");
i18nc("world.kgm", "Mexico");
i18nc("world.kgm", "Mexico City");
i18nc("world.kgm", "Guatemala");
i18nc("world.kgm", "Guatemala City");
i18nc("world.kgm", "Belize");
i18nc("world.kgm", "Belmopan");
i18nc("world.kgm", "Honduras");
i18nc("world.kgm", "Tegucigalpa");
i18nc("world.kgm", "Nicaragua");
i18nc("world.kgm", "Managua");
i18nc("world.kgm", "Costa Rica");
i18nc("world.kgm", "San José");
i18nc("world.kgm", "Panama");
i18nc("world.kgm", "Panama City");
i18nc("world.kgm", "Colombia");
i18nc("world.kgm", "Bogotá");
i18nc("world.kgm", "Venezuela");
i18nc("world.kgm", "Caracas");
i18nc("world.kgm", "Guyana");
i18nc("world.kgm", "Georgetown");
i18nc("world.kgm", "Suriname");
i18nc("world.kgm", "Paramaribo");
i18nc("world.kgm", "French Guiana");
i18nc("world.kgm", "Cayenne");
i18nc("world.kgm", "Ecuador");
i18nc("world.kgm", "Quito");
i18nc("world.kgm", "Peru");
i18nc("world.kgm", "Lima");
i18nc("world.kgm", "Brazil");
i18nc("world.kgm", "Brasilia");
i18nc("world.kgm", "Bolivia");
i18nc("world.kgm", "La Paz");
i18nc("world.kgm", "Chile");
i18nc("world.kgm", "Santiago");
i18nc("world.kgm", "Paraguay");
i18nc("world.kgm", "Asunción");
i18nc("world.kgm", "Argentina");
i18nc("world.kgm", "Buenos Aires");
i18nc("world.kgm", "Uruguay");
i18nc("world.kgm", "Montevideo");
i18nc("world.kgm", "Australia");
i18nc("world.kgm", "Canberra");
i18nc("world.kgm", "New Zealand");
i18nc("world.kgm", "Wellington");
i18nc("world.kgm", "Vatican City");
i18nc("world.kgm", "Vatican City");
i18nc("world.kgm", "Andorra");
i18nc("world.kgm", "Andorra la Vella");
i18nc("world.kgm", "Monaco");
i18nc("world.kgm", "Monaco-Ville");
i18nc("world.kgm", "China");
i18nc("world.kgm", "Beijing");
i18nc("world.kgm", "India");
i18nc("world.kgm", "New Delhi");
i18nc("world.kgm", "Sri Lanka");
i18nc("world.kgm", "Colombo and Sri Jayewardenepura");
i18nc("world.kgm", "Mongolia");
i18nc("world.kgm", "Ulaanbaatar");
i18nc("world.kgm", "Kazakhstan");
i18nc("world.kgm", "Astana");
i18nc("world.kgm", "Japan");
i18nc("world.kgm", "Tokyo");
i18nc("world.kgm", "Myanmar");
i18nc("world.kgm", "Naypyidaw");
i18nc("world.kgm", "Nepal");
i18nc("world.kgm", "Kathmandu");
i18nc("world.kgm", "Bhutan");
i18nc("world.kgm", "Thimphu");
i18nc("world.kgm", "Indonesia");
i18nc("world.kgm", "Jakarta");
i18nc("world.kgm", "Malaysia");
i18nc("world.kgm", "Kuala Lumpur");
i18nc("world.kgm", "Bangladesh");
i18nc("world.kgm", "Dhaka");
i18nc("world.kgm", "Cyprus");
i18nc("world.kgm", "Nicosia");
i18nc("world.kgm", "Afghanistan");
i18nc("world.kgm", "Kabul");
i18nc("world.kgm", "Azerbaijan");
i18nc("world.kgm", "Baku");
i18nc("world.kgm", "Armenia");
i18nc("world.kgm", "Yerevan");
i18nc("world.kgm", "Bahrain");
i18nc("world.kgm", "Manama");
i18nc("world.kgm", "Georgia");
i18nc("world.kgm", "Tbilisi");
i18nc("world.kgm", "Turkmenistan");
i18nc("world.kgm", "Ashgabat");
i18nc("world.kgm", "Uzbekistan");
i18nc("world.kgm", "Tashkent");
i18nc("world.kgm", "Kyrgyzstan");
i18nc("world.kgm", "Bishkek");
i18nc("world.kgm", "Tajikistan");
i18nc("world.kgm", "Dushanbe");
i18nc("world.kgm", "Pakistan");
i18nc("world.kgm", "Islamabad");
i18nc("world.kgm", "Laos");
i18nc("world.kgm", "Vientiane");
i18nc("world.kgm", "Cambodia");
i18nc("world.kgm", "Phnom Penh");
i18nc("world.kgm", "East Timor");
i18nc("world.kgm", "Dili");
i18nc("world.kgm", "Brunei");
i18nc("world.kgm", "Bandar Seri Begawan");
i18nc("world.kgm", "Philippines");
i18nc("world.kgm", "Manila");
i18nc("world.kgm", "Thailand");
i18nc("world.kgm", "Bangkok");
i18nc("world.kgm", "Vietnam");
i18nc("world.kgm", "Hanoi");
i18nc("world.kgm", "Republic of China (Taiwan)");
i18nc("world.kgm", "Taipei");
i18nc("world.kgm", "Singapore");
i18nc("world.kgm", "Singapore");
i18nc("world.kgm", "Democratic People's Republic of Korea");
i18nc("world.kgm", "Pyeongyang");
i18nc("world.kgm", "Republic of Korea");
i18nc("world.kgm", "Seoul");
i18nc("world.kgm", "Fiji");
i18nc("world.kgm", "Suva");
i18nc("world.kgm", "Tonga");
i18nc("world.kgm", "Nuku'alofa");
i18nc("world.kgm", "Papua New Guinea");
i18nc("world.kgm", "Port Moresby");
i18nc("world.kgm", "Greenland (Denmark)");
i18nc("world.kgm", "Nuuk");
i18nc("world_continents.kgm", "World continents (from North Pole)");
i18nc("world_continents.kgm", "Continents");
i18nc("@title:group", "What is the highest summit of %1?");
i18nc("@title", "Continents by highest summit");
i18nc("@title:group", "Which has %1 as its highest summit?");
i18nc("@title", "Highest summit of continents");
i18nc("world_continents.kgm", "Frontier");
i18nc("world_continents.kgm", "Water");
i18nc("world_continents.kgm", "Africa");
i18nc("world_continents.kgm", "Kilimanjaro");
i18nc("world_continents.kgm", "North America");
i18nc("world_continents.kgm", "Mac Kinley");
i18nc("world_continents.kgm", "South America");
i18nc("world_continents.kgm", "Aconcagua");
i18nc("world_continents.kgm", "Antarctica");
i18nc("world_continents.kgm", "Vinson");
i18nc("world_continents.kgm", "Asia");
i18nc("world_continents.kgm", "Everest");
i18nc("world_continents.kgm", "Europe");
i18nc("world_continents.kgm", "Elbrus");
i18nc("world_continents.kgm", "Oceania");
i18nc("world_continents.kgm", "Carstenz");
i18nc("yemen.kgm", "Yemen");
i18nc("yemen.kgm", "Governorates");
i18nc("yemen.kgm", "Frontier");
i18nc("yemen.kgm", "Water");
i18nc("yemen.kgm", "Not Yemen");
i18nc("yemen.kgm", "Abyan");
i18nc("yemen.kgm", "'Adan");
i18nc("yemen.kgm", "Ad Dali'");
i18nc("yemen.kgm", "Al Bayda'");
i18nc("yemen.kgm", "Al Hudaydah");
i18nc("yemen.kgm", "Al Jawf");
i18nc("yemen.kgm", "Al Mahri");
i18nc("yemen.kgm", "Al Mahwit");
i18nc("yemen.kgm", "'Amran");
i18nc("yemen.kgm", "Dhamar");
i18nc("yemen.kgm", "Hadramaout");
i18nc("yemen.kgm", "Hajjah");
i18nc("yemen.kgm", "Ibb");
i18nc("yemen.kgm", "Lahij");
i18nc("yemen.kgm", "Ma'rib");
i18nc("yemen.kgm", "Sa'dah");
i18nc("yemen.kgm", "Sanaa");
i18nc("yemen.kgm", "Shabwah");
i18nc("yemen.kgm", "Ta'izz");
i18nc("zaire2006.kgm", "Democratic Republic of the Congo");
i18nc("zaire2006.kgm", "Provinces");
i18nc("zaire2006.kgm", "Frontier");
i18nc("zaire2006.kgm", "Water");
i18nc("zaire2006.kgm", "Not Democratic Republic of the Congo");
i18nc("zaire2006.kgm", "Kinshasa");
i18nc("zaire2006.kgm", "Kinshasa");
i18nc("zaire2006.kgm", "Kongo central");
i18nc("zaire2006.kgm", "Matadi");
i18nc("zaire2006.kgm", "Kwango");
i18nc("zaire2006.kgm", "Kenge");
i18nc("zaire2006.kgm", "Kwilu");
i18nc("zaire2006.kgm", "Kikwit");
i18nc("zaire2006.kgm", "Mai-Ndombe");
i18nc("zaire2006.kgm", "Inongo");
i18nc("zaire2006.kgm", "Kasaï");
i18nc("zaire2006.kgm", "Luebo");
i18nc("zaire2006.kgm", "Lulua");
i18nc("zaire2006.kgm", "Kananga");
i18nc("zaire2006.kgm", "Kasaï oriental");
i18nc("zaire2006.kgm", "Mbuji-Mayi");
i18nc("zaire2006.kgm", "Lomami");
i18nc("zaire2006.kgm", "Kabinda");
i18nc("zaire2006.kgm", "Sankuru");
i18nc("zaire2006.kgm", "Lodja");
i18nc("zaire2006.kgm", "Maniema");
i18nc("zaire2006.kgm", "Kindu");
i18nc("zaire2006.kgm", "Sud-Kivu");
i18nc("zaire2006.kgm", "Bukavu");
i18nc("zaire2006.kgm", "Nord-Kivu");
i18nc("zaire2006.kgm", "Goma");
i18nc("zaire2006.kgm", "Ituri");
i18nc("zaire2006.kgm", "Bunia");
i18nc("zaire2006.kgm", "Haut-Uele");
i18nc("zaire2006.kgm", "Isiro");
i18nc("zaire2006.kgm", "Tshopo");
i18nc("zaire2006.kgm", "Kisangani");
i18nc("zaire2006.kgm", "Bas-Uele");
i18nc("zaire2006.kgm", "Buta");
i18nc("zaire2006.kgm", "Nord-Ubangi");
i18nc("zaire2006.kgm", "Gbadolite");
i18nc("zaire2006.kgm", "Mongala");
i18nc("zaire2006.kgm", "Lisala");
i18nc("zaire2006.kgm", "Sud-Ubangi");
i18nc("zaire2006.kgm", "Gemena");
i18nc("zaire2006.kgm", "Équateur");
i18nc("zaire2006.kgm", "Mbandaka");
i18nc("zaire2006.kgm", "Tshuapa");
i18nc("zaire2006.kgm", "Boende");
i18nc("zaire2006.kgm", "Tanganyika");
i18nc("zaire2006.kgm", "Kalemie");
i18nc("zaire2006.kgm", "Haut-Lomami");
i18nc("zaire2006.kgm", "Kamina");
i18nc("zaire2006.kgm", "Lualaba");
i18nc("zaire2006.kgm", "Kolwezi");
i18nc("zaire2006.kgm", "Haut-Katanga");
i18nc("zaire2006.kgm", "Lubumbashi");
i18nc("zambia_districts.kgm", "Zambia (Districts)");
i18nc("zambia_districts.kgm", "Districts");
i18nc("zambia_districts.kgm", "Frontier");
i18nc("zambia_districts.kgm", "Water");
i18nc("zambia_districts.kgm", "Not Zambia (Districts)");
i18nc("zambia_districts.kgm", "Chibombo");
i18nc("zambia_districts.kgm", "Kabwe");
i18nc("zambia_districts.kgm", "Kapiri Mposhi");
i18nc("zambia_districts.kgm", "Mkushi");
i18nc("zambia_districts.kgm", "Mumbwa");
i18nc("zambia_districts.kgm", "Serenje");
i18nc("zambia_districts.kgm", "Chililabombwe");
i18nc("zambia_districts.kgm", "Chingola");
i18nc("zambia_districts.kgm", "Kalulushi");
i18nc("zambia_districts.kgm", "Kitwe");
i18nc("zambia_districts.kgm", "Luanshya");
i18nc("zambia_districts.kgm", "Lufwanyama");
i18nc("zambia_districts.kgm", "Masaiti");
i18nc("zambia_districts.kgm", "Mpongwe");
i18nc("zambia_districts.kgm", "Mufulira");
i18nc("zambia_districts.kgm", "Ndola");
i18nc("zambia_districts.kgm", "Chadiza");
i18nc("zambia_districts.kgm", "Chama");
i18nc("zambia_districts.kgm", "Chipata");
i18nc("zambia_districts.kgm", "Katete");
i18nc("zambia_districts.kgm", "Lundazi");
i18nc("zambia_districts.kgm", "Mambwe");
i18nc("zambia_districts.kgm", "Nyimba");
i18nc("zambia_districts.kgm", "Petauke");
i18nc("zambia_districts.kgm", "Chiengi");
i18nc("zambia_districts.kgm", "Kawambwa");
i18nc("zambia_districts.kgm", "Mansa");
i18nc("zambia_districts.kgm", "Milenge");
i18nc("zambia_districts.kgm", "Mwense");
i18nc("zambia_districts.kgm", "Nchelenge");
i18nc("zambia_districts.kgm", "Samfya");
i18nc("zambia_districts.kgm", "Chongwe");
i18nc("zambia_districts.kgm", "Kafue");
i18nc("zambia_districts.kgm", "Luangwa");
i18nc("zambia_districts.kgm", "Lusaka");
i18nc("zambia_districts.kgm", "Chavuma");
i18nc("zambia_districts.kgm", "Kabompo");
i18nc("zambia_districts.kgm", "Kasempa");
i18nc("zambia_districts.kgm", "Mufumbwe");
i18nc("zambia_districts.kgm", "Mwinilunga");
i18nc("zambia_districts.kgm", "Solwezi");
i18nc("zambia_districts.kgm", "Zambezi");
i18nc("zambia_districts.kgm", "Chilubi");
i18nc("zambia_districts.kgm", "Chinsali");
i18nc("zambia_districts.kgm", "Isoka");
i18nc("zambia_districts.kgm", "Kaputa");
i18nc("zambia_districts.kgm", "Kasama");
i18nc("zambia_districts.kgm", "Luwingu");
i18nc("zambia_districts.kgm", "Mbala");
i18nc("zambia_districts.kgm", "Mpika");
i18nc("zambia_districts.kgm", "Mporokoso");
i18nc("zambia_districts.kgm", "Mpulungu");
i18nc("zambia_districts.kgm", "Mungwi");
i18nc("zambia_districts.kgm", "Nakonde");
i18nc("zambia_districts.kgm", "Choma");
i18nc("zambia_districts.kgm", "Gwembe");
i18nc("zambia_districts.kgm", "Itezhi-Tezhi");
i18nc("zambia_districts.kgm", "Kalomo");
i18nc("zambia_districts.kgm", "Kazungula");
i18nc("zambia_districts.kgm", "Livingstone");
i18nc("zambia_districts.kgm", "Mazabuka");
i18nc("zambia_districts.kgm", "Monze");
i18nc("zambia_districts.kgm", "Namwala");
i18nc("zambia_districts.kgm", "Siavonga");
i18nc("zambia_districts.kgm", "Sinazongwe");
i18nc("zambia_districts.kgm", "Kalabo");
i18nc("zambia_districts.kgm", "Kaoma");
i18nc("zambia_districts.kgm", "Lukulu");
i18nc("zambia_districts.kgm", "Mongu");
i18nc("zambia_districts.kgm", "Senanga");
i18nc("zambia_districts.kgm", "Sesheke");
i18nc("zambia_districts.kgm", "Shangombo");
i18nc("zambia_provinces.kgm", "Zambia (Provinces)");
i18nc("zambia_provinces.kgm", "Provinces");
i18nc("zambia_provinces.kgm", "Frontier");
i18nc("zambia_provinces.kgm", "Water");
i18nc("zambia_provinces.kgm", "Not Zambia (Provinces)");
i18nc("zambia_provinces.kgm", "Central");
i18nc("zambia_provinces.kgm", "Kabwe");
i18nc("zambia_provinces.kgm", "Copperbelt");
i18nc("zambia_provinces.kgm", "Ndola");
i18nc("zambia_provinces.kgm", "Eastern");
i18nc("zambia_provinces.kgm", "Chipata");
i18nc("zambia_provinces.kgm", "Luapula");
i18nc("zambia_provinces.kgm", "Mansa");
i18nc("zambia_provinces.kgm", "Lusaka");
i18nc("zambia_provinces.kgm", "Lusaka");
i18nc("zambia_provinces.kgm", "Northern");
i18nc("zambia_provinces.kgm", "Kasama");
i18nc("zambia_provinces.kgm", "North-Western");
i18nc("zambia_provinces.kgm", "Solwezi");
i18nc("zambia_provinces.kgm", "Southern");
i18nc("zambia_provinces.kgm", "Livingstone");
i18nc("zambia_provinces.kgm", "Western");
i18nc("zambia_provinces.kgm", "Mongu");
i18nc("zimbabwe.kgm", "Zimbabwe");
i18nc("zimbabwe.kgm", "Provinces");
i18nc("zimbabwe.kgm", "Frontier");
i18nc("zimbabwe.kgm", "Frontier");
i18nc("zimbabwe.kgm", "Not Zimbabwe");
i18nc("zimbabwe.kgm", "Bulawayo");
i18nc("zimbabwe.kgm", "Harare");
i18nc("zimbabwe.kgm", "Manicaland");
i18nc("zimbabwe.kgm", "Mutare");
i18nc("zimbabwe.kgm", "Mashonaland central");
i18nc("zimbabwe.kgm", "Bindura");
i18nc("zimbabwe.kgm", "Mashonaland east");
i18nc("zimbabwe.kgm", "Marondera");
i18nc("zimbabwe.kgm", "Mashonaland west");
i18nc("zimbabwe.kgm", "Chinhoyi");
i18nc("zimbabwe.kgm", "Masvingo");
i18nc("zimbabwe.kgm", "Masvingo");
i18nc("zimbabwe.kgm", "Matabeleland north");
i18nc("zimbabwe.kgm", "Lupane");
i18nc("zimbabwe.kgm", "Matabeleland south");
i18nc("zimbabwe.kgm", "Gwanda");
i18nc("zimbabwe.kgm", "Midlands");
i18nc("zimbabwe.kgm", "Gweru");
i18nc("zimbabwe_districts.kgm", "Zimbabwe (Districts)");
i18nc("zimbabwe_districts.kgm", "Districts");
i18nc("zimbabwe_districts.kgm", "Frontier");
i18nc("zimbabwe_districts.kgm", "Water");
i18nc("zimbabwe_districts.kgm", "Not Zimbabwe (Districts)");
i18nc("zimbabwe_districts.kgm", "Bulawayo");
i18nc("zimbabwe_districts.kgm", "Harare");
i18nc("zimbabwe_districts.kgm", "Buhera");
i18nc("zimbabwe_districts.kgm", "Chimanimani");
i18nc("zimbabwe_districts.kgm", "Chipinge");
i18nc("zimbabwe_districts.kgm", "Makoni");
i18nc("zimbabwe_districts.kgm", "Mutare");
i18nc("zimbabwe_districts.kgm", "Mutasa");
i18nc("zimbabwe_districts.kgm", "Nyanga");
i18nc("zimbabwe_districts.kgm", "Bindura");
i18nc("zimbabwe_districts.kgm", "Guruve");
i18nc("zimbabwe_districts.kgm", "Mazowe");
i18nc("zimbabwe_districts.kgm", "Mount Darwin");
i18nc("zimbabwe_districts.kgm", "Muzarabani");
i18nc("zimbabwe_districts.kgm", "Rushinga");
i18nc("zimbabwe_districts.kgm", "Shamva");
i18nc("zimbabwe_districts.kgm", "Chikomba");
i18nc("zimbabwe_districts.kgm", "Goromonzi");
i18nc("zimbabwe_districts.kgm", "Marondera");
i18nc("zimbabwe_districts.kgm", "Mudzi");
i18nc("zimbabwe_districts.kgm", "Murehwa");
i18nc("zimbabwe_districts.kgm", "Mutoko");
i18nc("zimbabwe_districts.kgm", "Seke");
i18nc("zimbabwe_districts.kgm", "UMP");
i18nc("zimbabwe_districts.kgm", "Wedza");
i18nc("zimbabwe_districts.kgm", "Chegutu");
i18nc("zimbabwe_districts.kgm", "Hurungwe");
i18nc("zimbabwe_districts.kgm", "Kadoma");
i18nc("zimbabwe_districts.kgm", "Kariba");
i18nc("zimbabwe_districts.kgm", "Makonde");
i18nc("zimbabwe_districts.kgm", "Zvimba");
i18nc("zimbabwe_districts.kgm", "Bikita");
i18nc("zimbabwe_districts.kgm", "Chiredzi");
i18nc("zimbabwe_districts.kgm", "Chivi");
i18nc("zimbabwe_districts.kgm", "Gutu");
i18nc("zimbabwe_districts.kgm", "Masvingo");
i18nc("zimbabwe_districts.kgm", "Mwenezi");
i18nc("zimbabwe_districts.kgm", "Zaka");
i18nc("zimbabwe_districts.kgm", "Binga");
i18nc("zimbabwe_districts.kgm", "Bubi");
i18nc("zimbabwe_districts.kgm", "Hwange");
i18nc("zimbabwe_districts.kgm", "Lupane");
i18nc("zimbabwe_districts.kgm", "Nkayi");
i18nc("zimbabwe_districts.kgm", "Tsholotsho");
i18nc("zimbabwe_districts.kgm", "Umguza");
i18nc("zimbabwe_districts.kgm", "Beitbridge");
i18nc("zimbabwe_districts.kgm", "Bulilimamangwe");
i18nc("zimbabwe_districts.kgm", "Gwanda");
i18nc("zimbabwe_districts.kgm", "Insiza");
i18nc("zimbabwe_districts.kgm", "Matobo");
i18nc("zimbabwe_districts.kgm", "Umzingwane");
i18nc("zimbabwe_districts.kgm", "Chirumhanzu");
i18nc("zimbabwe_districts.kgm", "Gokwe north");
i18nc("zimbabwe_districts.kgm", "Gokwe south");
i18nc("zimbabwe_districts.kgm", "Gweru");
i18nc("zimbabwe_districts.kgm", "Kwekwe");
i18nc("zimbabwe_districts.kgm", "Mberengwa");
i18nc("zimbabwe_districts.kgm", "Shurugwi");
i18nc("zimbabwe_districts.kgm", "Zvishavane");
